@@ -1,10 +1,9 @@
 //----------------------------------*-C++-*----------------------------------//
-// $Id: plstream.h 12885 2013-12-19 11:43:30Z andrewross $
 // Geoffrey Furnish
 // Sep 21 1994
 //
 // Copyright (C) 2004,2005  Andrew Ross
-// Copyright (C) 2004  Alan W. Irwin
+// Copyright (C) 2004-2014 Alan W. Irwin
 //
 // This file is part of PLplot.
 //
@@ -79,6 +78,36 @@ public:
     void xform( PLFLT x, PLFLT y, PLFLT& tx, PLFLT& ty ) const;
 };
 
+//--------------------------------------------------------------------------
+//Callback functions for passing into various API methods. We provide these
+//wrappers to avoid a requirement for linking to the C shared library.
+//--------------------------------------------------------------------------
+
+namespace plcallback
+{
+// Callback for plfill. This will just call the C plfill function
+
+PLDLLIMPEXP_CXX void fill( PLINT n, const PLFLT *x, const PLFLT *y );
+
+// Identity transformation.
+
+PLDLLIMPEXP_CXX void tr0( PLFLT x, PLFLT y, PLFLT *tx, PLFLT *ty, PLPointer pltr_data );
+
+// Does linear interpolation from singly dimensioned coord arrays.
+
+PLDLLIMPEXP_CXX void tr1( PLFLT x, PLFLT y, PLFLT *tx, PLFLT *ty, PLPointer pltr_data );
+
+// Does linear interpolation from doubly dimensioned coord arrays
+// (column dominant, as per normal C 2d arrays).
+
+PLDLLIMPEXP_CXX void tr2( PLFLT x, PLFLT y, PLFLT *tx, PLFLT *ty, PLPointer pltr_data );
+
+// Just like pltr2() but uses pointer arithmetic to get coordinates from
+// 2d grid tables.
+
+PLDLLIMPEXP_CXX void tr2p( PLFLT x, PLFLT y, PLFLT *tx, PLFLT *ty, PLPointer pltr_data );
+}
+
 //--------------------------------------------------------------------------
 // class plstream - C++ class for encapsulating PLplot streams
 
@@ -86,7 +115,7 @@ public:
 //--------------------------------------------------------------------------
 
 class PLDLLIMPEXP_CXX plstream {
-    PLINT stream;
+    PLINT        stream;
 
     static PLINT active_streams;
 
@@ -131,8 +160,7 @@ public:
 #endif // PL_DEPRECATED
 
     void vect( const PLFLT * const *u, const PLFLT * const *v, PLINT nx, PLINT ny, PLFLT scale,
-               void ( *pltr )( PLFLT, PLFLT, PLFLT *, PLFLT *, PLPointer ),
-               PLPointer pltr_data );
+               PLTRANSFORM_callback pltr, PLPointer pltr_data );
 
 // Set the arrow style
     void svect( const PLFLT *arrow_x = NULL, const PLFLT *arrow_y = NULL, PLINT npts = 0, bool fill = false );
@@ -204,8 +232,7 @@ public:
 
     void cont( const PLFLT * const *f, PLINT nx, PLINT ny, PLINT kx, PLINT lx,
                PLINT ky, PLINT ly, const PLFLT * clevel, PLINT nlevel,
-               void ( *pltr )( PLFLT, PLFLT, PLFLT *, PLFLT *, PLPointer ),
-               PLPointer pltr_data );
+               PLTRANSFORM_callback pltr, PLPointer pltr_data );
 
 // Draws a contour plot using the function evaluator f2eval and data stored
 // by way of the f2eval_data pointer.  This allows arbitrary organizations
@@ -215,8 +242,7 @@ public:
                 PLPointer f2eval_data,
                 PLINT nx, PLINT ny, PLINT kx, PLINT lx,
                 PLINT ky, PLINT ly, const PLFLT * clevel, PLINT nlevel,
-                void ( *pltr )( PLFLT, PLFLT, PLFLT *, PLFLT *, PLPointer ),
-                PLPointer pltr_data );
+                PLTRANSFORM_callback pltr, PLPointer pltr_data );
 
 // Copies state parameters from the reference stream to the current stream.
 
@@ -276,11 +302,11 @@ public:
 
 // Pattern fills the polygon bounded by the input points.
 
-    static void fill( PLINT n, const PLFLT *x, const PLFLT *y );
+    void fill( PLINT n, const PLFLT *x, const PLFLT *y );
 
 // Pattern fills the 3d polygon bounded by the input points.
 
-    static void fill3( PLINT n, const PLFLT *x, const PLFLT *y, const PLFLT *z );
+    void fill3( PLINT n, const PLFLT *x, const PLFLT *y, const PLFLT *z );
 
 // Flushes the output stream.  Use sparingly, if at all.
 
@@ -361,7 +387,7 @@ public:
 
 // Draw gradient in polygon.
 
-    static void gradient( PLINT n, const PLFLT *x, const PLFLT *y, PLFLT angle );
+    void gradient( PLINT n, const PLFLT *x, const PLFLT *y, PLFLT angle );
 
 // grid irregularly sampled data
 
@@ -469,14 +495,40 @@ public:
 
     void lsty( PLINT lin );
 
-// plot continental outline in world coordinates
+// Plot continental outline in world coordinates
 
-    void map( void ( *mapform )( PLINT, PLFLT *, PLFLT * ), const char *type,
-              PLFLT minlong, PLFLT maxlong, PLFLT minlat, PLFLT maxlat );
+    void map( PLMAPFORM_callback mapform, const char *name,
+              PLFLT minx, PLFLT maxx, PLFLT miny, PLFLT maxy );
+
+// Plot map lines
+
+    void mapline( PLMAPFORM_callback mapform, const char *name,
+                  PLFLT minx, PLFLT maxx, PLFLT miny, PLFLT maxy,
+                  const PLINT *plotentries, PLINT nplotentries );
+
+// Plot map points
+
+    void mapstring( PLMAPFORM_callback mapform,
+                    const char *name, const char *string,
+                    PLFLT minx, PLFLT maxx, PLFLT miny, PLFLT maxy,
+                    const PLINT *plotentries, PLINT nplotentries );
+
+// Plot map text
+
+    void maptex( PLMAPFORM_callback mapform,
+                 const char *name, PLFLT dx, PLFLT dy, PLFLT just, const char *text,
+                 PLFLT minx, PLFLT maxx, PLFLT miny, PLFLT maxy,
+                 PLINT plotentry );
+
+// Plot map fills
+
+    void mapfill( PLMAPFORM_callback mapform,
+                  const char *name, PLFLT minx, PLFLT maxx, PLFLT miny,
+                  PLFLT maxy, const PLINT *plotentries, PLINT nplotentries );
 
 // Plot the latitudes and longitudes on the background.
 
-    void meridians( void ( *mapform )( PLINT, PLFLT *, PLFLT * ),
+    void meridians( PLMAPFORM_callback mapform,
                     PLFLT dlong, PLFLT dlat, PLFLT minlong, PLFLT maxlong,
                     PLFLT minlat, PLFLT maxlat );
 
@@ -541,7 +593,7 @@ public:
 
 // Process options list using current options info.
 
-    int parseopts( int *p_argc, const char **argv, PLINT mode );
+    PLINT parseopts( int *p_argc, char **argv, PLINT mode );
 
 // Set fill pattern directly.
 
@@ -581,6 +633,10 @@ public:
     void ptex3( PLFLT wx, PLFLT wy, PLFLT wz, PLFLT dx, PLFLT dy, PLFLT dz,
                 PLFLT sx, PLFLT sy, PLFLT sz, PLFLT just, const char *text );
 
+// Get the world coordinates associated with device coordinates
+
+    PLINT translatecursor( PLGraphicsIn *gin );
+
 // Replays contents of plot buffer to current device/file.
 
     void replot( void );
@@ -730,6 +786,10 @@ public:
 
     void sfnam( const char *fnam );
 
+// Set the pointer to the data used in driver initialisation
+
+    void sdevdata( void *data );
+
 // Set the current font family, style and weight
 
     void sfont( PLINT family, PLINT style, PLINT weight );
@@ -737,24 +797,22 @@ public:
 // Shade region.
 
     void shade( const PLFLT * const *a, PLINT nx, PLINT ny,
-                PLINT ( *defined )( PLFLT, PLFLT ),
+                PLDEFINED_callback defined,
                 PLFLT left, PLFLT right, PLFLT bottom, PLFLT top,
                 PLFLT shade_min, PLFLT shade_max,
                 PLINT sh_cmap, PLFLT sh_color, PLFLT sh_width,
                 PLINT min_color, PLFLT min_width,
                 PLINT max_color, PLFLT max_width,
-                void ( *fill )( PLINT, const PLFLT *, const PLFLT * ), bool rectangular,
-                void ( *pltr )( PLFLT, PLFLT, PLFLT *, PLFLT *, PLPointer ),
-                PLPointer pltr_data );
+                PLFILL_callback fill, bool rectangular,
+                PLTRANSFORM_callback pltr, PLPointer pltr_data );
 
     void shades( const PLFLT * const *a, PLINT nx, PLINT ny,
-                 PLINT ( *defined )( PLFLT, PLFLT ),
+                 PLDEFINED_callback defined,
                  PLFLT xmin, PLFLT xmax, PLFLT ymin, PLFLT ymax,
                  const PLFLT * clevel, PLINT nlevel, PLFLT fill_width,
                  PLINT cont_color, PLFLT cont_width,
-                 void ( *fill )( PLINT, const PLFLT *, const PLFLT * ), bool rectangular,
-                 void ( *pltr )( PLFLT, PLFLT, PLFLT *, PLFLT *, PLPointer ),
-                 PLPointer pltr_data );
+                 PLFILL_callback fill, bool rectangular,
+                 PLTRANSFORM_callback pltr, PLPointer pltr_data );
 
 // Would be nice to fix this even more, say by stuffing xmin, xmax,
 // ymin, ymax, rectangular, and pcxf all into the contourable data
@@ -769,15 +827,14 @@ public:
                 Coord_Xformer *pcxf );
 
     void shade1( const PLFLT * a, PLINT nx, PLINT ny,
-                 PLINT ( *defined )( PLFLT, PLFLT ),
+                 PLDEFINED_callback defined,
                  PLFLT left, PLFLT right, PLFLT bottom, PLFLT top,
                  PLFLT shade_min, PLFLT shade_max,
                  PLINT sh_cmap, PLFLT sh_color, PLFLT sh_width,
                  PLINT min_color, PLFLT min_width,
                  PLINT max_color, PLFLT max_width,
-                 void ( *fill )( PLINT, const PLFLT *, const PLFLT * ), bool rectangular,
-                 void ( *pltr )( PLFLT, PLFLT, PLFLT *, PLFLT *, PLPointer ),
-                 PLPointer pltr_data );
+                 PLFILL_callback fill, bool rectangular,
+                 PLTRANSFORM_callback pltr, PLPointer pltr_data );
 
     void fshade( PLFLT ( *f2eval )( PLINT, PLINT, PLPointer ),
                  PLPointer f2eval_data,
@@ -789,14 +846,12 @@ public:
                  PLINT sh_cmap, PLFLT sh_color, PLFLT sh_width,
                  PLINT min_color, PLFLT min_width,
                  PLINT max_color, PLFLT max_width,
-                 void ( *fill )( PLINT, const PLFLT *, const PLFLT * ), bool rectangular,
-                 void ( *pltr )( PLFLT, PLFLT, PLFLT *, PLFLT *, PLPointer ),
-                 PLPointer pltr_data );
+                 PLFILL_callback fill, bool rectangular,
+                 PLTRANSFORM_callback pltr, PLPointer pltr_data );
 
 // Setup a user-provided custom labeling function
 
-    void slabelfunc( void ( *label_func )( PLINT, PLFLT, char *, PLINT, PLPointer ),
-                     PLPointer label_data );
+    void slabelfunc( PLLABEL_FUNC_callback label_func, PLPointer label_data );
 
 // Set up lengths of major tick marks.
 
@@ -857,7 +912,7 @@ public:
 
 // Set the coordinate transform
 
-    void stransform( void ( *coordinate_transform )( PLFLT, PLFLT, PLFLT*, PLFLT*, PLPointer ), PLPointer coordinate_transform_data );
+    void stransform( PLTRANSFORM_callback coordinate_transform, PLPointer coordinate_transform_data );
 
 // Prints out the same string repeatedly at the n points in world
 // coordinates given by the x and y arrays.  Supersedes plpoin and
@@ -905,8 +960,7 @@ public:
     void imagefr( const PLFLT * const *data, PLINT nx, PLINT ny, PLFLT xmin, PLFLT xmax,
                   PLFLT ymin, PLFLT ymax, PLFLT zmin, PLFLT zmax,
                   PLFLT valuemin, PLFLT valuemax,
-                  void ( *pltr )( PLFLT, PLFLT, PLFLT *, PLFLT *, PLPointer ),
-                  PLPointer pltr_data );
+                  PLTRANSFORM_callback pltr, PLPointer pltr_data );
 
 // Set up a new line style
 
@@ -1020,21 +1074,21 @@ public:
 
 // Identity transformation.
 
-    static void tr0( PLFLT x, PLFLT y, PLFLT *tx, PLFLT *ty, PLPointer pltr_data );
+    //static void tr0( PLFLT x, PLFLT y, PLFLT *tx, PLFLT *ty, PLPointer pltr_data );
 
 // Does linear interpolation from singly dimensioned coord arrays.
 
-    static void tr1( PLFLT x, PLFLT y, PLFLT *tx, PLFLT *ty, PLPointer pltr_data );
+    //static void tr1( PLFLT x, PLFLT y, PLFLT *tx, PLFLT *ty, PLPointer pltr_data );
 
 // Does linear interpolation from doubly dimensioned coord arrays
 // (column dominant, as per normal C 2d arrays).
 
-    static void tr2( PLFLT x, PLFLT y, PLFLT *tx, PLFLT *ty, PLPointer pltr_data );
+    //static void tr2( PLFLT x, PLFLT y, PLFLT *tx, PLFLT *ty, PLPointer pltr_data );
 
 // Just like pltr2() but uses pointer arithmetic to get coordinates from
 // 2d grid tables.
 
-    static void tr2p( PLFLT x, PLFLT y, PLFLT *tx, PLFLT *ty, PLPointer pltr_data );
+    //static void tr2p( PLFLT x, PLFLT y, PLFLT *tx, PLFLT *ty, PLPointer pltr_data );
 
 // We obviously won't be using this object from Fortran...
 
@@ -1080,7 +1134,7 @@ public:
 
 // Merge user option table into internal info structure.
 
-    int MergeOpts( PLOptionTable *options, const char *name, const char **notes );
+    PLINT MergeOpts( PLOptionTable *options, const char *name, const char **notes );
 
 // Set the strings used in usage and syntax messages.
 
@@ -1088,7 +1142,7 @@ public:
 
 // Process input strings, treating them as an option and argument pair.
 
-    int setopt( const char *opt, const char *optarg );
+    PLINT setopt( const char *opt, const char *optarg );
 
 // This version is for backward compatibility only - don't use in new code
 
@@ -1122,7 +1176,7 @@ public:
 
 // Return full pathname for given file if executable
 
-    int  FindName( char *p );
+    PLINT  FindName( char *p );
 
 // Looks for the specified executable file according to usual search path.
 
@@ -1164,7 +1218,7 @@ public:
 
 // Wait for graphics input event and translate to world coordinates
 
-    int GetCursor( PLGraphicsIn *plg );
+    PLINT GetCursor( PLGraphicsIn *plg );
 
 // Deprecated versions of methods which use PLINT instead of bool
     void svect( const PLFLT *arrow_x, const PLFLT *arrow_y, PLINT npts, PLINT fill );
@@ -1176,24 +1230,21 @@ public:
                   const PLFLT *coord1, const PLFLT *coord2, const PLFLT *coord3, const PLINT *alt_hue_path );
 
     void shade( const PLFLT * const *a, PLINT nx, PLINT ny,
-                PLINT ( *defined )( PLFLT, PLFLT ),
+                PLDEFINED_callback defined,
                 PLFLT left, PLFLT right, PLFLT bottom, PLFLT top,
                 PLFLT shade_min, PLFLT shade_max,
                 PLINT sh_cmap, PLFLT sh_color, PLFLT sh_width,
                 PLINT min_color, PLFLT min_width,
                 PLINT max_color, PLFLT max_width,
-                void ( *fill )( PLINT, const PLFLT *, const PLFLT * ), PLINT rectangular,
-                void ( *pltr )( PLFLT, PLFLT, PLFLT *, PLFLT *, PLPointer ),
-                PLPointer pltr_data );
+                PLFILL_callback fill, PLINT rectangular,
+                PLTRANSFORM_callback pltr, PLPointer pltr_data );
 
-    void shades( const PLFLT * const *a, PLINT nx, PLINT ny, PLINT ( *defined )( PLFLT,
-                                                                                 PLFLT ),
+    void shades( const PLFLT * const *a, PLINT nx, PLINT ny, PLDEFINED_callback defined,
                  PLFLT xmin, PLFLT xmax, PLFLT ymin, PLFLT ymax,
                  const PLFLT * clevel, PLINT nlevel, PLFLT fill_width,
                  PLINT cont_color, PLFLT cont_width,
-                 void ( *fill )( PLINT, const PLFLT *, const PLFLT * ), PLINT rectangular,
-                 void ( *pltr )( PLFLT, PLFLT, PLFLT *, PLFLT *, PLPointer ),
-                 PLPointer pltr_data );
+                 PLFILL_callback fill, PLINT rectangular,
+                 PLTRANSFORM_callback pltr, PLPointer pltr_data );
 
     void shade( Contourable_Data& d, PLFLT xmin, PLFLT xmax,
                 PLFLT ymin, PLFLT ymax, PLFLT shade_min, PLFLT shade_max,
@@ -1204,15 +1255,14 @@ public:
                 Coord_Xformer *pcxf );
 
     void shade1( const PLFLT * a, PLINT nx, PLINT ny,
-                 PLINT ( *defined )( PLFLT, PLFLT ),
+                 PLDEFINED_callback defined,
                  PLFLT left, PLFLT right, PLFLT bottom, PLFLT top,
                  PLFLT shade_min, PLFLT shade_max,
                  PLINT sh_cmap, PLFLT sh_color, PLFLT sh_width,
                  PLINT min_color, PLFLT min_width,
                  PLINT max_color, PLFLT max_width,
-                 void ( *fill )( PLINT, const PLFLT *, const PLFLT * ), PLINT rectangular,
-                 void ( *pltr )( PLFLT, PLFLT, PLFLT *, PLFLT *, PLPointer ),
-                 PLPointer pltr_data );
+                 PLFILL_callback fill, PLINT rectangular,
+                 PLTRANSFORM_callback pltr, PLPointer pltr_data );
 
     void fshade( PLFLT ( *f2eval )( PLINT, PLINT, PLPointer ),
                  PLPointer f2eval_data,
@@ -1224,9 +1274,8 @@ public:
                  PLINT sh_cmap, PLFLT sh_color, PLFLT sh_width,
                  PLINT min_color, PLFLT min_width,
                  PLINT max_color, PLFLT max_width,
-                 void ( *fill )( PLINT, const PLFLT *, const PLFLT * ), PLINT rectangular,
-                 void ( *pltr )( PLFLT, PLFLT, PLFLT *, PLFLT *, PLPointer ),
-                 PLPointer pltr_data );
+                 PLFILL_callback fill, PLINT rectangular,
+                 PLTRANSFORM_callback pltr, PLPointer pltr_data );
 
     void spause( PLINT pause );
 
