@@ -609,6 +609,30 @@ public class PLStream implements plplotjavacConstants {
         plplotjavac.plmap( mapform, type, minlong, maxlong, minlat, maxlat );
     }
 
+    public void mapline( PLCallbackMapform mapform, String type, double minlong, double maxlong, double minlat, double maxlat, int[] plotentries )
+    {
+        if ( set_stream() == -1 ) return;
+        plplotjavac.plmapline( mapform, type, minlong, maxlong, minlat, maxlat, plotentries );
+    }
+
+    public void mapstring( PLCallbackMapform mapform, String type, String string, double minlong, double maxlong, double minlat, double maxlat, int[] plotentries )
+    {
+        if ( set_stream() == -1 ) return;
+        plplotjavac.plmapstring( mapform, type, string, minlong, maxlong, minlat, maxlat, plotentries );
+    }
+
+    public void maptex( PLCallbackMapform mapform, String type, double dx, double dy, double just, String text, double minlong, double maxlong, double minlat, double maxlat, int plotentry )
+    {
+        if ( set_stream() == -1 ) return;
+        plplotjavac.plmaptex( mapform, type, dx, dy, just, text, minlong, maxlong, minlat, maxlat, plotentry );
+    }
+
+    public void mapfill( PLCallbackMapform mapform, String type, double minlong, double maxlong, double minlat, double maxlat, int[] plotentries )
+    {
+        if ( set_stream() == -1 ) return;
+        plplotjavac.plmapfill( mapform, type, minlong, maxlong, minlat, maxlat, plotentries );
+    }
+
     public void meridians( PLCallbackMapform mapform, double dlong, double dlat, double minlong, double maxlong, double minlat, double maxlat )
     {
         if ( set_stream() == -1 ) return;
@@ -683,10 +707,10 @@ public class PLStream implements plplotjavacConstants {
         plplotjavac.plsurf3dl( x, y, z, opt, clevel, ixstart, indexymin, indexymax );
     }
 
-    public void parseopts( String[] argv, int mode )
+    public int parseopts( String[] argv, int mode )
     {
-        if ( set_stream() == -1 ) return;
-        plplotjavac.plparseopts( argv, mode );
+        if ( set_stream() == -1 ) return 0;
+        return plplotjavac.plparseopts( argv, mode );
     }
 
     public void pat( int[] inc, int[] del )
@@ -922,10 +946,10 @@ public class PLStream implements plplotjavacConstants {
         plplotjavac.plsesc( esc );
     }
 
-    public void setopt( String opt, String optarg )
+    public int setopt( String opt, String optarg )
     {
-        if ( set_stream() == -1 ) return;
-        plplotjavac.plsetopt( opt, optarg );
+        if ( set_stream() == -1 ) return 0;
+        return plplotjavac.plsetopt( opt, optarg );
     }
 
     public void sfam( int fam, int num, int bmax )
@@ -1194,6 +1218,13 @@ public class PLStream implements plplotjavacConstants {
             zmin0, zmax0, alt, az );
     }
 
+    public void width( double width )
+    {
+        if ( set_stream() == -1 ) return;
+        plplotjavac.plwidth( width );
+    }
+
+    // Overloaded version with integer width.
     public void width( int width )
     {
         if ( set_stream() == -1 ) return;
