@@ -12,11 +12,6 @@ type attribute_spec = {
    below. *)
 let manual_function_attributes =
   [
-    {
-      function_name = "c_plhist";
-      function_attrs = None;
-      parameter_attrs = Some ["data", ["size_is(n)"]];
-    };
     {
       function_name = "c_plimage";
       function_attrs = None;
@@ -35,12 +30,12 @@ let manual_function_attributes =
     {
       function_name = "c_plscmap1l";
       function_attrs = None;
-      parameter_attrs = Some ["rev", ["in"; "size_is(npts)"; "unique"]];
+      parameter_attrs = Some ["alt_hue_path", ["in"; "size_is(npts)"; "unique"]];
     };
     {
       function_name = "c_plscmap1la";
       function_attrs = None;
-      parameter_attrs = Some ["rev", ["in"; "size_is(npts)"; "unique"]];
+      parameter_attrs = Some ["alt_hue_path", ["in"; "size_is(npts)"; "unique"]];
     };
     {
       function_name = "c_plxormod";
@@ -79,6 +74,7 @@ let manual_function_attributes =
       function_attrs = None;
       parameter_attrs = Some ["ctime", ["out"]];
     };
+    (* For now, this will be wrapped by hand...
     {
       function_name = "c_plcolorbar";
       function_attrs = None;
@@ -86,7 +82,6 @@ let manual_function_attributes =
                               "p_colorbar_width", ["out"];
                               "p_colorbar_height", ["out"]];
     };
-    (* For now, this will be wrapped by hand...
     {
       function_name = "c_plgriddata";
       function_attrs = None;
@@ -344,6 +339,12 @@ let parameter_attributes function_name types names =
       true,
       true,
       ["out"];
+      (* Index limits *)
+      true,
+      pmatch "\\*" p_type,
+      List.mem p_name ["indexymin"; "indexymax"],
+      true,
+      ["size_is(indexxmax)"; "in"];
     ]
   in
 
