@@ -1,11 +1,11 @@
 ## Copyright (C) 1998-2003  Joao Cardoso.
 ## Copyright (C) 2004  Rafael Laboissiere
-## 
+##
 ## This program is free software; you can redistribute it and/or modify it
 ## under the terms of the GNU General Public License as published by the
 ## Free Software Foundation; either version 2 of the License, or (at your
 ## option) any later version.
-## 
+##
 ## This program is distributed in the hope that it will be useful, but
 ## WITHOUT ANY WARRANTY; without even the implied warranty of
 ## MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
@@ -20,7 +20,7 @@
 function out = __pl_matstr(mat, str, n)
 
   ## Octave damned string arrays are defective!
-  if (ischar(str) & ischar(mat) & rows(str) == 1)
+  if (ischar(str) && ischar(mat) && rows(str) == 1)
     if (isempty(mat))
       out(n,:) = str;
     else
