@@ -5,7 +5,7 @@
 // Imperial College, London
 //
 // Copyright (C) 2009  Imperial College, London
-// Copyright (C) 2009-2011  Alan W. Irwin
+// Copyright (C) 2009-2016  Alan W. Irwin
 //
 // This is free software; you can redistribute it and/or modify
 // it under the terms of the GNU General Lesser Public License as published
@@ -265,7 +265,10 @@ QPicture QtPLDriver::getTextPicture( PLUNICODE fci, PLUNICODE* text, int len, PL
     // cairo.  I assume all these issues are due to Qt5 version 5.2.1
     // font selection and font alignment bugs which will be addressed
     // for future Qt5 versions.
-    PLFLT empirical_yOffset = -0.63 * chrht * POINTS_PER_INCH / 25.4;
+    // PLFLT empirical_yOffset = -0.63 * chrht * POINTS_PER_INCH / 25.4;
+    // With Debian Jessie Qt5 version 5.3.2, that font alignment bug
+    // finally appears to be fixed.
+    PLFLT empirical_yOffset = 0.;
 #else
     PLFLT empirical_yOffset = 0.;
 #endif
@@ -1653,7 +1656,7 @@ void plsetqtdev( QtExtWidget* widget )
 
 void plsetqtdev( QtExtWidget* widget, int argc, char** argv )
 {
-    plparseopts( &argc, (const char **) argv, PL_PARSE_FULL );
+    plparseopts( &argc, argv, PL_PARSE_FULL );
     plsc->dev = (void *) widget;
     widget->setPLStream( plsc );
 }
@@ -1664,5 +1667,3 @@ void plfreeqtdev()
     plsc->dev = NULL;
 }
 #endif
-
-#include "moc_files.h"
