@@ -1,5 +1,3 @@
-// $Id: pltcl.h 11295 2010-11-01 22:19:45Z airwin $
-//
 // Maurice LeBrun
 // 21-Jun-94
 //
@@ -23,7 +21,7 @@ extern "C" {
 // Main program for a Tcl-based shell that reads Tcl commands from stdin.
 
 PLDLLIMPEXP_TCLTK int
-pltclMain( int argc, const char **argv, char *RcFileName,
+pltclMain( int argc, char **argv, char *RcFileName,
            int ( *AppInit )( Tcl_Interp *interp ) );
 
 // tclAPI.c
