@@ -1,5 +1,3 @@
-// $Id: tkMain.c 12881 2013-12-19 01:25:14Z airwin $
-//
 // Modified version of tkMain.c, from Tk 3.6.
 // Maurice LeBrun
 // 23-Jun-1994
@@ -388,7 +386,7 @@ pltkMain( int argc, const char **argv, char *RcFileName,
 
     if ( fileName != NULL )
     {
-        code = Tcl_VarEval( interp, "source ", fileName, (char *) NULL );
+        code = Tcl_VarEval( interp, "source \"", fileName, "\"", (char *) NULL );
         if ( code != TCL_OK )
         {
             goto error;
