@@ -1,12 +1,8 @@
 var annotated =
 [
-    [ "makedocstrings", "namespacemakedocstrings.html", null ],
-    [ "plcallback", "namespaceplcallback.html", null ],
-    [ "Plframe", "namespacePlframe.html", "namespacePlframe" ],
     [ "plplot", "namespaceplplot.html", "namespaceplplot" ],
     [ "plplotc", "namespaceplplotc.html", "namespaceplplotc" ],
-    [ "Swig", "namespaceSwig.html", null ],
-    [ "TclSup", "namespaceTclSup.html", null ],
+    [ "plplotc_fixed", "namespaceplplotc__fixed.html", "namespaceplplotc__fixed" ],
     [ "__dlhandle", "struct____dlhandle.html", "struct____dlhandle" ],
     [ "_plm_format", "struct__plm__format.html", "struct__plm__format" ],
     [ "_plm_version", "struct__plm__version.html", "struct__plm__version" ],
@@ -34,6 +30,7 @@ var annotated =
     [ "DrvOptCmd", "structDrvOptCmd.html", "structDrvOptCmd" ],
     [ "EscText", "structEscText.html", "structEscText" ],
     [ "FCI_to_FontName_Table", "structFCI__to__FontName__Table.html", "structFCI__to__FontName__Table" ],
+    [ "Font", "classFont.html", "classFont" ],
     [ "FontGrabber", "classFontGrabber.html", "classFontGrabber" ],
     [ "hashtable", "structhashtable.html", "structhashtable" ],
     [ "Hershey_to_Unicode_table", "structHershey__to__Unicode__table.html", "structHershey__to__Unicode__table" ],
@@ -65,6 +62,7 @@ var annotated =
     [ "PLColor", "structPLColor.html", "structPLColor" ],
     [ "PLControlPt", "structPLControlPt.html", "structPLControlPt" ],
     [ "PLDev", "structPLDev.html", "structPLDev" ],
+    [ "PlDevice", "classPlDevice.html", "classPlDevice" ],
     [ "PLDispatchTable", "structPLDispatchTable.html", "structPLDispatchTable" ],
     [ "PLDisplay", "structPLDisplay.html", "structPLDisplay" ],
     [ "plf2ops_t", "structplf2ops__t.html", "structplf2ops__t" ],
@@ -82,24 +80,17 @@ var annotated =
     [ "PLOptionInfo", "structPLOptionInfo.html", "structPLOptionInfo" ],
     [ "PLOptionTable", "structPLOptionTable.html", "structPLOptionTable" ],
     [ "plplot", "classplplot.html", "classplplot" ],
-    [ "plplot_graphics", "classplplot__graphics.html", [
-      [ "plgraphicsin", "structplplot__graphics_1_1plgraphicsin.html", "structplplot__graphics_1_1plgraphicsin" ]
-    ] ],
-    [ "plplot_str", "classplplot__str.html", "classplplot__str" ],
-    [ "plplot_strutils", "classplplot__strutils.html", "classplplot__strutils" ],
+    [ "plplot_double", "classplplot__double.html", "classplplot__double" ],
+    [ "plplot_graphics", "classplplot__graphics.html", "classplplot__graphics" ],
+    [ "plplot_private_exposed", "classplplot__private__exposed.html", "classplplot__private__exposed" ],
+    [ "plplot_private_utilities", "classplplot__private__utilities.html", "classplplot__private__utilities" ],
+    [ "plplot_single", "classplplot__single.html", "classplplot__single" ],
     [ "plplot_types", "classplplot__types.html", "classplplot__types" ],
-    [ "plplotp", "classplplotp.html", [
-      [ "plcont", "interfaceplplotp_1_1plcont.html", "interfaceplplotp_1_1plcont" ],
-      [ "plimagefr", "interfaceplplotp_1_1plimagefr.html", "interfaceplplotp_1_1plimagefr" ],
-      [ "plshade", "interfaceplplotp_1_1plshade.html", "interfaceplplotp_1_1plshade" ],
-      [ "plshades", "interfaceplplotp_1_1plshades.html", "interfaceplplotp_1_1plshades" ],
-      [ "plvect", "interfaceplplotp_1_1plvect.html", "interfaceplplotp_1_1plvect" ]
-    ] ],
     [ "PlPlotter", "structPlPlotter.html", "structPlPlotter" ],
     [ "PLRDev", "structPLRDev.html", "structPLRDev" ],
     [ "PLS", "classPLS.html", "classPLS" ],
-    [ "PLStream", "structPLStream.html", "structPLStream" ],
     [ "plstream", "classplstream.html", "classplstream" ],
+    [ "PLStream", "structPLStream.html", "structPLStream" ],
     [ "PLStrip", "structPLStrip.html", "structPLStrip" ],
     [ "PLWindow", "structPLWindow.html", "structPLWindow" ],
     [ "point", "structpoint.html", "structpoint" ],
@@ -116,11 +107,11 @@ var annotated =
     [ "swig_cast_info", "structswig__cast__info.html", "structswig__cast__info" ],
     [ "swig_const_info", "structswig__const__info.html", "structswig__const__info" ],
     [ "swig_globalvar", "structswig__globalvar.html", "structswig__globalvar" ],
-    [ "SWIG_JavaExceptions_t", "structSWIG__JavaExceptions__t.html", "structSWIG__JavaExceptions__t" ],
     [ "swig_lua_attribute", "structswig__lua__attribute.html", "structswig__lua__attribute" ],
     [ "swig_lua_class", "structswig__lua__class.html", "structswig__lua__class" ],
     [ "swig_lua_const_info", "structswig__lua__const__info.html", "structswig__lua__const__info" ],
     [ "swig_lua_method", "structswig__lua__method.html", "structswig__lua__method" ],
+    [ "swig_lua_namespace", "structswig__lua__namespace.html", "structswig__lua__namespace" ],
     [ "swig_lua_rawdata", "structswig__lua__rawdata.html", "structswig__lua__rawdata" ],
     [ "swig_lua_userdata", "structswig__lua__userdata.html", "structswig__lua__userdata" ],
     [ "swig_lua_var_info", "structswig__lua__var__info.html", "structswig__lua__var__info" ],
@@ -136,6 +127,7 @@ var annotated =
     [ "tclMatrix", "structtclMatrix.html", "structtclMatrix" ],
     [ "tclMatrixXtnsnDescr", "structtclMatrixXtnsnDescr.html", "structtclMatrixXtnsnDescr" ],
     [ "TextObjectsChanger", "classTextObjectsChanger.html", "classTextObjectsChanger" ],
+    [ "TextObjectsSaver", "classTextObjectsSaver.html", "classTextObjectsSaver" ],
     [ "TextSizeInfo", "structTextSizeInfo.html", "structTextSizeInfo" ],
     [ "TkDev", "structTkDev.html", "structTkDev" ],
     [ "TkwDev", "structTkwDev.html", "structTkwDev" ],
