@@ -6,7 +6,7 @@ var classwxPLDevice =
     [ "ClearBackground", "classwxPLDevice.html#adf773b89cce422a8993cff532d1468b5", null ],
     [ "DrawLine", "classwxPLDevice.html#a024a6ab0b2b388e6cf576f19eb570012", null ],
     [ "DrawPolyline", "classwxPLDevice.html#a01db4914fcf1edabcc2e4bb0ccbe4771", null ],
-    [ "DrawTextSection", "classwxPLDevice.html#abc5f3cbb3309bb9edf754a38a6449fe6", null ],
+    [ "DrawTextSection", "classwxPLDevice.html#a51cbc96777fc3bb31e30de2c69843e6f", null ],
     [ "EndPage", "classwxPLDevice.html#a250d52287ba56f7ef6ae846622c71cd0", null ],
     [ "FillPolygon", "classwxPLDevice.html#afc705b073a3c6a8225eea0fd2a2ae2a2", null ],
     [ "FixAspectRatio", "classwxPLDevice.html#a4a4d4eab36f783ab13503a8f8ac23a4c", null ],
@@ -36,10 +36,6 @@ var classwxPLDevice =
     [ "m_outputMemoryMap", "classwxPLDevice.html#a5733188555ab4b717a512acdd5747e57", null ],
     [ "m_pen", "classwxPLDevice.html#a0079d66c3f5542e7a79624e12ce8e71c", null ],
     [ "m_plplotEdgeLength", "classwxPLDevice.html#ac572a6abcda3170a22d23452c7e1fca2", null ],
-    [ "m_prevSingleCharString", "classwxPLDevice.html#a8011085ebdb51ce0cd8883118abddbd8", null ],
-    [ "m_prevSingleCharStringDepth", "classwxPLDevice.html#a8b8093342019189974468e0de0613c32", null ],
-    [ "m_prevSingleCharStringHeight", "classwxPLDevice.html#a86093029f824890e931904a6aea05319", null ],
-    [ "m_prevSingleCharStringWidth", "classwxPLDevice.html#a246c1284577601ee6e2f7e2491bc11bd", null ],
     [ "m_scale", "classwxPLDevice.html#a50279c0d07a7533de040944191d18e95", null ],
     [ "m_useDcTextTransform", "classwxPLDevice.html#a096e5f08aa45dd8ea7fc4b71f41b69d1", null ],
     [ "m_width", "classwxPLDevice.html#a39aa02b295b77d9afe40b159405f13d8", null ],
