@@ -41,7 +41,7 @@ var files =
     [ "matrixInit.c", "matrixInit_8c.html", "matrixInit_8c" ],
     [ "mem.c", "mem_8c.html", null ],
     [ "metadefs.h", "metadefs_8h.html", "metadefs_8h" ],
-    [ "moc_qt_2CLBWPDUEWV5LU.cpp", "moc__qt__2CLBWPDUEWV5LU_8cpp.html", "moc__qt__2CLBWPDUEWV5LU_8cpp" ],
+    [ "moc_qt.cpp", "moc__qt_8cpp.html", "moc__qt_8cpp" ],
     [ "mt19937ar.c", "mt19937ar_8c.html", "mt19937ar_8c" ],
     [ "mt19937ar.h", "mt19937ar_8h.html", "mt19937ar_8h" ],
     [ "csa/nan.h", "csa_2nan_8h.html", "csa_2nan_8h" ],
@@ -198,10 +198,9 @@ var files =
       [ "plgetcursor", "interfaceplplot__graphics_1_1plgetcursor.html", "interfaceplplot__graphics_1_1plgetcursor" ],
       [ "plplot_private_exposed", "classplplot__private__exposed.html", "classplplot__private__exposed" ]
     ] ],
-    [ "plplot_widgetmodule.c", "plplot__widgetmodule_8c.html", "plplot__widgetmodule_8c" ],
     [ "plplotc.py", "plplotc_8py.html", "plplotc_8py" ],
     [ "plplotc_fixed.py", "plplotc__fixed_8py.html", "plplotc__fixed_8py" ],
-    [ "plplotcmodulePYTHON_wrap.c", "plplotcmodulePYTHON__wrap_8c.html", "plplotcmodulePYTHON__wrap_8c" ],
+    [ "plplotcPYTHON_wrap.c", "plplotcPYTHON__wrap_8c.html", "plplotcPYTHON__wrap_8c" ],
     [ "plplotluacLUA_wrap.c", "plplotluacLUA__wrap_8c.html", "plplotluacLUA__wrap_8c" ],
     [ "plplotP.h", "plplotP_8h.html", "plplotP_8h" ],
     [ "plplotqt_automoc.cpp", "plplotqt__automoc_8cpp.html", null ],
@@ -271,6 +270,7 @@ var files =
     [ "csa/version.h", "csa_2version_8h.html", "csa_2version_8h" ],
     [ "nn/version.h", "nn_2version_8h.html", "nn_2version_8h" ],
     [ "wingcc.c", "wingcc_8c.html", "wingcc_8c" ],
+    [ "wingdi.c", "wingdi_8c.html", "wingdi_8c" ],
     [ "wxPLplot_nanosec.cpp", "wxPLplot__nanosec_8cpp.html", null ],
     [ "wxPLplot_nanosec.h", "wxPLplot__nanosec_8h.html", "wxPLplot__nanosec_8h" ],
     [ "wxPLplotstream.cpp", "wxPLplotstream_8cpp.html", null ],
