@@ -39,45 +39,45 @@ var NAVTREE =
 var NAVTREEINDEX =
 [
 "Plplotter__Init_8c.html",
-"cd_8h.html#acda6912c19c2eb65c3d37031ee115844",
-"classoctave__swig__ref.html#a09c386829786d99a3e98a302907a4af2",
-"classplplot.html#a70f3c1ac3250c861cca7f6c9db9f2ad3",
-"classplstream.html#a115a82090b4005cba6c4603e3db014fe",
-"classwxPLDevice.html#a86093029f824890e931904a6aea05319",
-"drivers_8h.html#a3356f1609c863412f0ef0c9519249011",
-"globals_vars_y.html",
-"ltdl__win32_8h.html#a2b4aade23de5404819ba28542e1ece8a",
-"ntk_8c.html#a404b3535fdd386e5d96b157652b7b559",
-"plargs_8c.html#ad4432c090465deb00ff4bbe564245822",
-"plcore_8c.html#aca45ddfcca5aed11ab19be6911e4ebc1",
-"plevent_8h.html#a43a862fc778964aee8a84ab23bccc453",
-"plframe_8c.html#abebd7ec681497127fc6ea9ce684d65f8",
-"plot3d_8c.html#af6dfaf4bf98f307129151a4fd29a1764",
-"plplot_8d.html#a0d57569295ec0852f57d72c33d9c6c5f",
-"plplot_8d.html#aec97625786c16fb8de98d167bc88f44d",
-"plplot_8h.html#a56a2e7aff93cc40a833762f13d95e5a1",
-"plplot_8h.html#ac40cfbf950fe5727d3de6d31abc6c189",
-"plplot__impl_8c.html#a5863eb3a4fa34fdb0b247c44c2266808",
-"plplot__octaveOCTAVE__wrap_8cxx.html#a4f6f5e0444e44e48aef51f6620438a5f",
-"plplot__octaveOCTAVE__wrap_8cxx.html#aa974c1ed408faed8f0c2d36ccceb45bd",
-"plplotc_8py.html#a0277fab4399d9fd6f0fe282e0a590673",
-"plplotc_8py.html#ab1b848a62c75c8f0e27275b06138042c",
-"plplotc__fixed_8py.html#a52342f55be732d38cf0dd7f662ae01fe",
-"plplotcmodulePYTHON__wrap_8c.html#a01ff9379ead152cc27db42716b5aed9f",
-"plplotcmodulePYTHON__wrap_8c.html#a727eb104e49fa97ed1f193341009bc41",
-"plplotcmodulePYTHON__wrap_8c.html#ae0178153199e3020e8d586e0e50fc796",
-"plplotluacLUA__wrap_8c.html#a6f3c8e1ef48fe42610667adde377998f",
-"plplotluacLUA__wrap_8c.html#af6a25edb9ad2ab838e1b1fa3e4450121",
-"plstream_8h.html#af38a775b953a654b78d0f13cf899f38ba556650aa9f007ea0239e66d3ddf26759",
-"qsastime_8c.html#a782cabb15675eec0cb0b3e5b6f7fe15e",
-"structPLGraphicsIn.html#a21b1933fd85acc870381e8a8a176b259",
-"structPLStream.html#ab648c79121e511ce3fc6be88b8de9c23",
-"structPlFrame.html#aceaba949a67a76f868e08ae274b44949",
-"struct__state.html#a855b9fc8275e51f42ca108dc6b69a28d",
-"structplplot_1_1__N5.html#aef93c76a75ca48e587e1aaf0b3052fab",
-"tclAPI_8c.html#a04f3effbd8fc6a0e7671a5e2c5f69c74",
-"tclgen_8c.html#aa6b28a14562408b80c57913e011d686f",
-"wxPLplot__nanosec_8h_source.html"
+"cd_8h.html#ace99280dbd0715eb87b76f35b7d64c99",
+"classoctave__swig__ref.html",
+"classplplot.html#a7062ed1a9200c24101abce45a09fd72b",
+"classplstream.html#a1111f25bd8672650778425691a7f80d9",
+"classwxPLDevice.html#a85773a83ecd9f7ff2e2cdd847c537939",
+"drivers_8h.html#a372b75bf2e0b7b185b0ef44933b1e730",
+"globals_vars_z.html",
+"ltdl__win32_8h.html#a370a898974725d2b8d1e1027a30700c7",
+"ntk_8c_source.html",
+"plargs_8c.html#ad76fd4c382be3094b2aa225d1d8552ba",
+"plcore_8c.html#acb67a49f12188daff82a2ec48978d2df",
+"plevent_8h.html#a4a2d4af34170127e3830590db203a846",
+"plframe_8c.html#acb0c89e8571d17240740df533902e7da",
+"plot3d_8c.html#afa1271b789bc05f8f06f25f16d65a18f",
+"plplot_8d.html#a0f2171cbf0a6f0b1388f6d0172d63046",
+"plplot_8d.html#aed4d8d7bc69de498a92b4c8f305e1ecc",
+"plplot_8h.html#a58a4cf16afb401d8c65f944770c53d49",
+"plplot_8h.html#ac55bfe409e42314412f2a130595610c7",
+"plplot__impl_8c.html#a5cd37f11a0ca219e9335f5ba15b8b6fe",
+"plplot__octaveOCTAVE__wrap_8cxx.html#a4f79c306c74e28a67f0747668430f6ce",
+"plplot__octaveOCTAVE__wrap_8cxx.html#aaad920dfbe901f64939bb9ac90368861",
+"plplotcPYTHON__wrap_8c.html#a0527a8d1f182f20b212bfae51a40e812",
+"plplotcPYTHON__wrap_8c.html#a73671bbcb7aaa4b6221c5df016c52d7f",
+"plplotcPYTHON__wrap_8c.html#ae4cc0f5599402526dd5c2fdb80d87517",
+"plplotc_8py.html#a8aa8ffa99953ead9bfb1f6325278ffac",
+"plplotc__fixed_8py.html#a2db0c2ffb9faaf9f1fa88bc8c1a404cf",
+"plplotc__fixed_8py.html#ad1131b860a499d68f1c0d8160a06948f",
+"plplotluacLUA__wrap_8c.html#a712321d8f9a62e655c27a0c6dc6792c0",
+"plplotluacLUA__wrap_8c.html#af903e6809a1fb2ba06deff49795c6e65",
+"plstream_8h.html#af38a775b953a654b78d0f13cf899f38bad0784a3f969fe736e8b271a5a161d106",
+"qsastime_8c.html#abd41112517c181424c476bd0469ac728",
+"structPLGraphicsIn.html#aa49f4f9952d4d5b8ccc36544dc7feebe",
+"structPLStream.html#ab9e36ad9df32802d429079a114dfecfc",
+"structPlFrame.html#ae6cd88baa34aa30ef958d96c5a399336",
+"structarc__struct.html#a239e57f45d87b43b53584fff68d9d995",
+"structplplot_1_1__N7.html#a2b877746e25cd16bf78c97598e07a9cd",
+"tclAPI_8c.html#a0a549425032c27fb11723dffdf716276",
+"tclgen_8c.html#ab49bf424ef5f10a14aad8dae75f91d39",
+"wxPLplotstream_8h.html#a99fb83031ce9923c84392b4e92f956b5a377186d2b88dd9178e5b6da729d6647b"
 ];
 
 var SYNCONMSG = 'click to disable panel synchronisation';
