@@ -1,6 +1,5 @@
 var NAVTREEINDEX19 =
 {
-"plplot__impl_8c.html#a5863eb3a4fa34fdb0b247c44c2266808":[2,0,98,3],
 "plplot__impl_8c.html#a5cd37f11a0ca219e9335f5ba15b8b6fe":[2,0,98,22],
 "plplot__impl_8c.html#a5f2e6fa4f35c8a5d1b9a9ae5a37c9e56":[2,0,98,39],
 "plplot__impl_8c.html#a603e82ba9c5ea6b5c1bc56dd0ff2b38a":[2,0,98,32],
@@ -249,5 +248,6 @@ var NAVTREEINDEX19 =
 "plplot__octaveOCTAVE__wrap_8cxx.html#a4ce59043e4908e9d399c4ce3063db487":[2,0,99,313],
 "plplot__octaveOCTAVE__wrap_8cxx.html#a4e4f2ee94e2f3ac59f9643125c446d83":[2,0,99,415],
 "plplot__octaveOCTAVE__wrap_8cxx.html#a4ea42eb5effb1db6292c0a7dacad5406":[2,0,99,381],
-"plplot__octaveOCTAVE__wrap_8cxx.html#a4f2bcefca98606b5697148b740127ce6":[2,0,99,545]
+"plplot__octaveOCTAVE__wrap_8cxx.html#a4f2bcefca98606b5697148b740127ce6":[2,0,99,545],
+"plplot__octaveOCTAVE__wrap_8cxx.html#a4f6f5e0444e44e48aef51f6620438a5f":[2,0,99,16]
 };
