@@ -1,5 +1,7 @@
 var NAVTREEINDEX2 =
 {
+"classoctave__swig__ref.html":[1,0,48],
+"classoctave__swig__ref.html#a0129a73ac6adc93b6f1c8bf5f653ce37":[1,0,48,19],
 "classoctave__swig__ref.html#a09c386829786d99a3e98a302907a4af2":[1,0,48,7],
 "classoctave__swig__ref.html#a0df5005486aa7a79f8bc1467954cd229":[1,0,48,18],
 "classoctave__swig__ref.html#a3017b71afa22c1f8c17014b6cb1343d1":[1,0,48,20],
@@ -247,7 +249,5 @@ var NAVTREEINDEX2 =
 "classplplot.html#a6e2bbc3ec109f773d0b9d6ff6c6c4110":[1,0,79,197],
 "classplplot.html#a6eab4aca6ab601078b3922e67321e405":[1,0,79,252],
 "classplplot.html#a6f5b48bed581eda8e674fde4eb0661d9":[1,0,79,215],
-"classplplot.html#a7037fdfc9842c5eedd62fbc94d565b87":[1,0,79,117],
-"classplplot.html#a7062ed1a9200c24101abce45a09fd72b":[1,0,79,102],
-"classplplot.html#a707227bacf7694b6ab3161ea9ce6e1d2":[1,0,79,390]
+"classplplot.html#a7037fdfc9842c5eedd62fbc94d565b87":[1,0,79,117]
 };
