@@ -1,6 +1,5 @@
 var NAVTREEINDEX21 =
 {
-"plplot__octaveOCTAVE__wrap_8cxx.html#aa974c1ed408faed8f0c2d36ccceb45bd":[2,0,99,158],
 "plplot__octaveOCTAVE__wrap_8cxx.html#aaad920dfbe901f64939bb9ac90368861":[2,0,99,401],
 "plplot__octaveOCTAVE__wrap_8cxx.html#aab2f1993f97bd27040adf9836dafff18":[2,0,99,56],
 "plplot__octaveOCTAVE__wrap_8cxx.html#aad280f1c356f1ba8b14a91a4c1200cca":[2,0,99,177],
@@ -239,15 +238,16 @@ var NAVTREEINDEX21 =
 "plplot__single_8f90_source.html":[2,0,101],
 "plplot__small__modules_8f90.html":[2,0,102],
 "plplot__small__modules_8f90_source.html":[2,0,102],
-"plplot__widgetmodule_8c.html":[2,0,103],
-"plplot__widgetmodule_8c.html#a18c528d058ef76e80f11e719370a1a88":[2,0,103,2],
-"plplot__widgetmodule_8c.html#a91666925fff3e80ea47304f2bdd9b2b8":[2,0,103,3],
-"plplot__widgetmodule_8c.html#a9e22e0e889a104e52ed38cccd08aa4d2":[2,0,103,1],
-"plplot__widgetmodule_8c.html#ab6e6ee86736f9ebb56e74ae21bf3ff8a":[2,0,103,0],
-"plplot__widgetmodule_8c_source.html":[2,0,103],
-"plplotc_8py.html":[2,0,104],
-"plplotc_8py.html#a005e373d6b6e1eccf18123558b17f263":[2,0,104,126],
-"plplotc_8py.html#a00cc4c7170501708af758b576e756ebd":[2,0,104,203],
-"plplotc_8py.html#a0161658227f3be0036ce2be29b831977":[2,0,104,328],
-"plplotc_8py.html#a024bb3fc79b423e4157bfff0bd14a3b3":[2,0,104,124]
+"plplotcPYTHON__wrap_8c.html":[2,0,105],
+"plplotcPYTHON__wrap_8c.html#a0021b435c31c3ab285b5a6f4547719e3":[2,0,105,85],
+"plplotcPYTHON__wrap_8c.html#a00275cc63b33b60eaa342cf144dc6215":[2,0,105,332],
+"plplotcPYTHON__wrap_8c.html#a00a2aa9762204b8a6a82fb5b1e0ef24c":[2,0,105,471],
+"plplotcPYTHON__wrap_8c.html#a01b485cfacae7d870729eea43fb17cb0":[2,0,105,62],
+"plplotcPYTHON__wrap_8c.html#a01ff9379ead152cc27db42716b5aed9f":[2,0,105,38],
+"plplotcPYTHON__wrap_8c.html#a02a0d646b3eb8c7dd6d4ce41718ce04a":[2,0,105,245],
+"plplotcPYTHON__wrap_8c.html#a02c2ac3db8ce87dd62813334e66c9a3a":[2,0,105,432],
+"plplotcPYTHON__wrap_8c.html#a035fe8189afe879b5954fb172f86f1c4":[2,0,105,195],
+"plplotcPYTHON__wrap_8c.html#a03b3793a4bd02ab2e9dda57331f4b5f3":[2,0,105,447],
+"plplotcPYTHON__wrap_8c.html#a04346a912e109a81b6a1a184e988937f":[2,0,105,303],
+"plplotcPYTHON__wrap_8c.html#a0521a528b9a320ebc6e09b5e7039c333":[2,0,105,372]
 };
