@@ -1,5 +1,7 @@
 var NAVTREEINDEX3 =
 {
+"classplplot.html#a7062ed1a9200c24101abce45a09fd72b":[1,0,79,102],
+"classplplot.html#a707227bacf7694b6ab3161ea9ce6e1d2":[1,0,79,390],
 "classplplot.html#a70f3c1ac3250c861cca7f6c9db9f2ad3":[1,0,79,118],
 "classplplot.html#a714a6de0bc30ecca7c16eb3cb57a8705":[1,0,79,302],
 "classplplot.html#a72f5ce4b770385225aad8c0b76efa39c":[1,0,79,374],
@@ -247,7 +249,5 @@ var NAVTREEINDEX3 =
 "classplstream.html#a04f0cb933006bf6700acf8bcab2f2658":[1,0,89,190],
 "classplstream.html#a0aed09ebde7556077e59ecba2af1b2a8":[1,0,89,20],
 "classplstream.html#a0b65ab13455c59f457f3037eb08cbbe1":[1,0,89,1],
-"classplstream.html#a0fd06540f1adbd4cf74108daa1473e7e":[1,0,89,187],
-"classplstream.html#a1111f25bd8672650778425691a7f80d9":[1,0,89,165],
-"classplstream.html#a11207900db18a5701868fdce0442856a":[1,0,89,43]
+"classplstream.html#a0fd06540f1adbd4cf74108daa1473e7e":[1,0,89,187]
 };
