@@ -1,12 +1,5 @@
 var NAVTREEINDEX32 =
 {
-"structPLGraphicsIn.html#a21b1933fd85acc870381e8a8a176b259":[1,0,69,5],
-"structPLGraphicsIn.html#a5b265dd393e9731157ecf8bc421bc479":[1,0,69,10],
-"structPLGraphicsIn.html#a5d79945d06cba50e5e44cc62543312f3":[1,0,69,11],
-"structPLGraphicsIn.html#a65a7c2ad35465fdda2da1cdad78c6fed":[1,0,69,4],
-"structPLGraphicsIn.html#a8579e8d68cc7249bd8959ba7eef221dd":[1,0,69,9],
-"structPLGraphicsIn.html#a87ee773ac5a20f2989f4a4a193750fe4":[1,0,69,8],
-"structPLGraphicsIn.html#a90a08dfcb5e486ac4ce34507a6004c11":[1,0,69,2],
 "structPLGraphicsIn.html#aa49f4f9952d4d5b8ccc36544dc7feebe":[1,0,69,6],
 "structPLGraphicsIn.html#ad70616982f7224261873697c93e48ee4":[1,0,69,3],
 "structPLGraphicsIn.html#ae15d582003fed123c0d48d422bffd144":[1,0,69,1],
@@ -21,12 +14,12 @@ var NAVTREEINDEX32 =
 "structPLOptionInfo.html#ac590f78a71f825d37f24e10f7ec443d9":[1,0,77,0],
 "structPLOptionTable.html":[1,0,78],
 "structPLOptionTable.html#a594f71ef71580c5b5a91d2e6771fcd97":[1,0,78,1],
+"structPLOptionTable.html#a6046671ce05cea570f5eda5e64d84b55":[1,0,78,2],
 "structPLOptionTable.html#a813692b51c558740a63d3903bb226470":[1,0,78,3],
 "structPLOptionTable.html#a9f6233441172fbe3198bfec5f8d25fc1":[1,0,78,4],
 "structPLOptionTable.html#aa1560d1a020b8488f6669b33fe5d845e":[1,0,78,5],
-"structPLOptionTable.html#ab571e3a60f52f54c3b946464fbf65213":[1,0,78,0],
-"structPLOptionTable.html#ae11c220f9d7cce15ccbd271f3ddf8e8f":[1,0,78,6],
-"structPLOptionTable.html#ae45b61c133c0931d2a6dd743d9336b8d":[1,0,78,2],
+"structPLOptionTable.html#abf2b587b8340cfa0b00349b02dd62aa7":[1,0,78,0],
+"structPLOptionTable.html#abf69bb97e4cf52fbae8335e0b7ee524f":[1,0,78,6],
 "structPLRDev.html":[1,0,87],
 "structPLRDev.html#a18b078383daba6f7399d73aa5b2a8433":[1,0,87,1],
 "structPLRDev.html#a1b93a8aba2e97f23d7b031a5a224baed":[1,0,87,8],
@@ -249,5 +242,12 @@ var NAVTREEINDEX32 =
 "structPLStream.html#ab4124f5acbd397314da02d08f6e29174":[1,0,90,280],
 "structPLStream.html#ab459504b6e9f6bb01e8a4f20dafb1a3b":[1,0,90,119],
 "structPLStream.html#ab486e5550932eed05f4d67642acfb322":[1,0,90,204],
-"structPLStream.html#ab566a389669a6fee28c910633ddd1bbc":[1,0,90,251]
+"structPLStream.html#ab566a389669a6fee28c910633ddd1bbc":[1,0,90,251],
+"structPLStream.html#ab648c79121e511ce3fc6be88b8de9c23":[1,0,90,269],
+"structPLStream.html#ab6a87dc559f780569957bdd96f586e2e":[1,0,90,198],
+"structPLStream.html#ab74c69a6d7c33eac59b640e18607c2ba":[1,0,90,206],
+"structPLStream.html#ab85067bdc3a57afc4a2d3232eebf3b82":[1,0,90,83],
+"structPLStream.html#ab8a4ab4b5ce5ed5892455da26b638af3":[1,0,90,196],
+"structPLStream.html#ab8ac2cfcc7c89b3cb21006ec7090a73b":[1,0,90,176],
+"structPLStream.html#ab992021872cb743f34265ca2bd9388eb":[1,0,90,77]
 };
