@@ -45,10 +45,23 @@ var plplotP_8h =
     [ "PLDI_PLT", "plplotP_8h.html#ae0216a36024534929c94ff732870ff90", null ],
     [ "PLPLOT5_FONTS", "plplotP_8h.html#adddbf64c5ed632bfd3883b110cdf8fef", null ],
     [ "PLPLOT_BIN_ENV", "plplotP_8h.html#ac03c79ca8cd54fb9e7509706e7e68f0d", null ],
+    [ "PLPLOT_DEFAULT_HEIGHT_MM", "plplotP_8h.html#ab2ace681fb9b3b392cba0f18bbe66071", null ],
+    [ "PLPLOT_DEFAULT_HEIGHT_PIXELS", "plplotP_8h.html#a9e67a9eef9de5dc820c06f92a4f344b1", null ],
+    [ "PLPLOT_DEFAULT_HEIGHT_POINTS", "plplotP_8h.html#a826fd901df2855ac98c9b33ec0b57fe3", null ],
+    [ "PLPLOT_DEFAULT_PIXELS_PER_INCH", "plplotP_8h.html#ac3e74dd5ad2cabab8fe4652c29b6512b", null ],
+    [ "PLPLOT_DEFAULT_WIDTH_MM", "plplotP_8h.html#a1d6d7570fcd62267241708091023650e", null ],
+    [ "PLPLOT_DEFAULT_WIDTH_PIXELS", "plplotP_8h.html#a91cb3228499847af3a270c7b6ad19eb7", null ],
+    [ "PLPLOT_DEFAULT_WIDTH_POINTS", "plplotP_8h.html#a7fcdda9368b70cb7ca54f5a74efe16c5", null ],
+    [ "PLPLOT_HEIGHT_A4_MM", "plplotP_8h.html#a90709d034193dd5dfdbdedcc8d393b54", null ],
+    [ "PLPLOT_HEIGHT_A5_MM", "plplotP_8h.html#a52ca90477cd17bcfc5315377db003d83", null ],
     [ "PLPLOT_HOME_ENV", "plplotP_8h.html#aa75c95ff00e85a94e00607777d07cae9", null ],
     [ "PLPLOT_LIB_ENV", "plplotP_8h.html#a4d712860a546e16091b8bfa9b6fb355f", null ],
     [ "PLPLOT_MAX_PATH", "plplotP_8h.html#a0b360f193f449275cbdc9b36a756dd6c", null ],
+    [ "PLPLOT_MM_PER_INCH", "plplotP_8h.html#a3e57d03a5161d56776f4b8cbdd8532cc", null ],
+    [ "PLPLOT_POINTS_PER_INCH", "plplotP_8h.html#a49a32722e9dcc0e01c3b3faee3ed082e", null ],
     [ "PLPLOT_TCL_ENV", "plplotP_8h.html#a7ec795052c6fe6de491ff626aae9a09b", null ],
+    [ "PLPLOT_WIDTH_A4_MM", "plplotP_8h.html#a1e5f5dadc703e4a5c36491aab7ef692a", null ],
+    [ "PLPLOT_WIDTH_A5_MM", "plplotP_8h.html#a9401bef8aac9d41473ed40dbf9878bce", null ],
     [ "plsetvar", "plplotP_8h.html#a4eeb27aac45f99ad72cc6da3115a587d", null ],
     [ "PLSTATE_CHR", "plplotP_8h.html#a466c3c0c53d46b141b3c1f4d46bc3456", null ],
     [ "PLSTATE_CMAP0", "plplotP_8h.html#a8d2bf416c54687c37054904f985fb13f", null ],
@@ -73,23 +86,23 @@ var plplotP_8h =
     [ "DRV_FLT", "plplotP_8h.html#adc29c2ff13d900c2f185ee95427fb06ca003e5f646837605b279c4a3e21a9e55d", null ],
     [ "DRV_STR", "plplotP_8h.html#adc29c2ff13d900c2f185ee95427fb06cac8cb0d9ed936be241f5a8d60e42056c2", null ],
     [ "cont_clean_store", "plplotP_8h.html#a1369d4790c599d92559808545b63f01d", null ],
-    [ "cont_store", "plplotP_8h.html#a5c250a2c0325c94b33910e242fb38b89", null ],
+    [ "cont_store", "plplotP_8h.html#ab31ef38f5bb56843df09bf42078665c5", null ],
     [ "difilt", "plplotP_8h.html#aeb14106a80979de5e9f0db61b38bbc11", null ],
     [ "difilt_clip", "plplotP_8h.html#a123456aef2077b98710c1945cc423716", null ],
     [ "grimage", "plplotP_8h.html#a3bb953b941f306756707370648093b64", null ],
-    [ "label_box_custom", "plplotP_8h.html#a0e709b305271c726e295fc3fe4c890ac", null ],
+    [ "label_box_custom", "plplotP_8h.html#abf89e2f3c6586e8f65a7cb9e03bc90ce", null ],
     [ "NoBufferNoPixmap", "plplotP_8h.html#a9b62a55b84cec4a17aedb04d620d46e0", null ],
     [ "pl_cpcolor", "plplotP_8h.html#a5a5a672a2b2a3513da5ca0e32209ad48", null ],
     [ "pl_create_tempfifo", "plplotP_8h.html#ad62d6a4c9eb019d77c1cec8d2d34f28a", null ],
     [ "pl_create_tempfile", "plplotP_8h.html#a3f8f961cbdb66cefd44f853e3f0895cc", null ],
     [ "pl_exit", "plplotP_8h.html#a2d4687ec27d861f778294d9473a169d8", null ],
-    [ "plabort", "plplotP_8h.html#a3ab9bb1abe23785b23022b98f5a58ae1", null ],
+    [ "plabort", "plplotP_8h.html#a35e0eff00813c22036a1c2d038d212f5", null ],
     [ "plcmap1_calc", "plplotP_8h.html#ae8a97df76143950564dfcd3816e3fd20", null ],
     [ "PLDLLIMPEXP_DATA", "plplotP_8h.html#a9343f56b51401cd1fecbf729753112aa", null ],
     [ "pldprec", "plplotP_8h.html#a65787139fccaa926cb497446f1701912", null ],
     [ "pldtfac", "plplotP_8h.html#ab3f8597dcfd3994254ba9865decdb5af", null ],
     [ "pldtik", "plplotP_8h.html#a04f05748c5a4733a92b2595887c0082e", null ],
-    [ "plexit", "plplotP_8h.html#a9d4e2a466d6d360ffca7d871c0ff2b48", null ],
+    [ "plexit", "plplotP_8h.html#aca11cb4ac20a3feefd2d3408364310a5", null ],
     [ "plfill_soft", "plplotP_8h.html#ae4bcd3646ea1389b8f8f94d18f07e2fe", null ],
     [ "plfntld", "plplotP_8h.html#a24d750074d86147f34da1f107a1f88b1", null ],
     [ "plfontrel", "plplotP_8h.html#a87c8e3d2000c939fffb6d7d06ec52d21", null ],
@@ -104,9 +117,9 @@ var plplotP_8h =
     [ "plio_fwrite", "plplotP_8h.html#a1fd36c5dcb538d9f95c23d915f74fe1f", null ],
     [ "pllib_devinit", "plplotP_8h.html#a77a3382e0b51b2f438452e022bd4cbad", null ],
     [ "pllib_init", "plplotP_8h.html#a53902ab4f12b8699f46aa8c11c8689fc", null ],
-    [ "plLibOpen", "plplotP_8h.html#abd31f8ce411afef4dd5168a5cffbe2ab", null ],
+    [ "plLibOpen", "plplotP_8h.html#a31d17dbc1aca95422473dbf4d4534a59", null ],
     [ "plP_affine_identity", "plplotP_8h.html#aae582b02f77fb4be7d2f205862549f41", null ],
-    [ "plP_affine_multiply", "plplotP_8h.html#a0039cbd058977d15c05383b9d3c061ac", null ],
+    [ "plP_affine_multiply", "plplotP_8h.html#a48f15224c33dd13fecd8f4b7ca30be92", null ],
     [ "plP_affine_rotate", "plplotP_8h.html#a65e3c05e7d5fd74e2f224b70bb721c4c", null ],
     [ "plP_affine_scale", "plplotP_8h.html#ab5487c077d6a2e96424a01873afcc6ae", null ],
     [ "plP_affine_translate", "plplotP_8h.html#aca2df0605b6a1cab6395a5031dd88f75", null ],
@@ -125,7 +138,7 @@ var plplotP_8h =
     [ "plP_draphy", "plplotP_8h.html#afcf4a0fbaee4a71e704e03070501221b", null ],
     [ "plP_draphy_poly", "plplotP_8h.html#ad7659fc7e58a8dd05c41e6feccefb04a", null ],
     [ "plP_drawor", "plplotP_8h.html#a1f1ed49c980af9b6cd533f1a3acd799e", null ],
-    [ "plP_drawor_poly", "plplotP_8h.html#ab713a044323595975c99c2e4f5b9d2c9", null ],
+    [ "plP_drawor_poly", "plplotP_8h.html#a540ad13e35c747691393411baecf348c", null ],
     [ "plP_eop", "plplotP_8h.html#ab1e5007b5ce8c229f1ef969c3fbee0e7", null ],
     [ "plP_esc", "plplotP_8h.html#ad2f35ac89cd851e9db2f1eea32f9a799", null ],
     [ "plP_FCI2FontName", "plplotP_8h.html#a94bbf5280fb83c06d1692c43a2452c0f", null ],
@@ -158,7 +171,7 @@ var plplotP_8h =
     [ "plP_pcdcy", "plplotP_8h.html#a7be79974555917c614d252126ced3c20", null ],
     [ "plP_plfclp", "plplotP_8h.html#a0531fd7924d4b2e9c2570f6ec7aeb507", null ],
     [ "plP_pllclp", "plplotP_8h.html#a4f34e7e8f5427783cb8fc89d460a3ec5", null ],
-    [ "plP_pointinpolygon", "plplotP_8h.html#abf208193c7378e3443fbcb5a39d00ed0", null ],
+    [ "plP_pointinpolygon", "plplotP_8h.html#ae5bc736692ac9c73764b7eb6585cf97a", null ],
     [ "plP_polyline", "plplotP_8h.html#a1aba6c2de9e2d7f7e74589b909e20a49", null ],
     [ "plP_scdcx", "plplotP_8h.html#a25b8ea175a717e1e9bb83b3478df41db", null ],
     [ "plP_scdcy", "plplotP_8h.html#a8f9e4adf283a1979c12e5cf885510a0e", null ],
@@ -169,12 +182,12 @@ var plplotP_8h =
     [ "plP_setsub", "plplotP_8h.html#a117b8b993c854bc0e2f68c1f3483201c", null ],
     [ "plP_ssub", "plplotP_8h.html#a1f7cb220888fd00e4aa6b33a499dee8c", null ],
     [ "plP_state", "plplotP_8h.html#af52a8d24cb23cb455d10983c18cbf6e0", null ],
-    [ "plP_stindex", "plplotP_8h.html#a2d8fe21fcd4b5ed36d6df4bad0a1fcf2", null ],
-    [ "plP_strpos", "plplotP_8h.html#a3cf65d12d585fd791e04b194fbc561a7", null ],
-    [ "plP_stsearch", "plplotP_8h.html#a8fb44d9b31d584b137579190e8357586", null ],
+    [ "plP_stindex", "plplotP_8h.html#a3f50d12313fafdb69940ee278cb5df29", null ],
+    [ "plP_strpos", "plplotP_8h.html#ae61bc6b9da780fda49b1754b59e161ac", null ],
+    [ "plP_stsearch", "plplotP_8h.html#ab8d5b382b940de087c67fd9c278dd285", null ],
     [ "plP_subpInit", "plplotP_8h.html#a60303902fa8f1b50e0e3711f41f7fadf", null ],
     [ "plP_swin", "plplotP_8h.html#a93ba5ed9e5f7401b4f489dbd6758c8aa", null ],
-    [ "plP_text", "plplotP_8h.html#a60f08ea02ac98641d98af649f4da10ae", null ],
+    [ "plP_text", "plplotP_8h.html#a2a160696d430297f433fe017de408b06", null ],
     [ "plP_tidy", "plplotP_8h.html#a58a3581c01cee21a43d2cceb63861cac", null ],
     [ "plP_w3wcx", "plplotP_8h.html#a7bdfc2321dda486d861347e121845c42", null ],
     [ "plP_w3wcy", "plplotP_8h.html#ad800713c5dc0e318c32fb6f40500ee20", null ],
@@ -192,14 +205,14 @@ var plplotP_8h =
     [ "plrestore_locale", "plplotP_8h.html#a774dd4dd367a4c8695730246cbfffef4", null ],
     [ "plRotationShear", "plplotP_8h.html#aaeeeedfb840b832ab1fee2b55ac1591a", null ],
     [ "plsave_set_locale", "plplotP_8h.html#a43d4c825760173fd9980f840ff3b4683", null ],
-    [ "plsnprintf", "plplotP_8h.html#a8f90316f6de25fec7609ee1dc408a55c", null ],
-    [ "plsnscanf", "plplotP_8h.html#af78de27d9dc597e8c1f8eef0ffa2fb02", null ],
+    [ "plsnprintf", "plplotP_8h.html#a3e82cbc1c6f5f241088200eba4f3eb4c", null ],
+    [ "plsnscanf", "plplotP_8h.html#a83e193a36aa2ff36eeb3bac560b0fad2", null ],
     [ "plstik", "plplotP_8h.html#acc2c4d27dede240dfff47df0597413b7", null ],
-    [ "plstr", "plplotP_8h.html#a77329f5aeefe8c1d2a78f1dddce2536d", null ],
-    [ "plstrdup", "plplotP_8h.html#ab519926e133239952dc33fc59b1ff3c2", null ],
-    [ "plstrl", "plplotP_8h.html#a93ab6b4fd258ff4b3b26509a80d30ec2", null ],
+    [ "plstr", "plplotP_8h.html#a1ed2476ebb26f491f69b2a1530b3549a", null ],
+    [ "plstrdup", "plplotP_8h.html#a626af54723e59fc91744971f63f35942", null ],
+    [ "plstrl", "plplotP_8h.html#a7ca0093abd2c4969818b16c24bc69144", null ],
     [ "plstrm_init", "plplotP_8h.html#a659bd03250b8cee5bc6dd32d0e81a200", null ],
-    [ "plwarn", "plplotP_8h.html#aff58ab1fbda79ccc53366221987393b3", null ],
+    [ "plwarn", "plplotP_8h.html#a7b4834689ffbd72c3b9a9dd6bf782fe5", null ],
     [ "plwxtik", "plplotP_8h.html#ac1919aee4a3ac0ce8f8ce97fd353d224", null ],
     [ "plwytik", "plplotP_8h.html#a3cf0d579677a727ac4f3eccad1cecbc2", null ],
     [ "plxtik", "plplotP_8h.html#a47734cc23885611abbeee1807b648365", null ],
