@@ -10,12 +10,13 @@ var plplot__octaveOCTAVE__wrap_8cxx =
     [ "octave_swig_ref", "classoctave__swig__ref.html", "classoctave__swig__ref" ],
     [ "octave_swig_packed", "classoctave__swig__packed.html", "classoctave__swig__packed" ],
     [ "octave_value_ref", "structoctave__value__ref.html", "structoctave__value__ref" ],
-    [ "_SWIG_OCT_SEGF_HACK_ATEXIT_FCN", "plplot__octaveOCTAVE__wrap_8cxx.html#a8719d3fa039deb7869ac4efd6a027c60", null ],
     [ "ComplexLU", "plplot__octaveOCTAVE__wrap_8cxx.html#a3f7a7992e99f3131e9f40ef943a87dd8", null ],
     [ "f2c", "plplot__octaveOCTAVE__wrap_8cxx.html#a1ffa0c2ac3e8935b915b4c2abd3e52d8", null ],
-    [ "OCTAVE_API_VERSION_NUMBER", "plplot__octaveOCTAVE__wrap_8cxx.html#a1254fb4e5ab79f0fdb1edb9d6b387f58", null ],
     [ "Octave_Error_Occurred", "plplot__octaveOCTAVE__wrap_8cxx.html#aeef1c9b2220cc590521fe43f74bea0c9", null ],
-    [ "SWIG_AddCast", "plplot__octaveOCTAVE__wrap_8cxx.html#ad69473581dbf2292673b61e56b35d893", null ],
+    [ "OCTAVE_MAJOR_VERSION", "plplot__octaveOCTAVE__wrap_8cxx.html#a4c73d0aabc6ebc5d6eb334742dc8fd53", null ],
+    [ "OCTAVE_MINOR_VERSION", "plplot__octaveOCTAVE__wrap_8cxx.html#a3a009c79dc9971658b521413eb584f2a", null ],
+    [ "OCTAVE_PATCH_VERSION", "plplot__octaveOCTAVE__wrap_8cxx.html#a3a629625db506499fa1a95e5f0c427aa", null ],
+    [ "SWIG_AddCast", "plplot__octaveOCTAVE__wrap_8cxx.html#a4f6f5e0444e44e48aef51f6620438a5f", null ],
     [ "SWIG_AddNewMask", "plplot__octaveOCTAVE__wrap_8cxx.html#af7ac7e424b623712f70e9b6640a54853", null ],
     [ "SWIG_AddTmpMask", "plplot__octaveOCTAVE__wrap_8cxx.html#af8527f0123949ec90e05d0fb156c11e3", null ],
     [ "SWIG_arg_fail", "plplot__octaveOCTAVE__wrap_8cxx.html#a01ff9379ead152cc27db42716b5aed9f", null ],
@@ -62,10 +63,9 @@ var plplot__octaveOCTAVE__wrap_8cxx =
     [ "SWIG_NewPackedObj", "plplot__octaveOCTAVE__wrap_8cxx.html#ab6d4285e098e13c5797188b2cf77592e", null ],
     [ "SWIG_NewPointerObj", "plplot__octaveOCTAVE__wrap_8cxx.html#a978ff8eb5e32b08b8a1b8399c1994f23", null ],
     [ "SWIG_NullReferenceError", "plplot__octaveOCTAVE__wrap_8cxx.html#aa11fe417abd4c5a02d31cc1a51dee007", null ],
-    [ "SWIG_OCT_SEGF_HACK_ATEXIT_FCN", "plplot__octaveOCTAVE__wrap_8cxx.html#af69c96a84916a335ccaa5c9da0907208", null ],
     [ "SWIG_Octave_AddErrorMsg", "plplot__octaveOCTAVE__wrap_8cxx.html#a074b6a028433944b362f531ee7a7fa5f", null ],
     [ "SWIG_Octave_ConvertPtr", "plplot__octaveOCTAVE__wrap_8cxx.html#a059ec983f00a9ff600d30f35b72b1737", null ],
-    [ "SWIG_OCTAVE_SEGFAULT_HACK", "plplot__octaveOCTAVE__wrap_8cxx.html#acd3193daa93921681446ad58453da13f", null ],
+    [ "SWIG_OCTAVE_PREREQ", "plplot__octaveOCTAVE__wrap_8cxx.html#a448761d7811a0a61bd974332adf5ea77", null ],
     [ "SWIG_OK", "plplot__octaveOCTAVE__wrap_8cxx.html#af9ecbac56d4c5cd6104ae8f6bb82e9f7", null ],
     [ "SWIG_OLDOBJ", "plplot__octaveOCTAVE__wrap_8cxx.html#a4afcf490ff5b4abbca27ca23d9af288e", null ],
     [ "SWIG_op_prefix", "plplot__octaveOCTAVE__wrap_8cxx.html#a92d38f42f6f1e9aef0b57bd89a92d542", null ],
@@ -220,7 +220,7 @@ var plplot__octaveOCTAVE__wrap_8cxx =
     [ "swig_binary_op", "plplot__octaveOCTAVE__wrap_8cxx.html#affb66c4c6a1857f0af6a704c288ee6e2", null ],
     [ "SWIG_check_num_args", "plplot__octaveOCTAVE__wrap_8cxx.html#ac5984049b372c015bfe3abfbdb3d24a8", null ],
     [ "SWIG_DEFUN", "plplot__octaveOCTAVE__wrap_8cxx.html#a77a3f76cb1445325a013c2676f9c4581", null ],
-    [ "SWIG_DEFUN", "plplot__octaveOCTAVE__wrap_8cxx.html#a5734d9353408f1ae453b0385a02393e7", null ],
+    [ "SWIG_DEFUN", "plplot__octaveOCTAVE__wrap_8cxx.html#a4290153c5c7401fd21ec341976bb3e38", null ],
     [ "SWIG_DEFUN", "plplot__octaveOCTAVE__wrap_8cxx.html#ac3a0c15e37d0b3f465a844dee154db26", null ],
     [ "SWIG_DEFUN", "plplot__octaveOCTAVE__wrap_8cxx.html#a5f11455ff62681657ca4c57d9d96863f", null ],
     [ "SWIG_DEFUN", "plplot__octaveOCTAVE__wrap_8cxx.html#a2b39f891ef522830a1cf19b32de8e89a", null ],
@@ -237,7 +237,7 @@ var plplot__octaveOCTAVE__wrap_8cxx =
     [ "SWIG_DEFUN", "plplot__octaveOCTAVE__wrap_8cxx.html#a06472d4b7e3ec0c57dc9e705d0ef4ade", null ],
     [ "SWIG_DEFUN", "plplot__octaveOCTAVE__wrap_8cxx.html#abcff8cd901eedb5192c484c3eccb8421", null ],
     [ "SWIG_DEFUN", "plplot__octaveOCTAVE__wrap_8cxx.html#addc35e21a73364c0e426b888c5327fb9", null ],
-    [ "SWIG_DEFUN", "plplot__octaveOCTAVE__wrap_8cxx.html#a6e3bcd29255120af19fb2c33a1768c08", null ],
+    [ "SWIG_DEFUN", "plplot__octaveOCTAVE__wrap_8cxx.html#ada8de35086b729117ee1b08a09d92e78", null ],
     [ "SWIG_DEFUN", "plplot__octaveOCTAVE__wrap_8cxx.html#aba57b582a1c7d882bf7d933cdc6f7b8c", null ],
     [ "SWIG_DEFUN", "plplot__octaveOCTAVE__wrap_8cxx.html#a3149b3bca7f590c0b2a3362ab4a2c2ec", null ],
     [ "SWIG_DEFUN", "plplot__octaveOCTAVE__wrap_8cxx.html#a647965de63f19cb1852c4aa05b614cd4", null ],
@@ -443,23 +443,23 @@ var plplot__octaveOCTAVE__wrap_8cxx =
     [ "SWIG_From_unsigned_SS_int", "plplot__octaveOCTAVE__wrap_8cxx.html#affdef728dd1d3a1e6e233b1cc8ed7df1", null ],
     [ "SWIG_From_unsigned_SS_long", "plplot__octaveOCTAVE__wrap_8cxx.html#a846ff0c62d84b7501ba645b6c846c1e1", null ],
     [ "SWIG_FromCharPtrAndSize", "plplot__octaveOCTAVE__wrap_8cxx.html#a8c000dfd477fe68ba6bb164a3206152c", null ],
-    [ "SWIG_init_user", "plplot__octaveOCTAVE__wrap_8cxx.html#a29869e3a769ac2b104bd19850e78c345", null ],
+    [ "SWIG_init_user", "plplot__octaveOCTAVE__wrap_8cxx.html#af4d4ff2d9ab554bc1c31c09d6eb0bccd", null ],
     [ "SWIG_InitializeModule", "plplot__octaveOCTAVE__wrap_8cxx.html#a7f8da48fe4dbc23aef01a714623b8a6b", null ],
     [ "SWIG_InstallBinaryOps", "plplot__octaveOCTAVE__wrap_8cxx.html#a13dab8071049aa71567f6228ef64ce37", null ],
     [ "SWIG_InstallOps", "plplot__octaveOCTAVE__wrap_8cxx.html#ae441c428852d06ec6fe63cc6b3bcc5fd", null ],
     [ "SWIG_InstallUnaryOps", "plplot__octaveOCTAVE__wrap_8cxx.html#a179da016e9dc5705402cf3bf3e093c33", null ],
     [ "SWIG_MangledTypeQueryModule", "plplot__octaveOCTAVE__wrap_8cxx.html#ac63ad9b58a96793188f944c92ff40ec6", null ],
-    [ "SWIG_name", "plplot__octaveOCTAVE__wrap_8cxx.html#a79097447f8af73de5d6567694270efe3", null ],
     [ "SWIG_Octave_AppendOutput", "plplot__octaveOCTAVE__wrap_8cxx.html#aa4e22e8ae30360485ff5feb73976b72c", null ],
     [ "SWIG_Octave_ConvertPacked", "plplot__octaveOCTAVE__wrap_8cxx.html#ae962d8a53602e6704dc9a9f58cad789a", null ],
     [ "SWIG_Octave_ConvertPtrAndOwn", "plplot__octaveOCTAVE__wrap_8cxx.html#a22bd0c6c9045fd5570cbd7b702463191", null ],
     [ "SWIG_Octave_GetGlobalValue", "plplot__octaveOCTAVE__wrap_8cxx.html#a42bb6b1a3ec055a7117bae65aa1a2ac5", null ],
     [ "SWIG_Octave_GetModule", "plplot__octaveOCTAVE__wrap_8cxx.html#a9f1e2742a274869c13513a5382b1125e", null ],
-    [ "SWIG_Octave_InstallFunction", "plplot__octaveOCTAVE__wrap_8cxx.html#a06f759762d8d2871dab7242714e791ad", null ],
+    [ "SWIG_Octave_InstallFunction", "plplot__octaveOCTAVE__wrap_8cxx.html#a1853f9a4776f0374fdf49ccce08fac0d", null ],
     [ "SWIG_Octave_LinkGlobalValue", "plplot__octaveOCTAVE__wrap_8cxx.html#aa7aca5a9598d3a7e54a10c9ef913b551", null ],
+    [ "SWIG_Octave_LoadModule", "plplot__octaveOCTAVE__wrap_8cxx.html#a0631969adcee59914f6dbbbd1ad5ac30", null ],
     [ "SWIG_Octave_NewPackedObj", "plplot__octaveOCTAVE__wrap_8cxx.html#a6178ee9c4a9a2bd28569fc00794fba30", null ],
     [ "SWIG_Octave_NewPointerObj", "plplot__octaveOCTAVE__wrap_8cxx.html#a6265b3fadf4a3e2b2cbb3bb207f80acb", null ],
-    [ "SWIG_Octave_SetConstant", "plplot__octaveOCTAVE__wrap_8cxx.html#a8e8f2beeeb0aa3e404a0af39c30ab0ca", null ],
+    [ "SWIG_Octave_SetConstant", "plplot__octaveOCTAVE__wrap_8cxx.html#a55080f72a30ffb379e86d6b4da65c335", null ],
     [ "SWIG_Octave_SetGlobalValue", "plplot__octaveOCTAVE__wrap_8cxx.html#a0d0c1da95cd910c92d6cd5fe4b9abf7e", null ],
     [ "SWIG_Octave_SetModule", "plplot__octaveOCTAVE__wrap_8cxx.html#a9cd1c69fc1037d2fa2385f33b4a0531b", null ],
     [ "SWIG_PackData", "plplot__octaveOCTAVE__wrap_8cxx.html#a02c2ac3db8ce87dd62813334e66c9a3a", null ],
@@ -471,7 +471,7 @@ var plplot__octaveOCTAVE__wrap_8cxx =
     [ "SWIG_TypeCheck", "plplot__octaveOCTAVE__wrap_8cxx.html#abd0cb78a9663e41312c8f14ab6715f04", null ],
     [ "SWIG_TypeCheckStruct", "plplot__octaveOCTAVE__wrap_8cxx.html#a898a1dfcdf96d53a2c7fd90e8500b36e", null ],
     [ "SWIG_TypeClientData", "plplot__octaveOCTAVE__wrap_8cxx.html#a4b0a40223812f7d43bc2f0c2342fe2f7", null ],
-    [ "SWIG_TypeCompare", "plplot__octaveOCTAVE__wrap_8cxx.html#adc0e91b1eac793ed183ae989c62d33fb", null ],
+    [ "SWIG_TypeCmp", "plplot__octaveOCTAVE__wrap_8cxx.html#a73131c439c907ed987c34da85b95a597", null ],
     [ "SWIG_TypeDynamicCast", "plplot__octaveOCTAVE__wrap_8cxx.html#add8cb1a47628b36915ffa37d61452b1e", null ],
     [ "SWIG_TypeEquiv", "plplot__octaveOCTAVE__wrap_8cxx.html#a23ecf039d651082ffc7582c4f50af780", null ],
     [ "SWIG_TypeName", "plplot__octaveOCTAVE__wrap_8cxx.html#a68560e0bf641c9691704d6d05bac4358", null ],
@@ -556,6 +556,7 @@ var plplot__octaveOCTAVE__wrap_8cxx =
     [ "_wrap_plgdidev_texinfo", "plplot__octaveOCTAVE__wrap_8cxx.html#ade375d0038cb6f2024a244e0ecd34ff0", null ],
     [ "_wrap_plgdiori_texinfo", "plplot__octaveOCTAVE__wrap_8cxx.html#a58b681a2e82a2a4b6abed90d18e7cfe2", null ],
     [ "_wrap_plgdiplt_texinfo", "plplot__octaveOCTAVE__wrap_8cxx.html#a81af5d9d150d7f45682f903e3f0bb1a2", null ],
+    [ "_wrap_plGetCursor_texinfo", "plplot__octaveOCTAVE__wrap_8cxx.html#afd49d641e72ee51611cf1a5b51691cda", null ],
     [ "_wrap_plgfam_texinfo", "plplot__octaveOCTAVE__wrap_8cxx.html#a5dbd9d3f9accae4a39c873006db5a504", null ],
     [ "_wrap_plgfci_texinfo", "plplot__octaveOCTAVE__wrap_8cxx.html#a9f4997b65360e1bb8940cf15e8cdb3d7", null ],
     [ "_wrap_plgfnam_texinfo", "plplot__octaveOCTAVE__wrap_8cxx.html#a448e50f9abb019758b9cb1b64c95f335", null ],
@@ -640,7 +641,6 @@ var plplot__octaveOCTAVE__wrap_8cxx =
     [ "_wrap_plsfci_texinfo", "plplot__octaveOCTAVE__wrap_8cxx.html#a4c3dcc40198bd902387211e9e20e62d7", null ],
     [ "_wrap_plsfnam_texinfo", "plplot__octaveOCTAVE__wrap_8cxx.html#a1f9dfda765c853242b80ce0b909bd171", null ],
     [ "_wrap_plsfont_texinfo", "plplot__octaveOCTAVE__wrap_8cxx.html#a9fd95438850d30290a2696b0772d0943", null ],
-    [ "_wrap_plshade1_texinfo", "plplot__octaveOCTAVE__wrap_8cxx.html#a56e6bbe3f1b66306773901d7a6a33901", null ],
     [ "_wrap_plshade_texinfo", "plplot__octaveOCTAVE__wrap_8cxx.html#a758878c62155eddc4ed09be54c46e585", null ],
     [ "_wrap_plshades_texinfo", "plplot__octaveOCTAVE__wrap_8cxx.html#a69ba285128deca5a9e650bb24066d5d6", null ],
     [ "_wrap_plslabelfunc_texinfo", "plplot__octaveOCTAVE__wrap_8cxx.html#a4bf96847a6ca31044b2aaf3d1fc73ed2", null ],
@@ -691,7 +691,7 @@ var plplot__octaveOCTAVE__wrap_8cxx =
     [ "nameMapForm", "plplot__octaveOCTAVE__wrap_8cxx.html#a55952eae0c718eb31b7692a0db8957c5", null ],
     [ "subclass_usage", "plplot__octaveOCTAVE__wrap_8cxx.html#a70e41eebfacedae630ffb0f6830da98d", null ],
     [ "swig_cast_initial", "plplot__octaveOCTAVE__wrap_8cxx.html#a0666e347f7d486a3bc82b78efd732333", null ],
-    [ "swig_globals", "plplot__octaveOCTAVE__wrap_8cxx.html#a78ba4a1a89f3ec642716ba1cdbb414b6", null ],
+    [ "swig_globals", "plplot__octaveOCTAVE__wrap_8cxx.html#a2e16be9ca3dc12041253a0e53d5d5866", null ],
     [ "swig_module", "plplot__octaveOCTAVE__wrap_8cxx.html#a5f41f6e106d3195e660a39e5292f50fd", null ],
     [ "SWIG_name_usage", "plplot__octaveOCTAVE__wrap_8cxx.html#a3be459f147c734c484303f9ca2e95fd5", null ],
     [ "swig_PLGraphicsIn_base", "plplot__octaveOCTAVE__wrap_8cxx.html#a131d0e3556f9b6d6929bcc035e4decf5", null ],
