@@ -7,6 +7,7 @@ var plplotluacLUA__wrap_8c =
     [ "swig_lua_const_info", "structswig__lua__const__info.html", "structswig__lua__const__info" ],
     [ "swig_lua_method", "structswig__lua__method.html", "structswig__lua__method" ],
     [ "swig_lua_attribute", "structswig__lua__attribute.html", "structswig__lua__attribute" ],
+    [ "swig_lua_namespace", "structswig__lua__namespace.html", "structswig__lua__namespace" ],
     [ "swig_lua_class", "structswig__lua__class.html", "structswig__lua__class" ],
     [ "swig_lua_userdata", "structswig__lua__userdata.html", "structswig__lua__userdata" ],
     [ "swig_lua_rawdata", "structswig__lua__rawdata.html", "structswig__lua__rawdata" ],
@@ -15,7 +16,7 @@ var plplotluacLUA__wrap_8c =
     [ "LUA_FREE_ARRAY", "plplotluacLUA__wrap_8c.html#ad034efaaaac3076aa497086bf63370af", null ],
     [ "lua_pushglobaltable", "plplotluacLUA__wrap_8c.html#abf88c897458bd9848010301cb46ade18", null ],
     [ "lua_rawlen", "plplotluacLUA__wrap_8c.html#a0a129d773aae7e71b7c30370cd3c3dd9", null ],
-    [ "SWIG_AddCast", "plplotluacLUA__wrap_8c.html#ad69473581dbf2292673b61e56b35d893", null ],
+    [ "SWIG_AddCast", "plplotluacLUA__wrap_8c.html#a4f6f5e0444e44e48aef51f6620438a5f", null ],
     [ "SWIG_AddNewMask", "plplotluacLUA__wrap_8c.html#af7ac7e424b623712f70e9b6640a54853", null ],
     [ "SWIG_AddTmpMask", "plplotluacLUA__wrap_8c.html#af8527f0123949ec90e05d0fb156c11e3", null ],
     [ "SWIG_ALLOC_ARRAY", "plplotluacLUA__wrap_8c.html#a0fcc00738845cf2e532f6909f27d54d3", null ],
@@ -348,13 +349,17 @@ var plplotluacLUA__wrap_8c =
     [ "SWIG_InitializeModule", "plplotluacLUA__wrap_8c.html#a7f8da48fe4dbc23aef01a714623b8a6b", null ],
     [ "SWIG_itable_size", "plplotluacLUA__wrap_8c.html#a6e0b3731cc48dd5ee179491ca42b2785", null ],
     [ "SWIG_Lua_add_class_details", "plplotluacLUA__wrap_8c.html#aa82840b8b3ce37d1cf1e3c3aa1bc6beb", null ],
+    [ "SWIG_Lua_add_class_static_details", "plplotluacLUA__wrap_8c.html#a893afdb43641c6f2a334bc28b2bc5d90", null ],
     [ "SWIG_Lua_add_class_variable", "plplotluacLUA__wrap_8c.html#a199fa578fb0309b79b5ed51844c590ad", null ],
+    [ "SWIG_Lua_add_namespace_details", "plplotluacLUA__wrap_8c.html#a9ee5ba0a0bf072010a447d4b2f98d545", null ],
     [ "SWIG_Lua_class_destruct", "plplotluacLUA__wrap_8c.html#aba87e0d4ef2c7e61e81b4f685eef7b7b", null ],
     [ "SWIG_Lua_class_disown", "plplotluacLUA__wrap_8c.html#aa6dab0ada88ba05ba8067207c79efbd8", null ],
     [ "SWIG_Lua_class_get", "plplotluacLUA__wrap_8c.html#a85b5ba6bf2bdbe0d21a3611f3b5f8df3", null ],
     [ "SWIG_Lua_class_register", "plplotluacLUA__wrap_8c.html#a96a75364a5f20fd525bb603440f698d3", null ],
+    [ "SWIG_Lua_class_register_static", "plplotluacLUA__wrap_8c.html#a2451693ac83d6d677ab826b113491760", null ],
     [ "SWIG_Lua_class_set", "plplotluacLUA__wrap_8c.html#ab75aeed852fd5b630a45dd2312ced041", null ],
     [ "SWIG_Lua_class_tostring", "plplotluacLUA__wrap_8c.html#aeabb40f074f78d6ff46831b93e4750e1", null ],
+    [ "SWIG_Lua_constructor_proxy", "plplotluacLUA__wrap_8c.html#aa6b2b3e8c34678d30d3a95d5026681b6", null ],
     [ "SWIG_Lua_ConvertPacked", "plplotluacLUA__wrap_8c.html#a34313b58896afa8f8a27f1d0bfd2b7c4", null ],
     [ "SWIG_Lua_ConvertPtr", "plplotluacLUA__wrap_8c.html#a0d0394796468d0001b1d3d358a19891f", null ],
     [ "SWIG_Lua_dostring", "plplotluacLUA__wrap_8c.html#a3af0c40da7cc32dc9af81d722828ad63", null ],
@@ -372,8 +377,13 @@ var plplotluacLUA__wrap_8c =
     [ "SWIG_Lua_module_get", "plplotluacLUA__wrap_8c.html#adac9c2918f945c6a24bde2e4fecf9f70", null ],
     [ "SWIG_Lua_module_set", "plplotluacLUA__wrap_8c.html#a8bb6f0983ff06b1c171f90d0009e9eba", null ],
     [ "SWIG_Lua_MustGetPtr", "plplotluacLUA__wrap_8c.html#a8ed84d67fe041f17069ed2e28e23d1e4", null ],
+    [ "SWIG_Lua_namespace_get", "plplotluacLUA__wrap_8c.html#a82a3c5d46b7bdaa57cc1106ff5a89663", null ],
+    [ "SWIG_Lua_namespace_register", "plplotluacLUA__wrap_8c.html#a8600fb5860a603c15d18321afd3b910a", null ],
+    [ "SWIG_Lua_namespace_set", "plplotluacLUA__wrap_8c.html#aa56ce48dad661ece0586e2b0477d04d6", null ],
     [ "SWIG_Lua_NewPackedObj", "plplotluacLUA__wrap_8c.html#ab98924e8e52ff8f34ace1515120ccda6", null ],
     [ "SWIG_Lua_NewPointerObj", "plplotluacLUA__wrap_8c.html#a96c4cba9e0940983c98de6a9d6f339c8", null ],
+    [ "SWIG_Lua_pusherrstring", "plplotluacLUA__wrap_8c.html#a17d5e7cfbab0914882ec82e36d22381e", null ],
+    [ "SWIG_Lua_pushferrstring", "plplotluacLUA__wrap_8c.html#ad4708a823127d389179291ebcace732d", null ],
     [ "SWIG_Lua_set_immutable", "plplotluacLUA__wrap_8c.html#a98115a70232aa660ee341e0ea4353485", null ],
     [ "SWIG_Lua_SetModule", "plplotluacLUA__wrap_8c.html#a127abd2d6d37e5b1e86d2421c751492e", null ],
     [ "SWIG_Lua_type", "plplotluacLUA__wrap_8c.html#a85bb429fb2e29e3681bbda49ce8c34c1", null ],
@@ -389,7 +399,7 @@ var plplotluacLUA__wrap_8c =
     [ "SWIG_TypeCheck", "plplotluacLUA__wrap_8c.html#abd0cb78a9663e41312c8f14ab6715f04", null ],
     [ "SWIG_TypeCheckStruct", "plplotluacLUA__wrap_8c.html#a898a1dfcdf96d53a2c7fd90e8500b36e", null ],
     [ "SWIG_TypeClientData", "plplotluacLUA__wrap_8c.html#a4b0a40223812f7d43bc2f0c2342fe2f7", null ],
-    [ "SWIG_TypeCompare", "plplotluacLUA__wrap_8c.html#adc0e91b1eac793ed183ae989c62d33fb", null ],
+    [ "SWIG_TypeCmp", "plplotluacLUA__wrap_8c.html#a73131c439c907ed987c34da85b95a597", null ],
     [ "SWIG_TypeDynamicCast", "plplotluacLUA__wrap_8c.html#add8cb1a47628b36915ffa37d61452b1e", null ],
     [ "SWIG_TypeEquiv", "plplotluacLUA__wrap_8c.html#a23ecf039d651082ffc7582c4f50af780", null ],
     [ "SWIG_TypeName", "plplotluacLUA__wrap_8c.html#a68560e0bf641c9691704d6d05bac4358", null ],
@@ -433,13 +443,16 @@ var plplotluacLUA__wrap_8c =
     [ "mylabel_funcstr", "plplotluacLUA__wrap_8c.html#a5797cce2266cabb8bc8f22e3c212fb2c", null ],
     [ "mypltr_funcstr", "plplotluacLUA__wrap_8c.html#a6abec419e8ef65ee5b90b45b293654ae", null ],
     [ "swig_cast_initial", "plplotluacLUA__wrap_8c.html#a0666e347f7d486a3bc82b78efd732333", null ],
-    [ "swig_commands", "plplotluacLUA__wrap_8c.html#aa647df43a2be38ccba20d3c685d865f4", null ],
+    [ "swig_commands", "plplotluacLUA__wrap_8c.html#a81939268e0c5a2bcdc5b85a2b81af578", null ],
     [ "swig_constants", "plplotluacLUA__wrap_8c.html#ad6cf4679bcd945976329a7a2322eb933", null ],
     [ "SWIG_LUACODE", "plplotluacLUA__wrap_8c.html#aa51daa176c79b3ddc28ddd7faea49df6", null ],
     [ "swig_module", "plplotluacLUA__wrap_8c.html#a5f41f6e106d3195e660a39e5292f50fd", null ],
     [ "swig_PLGraphicsIn_attributes", "plplotluacLUA__wrap_8c.html#a31ea4233864be17d7c1522edd94cae04", null ],
     [ "swig_PLGraphicsIn_base_names", "plplotluacLUA__wrap_8c.html#a61ee77e649c977070ca543d7c915c4dd", null ],
     [ "swig_PLGraphicsIn_bases", "plplotluacLUA__wrap_8c.html#a628bc42b3766b1f707c39d4744799c70", null ],
+    [ "swig_PLGraphicsIn_cls_attributes", "plplotluacLUA__wrap_8c.html#a3fa85ddbe4f32bc9793de6ecb8aa915a", null ],
+    [ "swig_PLGraphicsIn_cls_constants", "plplotluacLUA__wrap_8c.html#a8d528cee4f8bfb79408fa2a9a6a7ad6d", null ],
+    [ "swig_PLGraphicsIn_cls_methods", "plplotluacLUA__wrap_8c.html#a246a673ec285a0ba6a7d8f03ab3bbb05", null ],
     [ "swig_PLGraphicsIn_methods", "plplotluacLUA__wrap_8c.html#ae99b2700e57e59871b8f487565d83c73", null ],
     [ "swig_type_initial", "plplotluacLUA__wrap_8c.html#ad621c8a05a43cf3a48467c791142bb44", null ],
     [ "swig_types", "plplotluacLUA__wrap_8c.html#a5a4358414fc0b190c3d0255e2d5d4ca2", null ],
