@@ -32,7 +32,7 @@ var searchData=
   ['defaultfamilylookup',['defaultFamilyLookup',['../cairo_8c.html#a736736436b0cd48c0634f4b6d24281dc',1,'cairo.c']]],
   ['define_5foctave_5fallocator',['DEFINE_OCTAVE_ALLOCATOR',['../plplot__octaveOCTAVE__wrap_8cxx.html#a1c38bc0a81e9cac4e99cad1615434041',1,'DEFINE_OCTAVE_ALLOCATOR(octave_swig_ref):&#160;plplot_octaveOCTAVE_wrap.cxx'],['../plplot__octaveOCTAVE__wrap_8cxx.html#a621d8272de7916252c4a0565a86c2b43',1,'DEFINE_OCTAVE_ALLOCATOR(octave_swig_packed):&#160;plplot_octaveOCTAVE_wrap.cxx']]],
   ['define_5fov_5ftypeid_5ffunctions_5fand_5fdata',['DEFINE_OV_TYPEID_FUNCTIONS_AND_DATA',['../plplot__octaveOCTAVE__wrap_8cxx.html#ac4d8460f6574c9e8f5f170ef57c99814',1,'DEFINE_OV_TYPEID_FUNCTIONS_AND_DATA(octave_swig_ref,&quot;swig_ref&quot;,&quot;swig_ref&quot;):&#160;plplot_octaveOCTAVE_wrap.cxx'],['../plplot__octaveOCTAVE__wrap_8cxx.html#a4002b21652bb2b7c222e4a3968be9b27',1,'DEFINE_OV_TYPEID_FUNCTIONS_AND_DATA(octave_swig_packed,&quot;swig_packed&quot;,&quot;swig_packed&quot;):&#160;plplot_octaveOCTAVE_wrap.cxx']]],
-  ['defined_5ffunc',['defined_func',['../plplotluacLUA__wrap_8c.html#aead6f867c497426f7186863e3851644f',1,'defined_func():&#160;plplotluacLUA_wrap.c'],['../plplot__octaveOCTAVE__wrap_8cxx.html#aead6f867c497426f7186863e3851644f',1,'defined_func():&#160;plplot_octaveOCTAVE_wrap.cxx'],['../plplotcmodulePYTHON__wrap_8c.html#aead6f867c497426f7186863e3851644f',1,'defined_func():&#160;plplotcmodulePYTHON_wrap.c']]],
+  ['defined_5ffunc',['defined_func',['../plplotluacLUA__wrap_8c.html#aead6f867c497426f7186863e3851644f',1,'defined_func():&#160;plplotluacLUA_wrap.c'],['../plplot__octaveOCTAVE__wrap_8cxx.html#aead6f867c497426f7186863e3851644f',1,'defined_func():&#160;plplot_octaveOCTAVE_wrap.cxx'],['../plplotcPYTHON__wrap_8c.html#aead6f867c497426f7186863e3851644f',1,'defined_func():&#160;plplotcPYTHON_wrap.c']]],
   ['defines_2eh',['defines.h',['../defines_8h.html',1,'']]],
   ['defun_5fdld',['DEFUN_DLD',['../plplot__octaveOCTAVE__wrap_8cxx.html#ac13932b327fb71daa08748c18951c3f9',1,'DEFUN_DLD(subclass, args, nargout, subclass_usage):&#160;plplot_octaveOCTAVE_wrap.cxx'],['../plplot__octaveOCTAVE__wrap_8cxx.html#abbf0ebabef8311f62e7fae987a70b0fd',1,'DEFUN_DLD(swig_type, args, nargout, swig_type_usage):&#160;plplot_octaveOCTAVE_wrap.cxx'],['../plplot__octaveOCTAVE__wrap_8cxx.html#a1088cd965f29ad14aca570370afb8fd7',1,'DEFUN_DLD(swig_typequery, args, nargout, swig_typequery_usage):&#160;plplot_octaveOCTAVE_wrap.cxx'],['../plplot__octaveOCTAVE__wrap_8cxx.html#a41e892f26c71c2d1d444a693d46adcd7',1,'DEFUN_DLD(swig_this, args, nargout, swig_this_usage):&#160;plplot_octaveOCTAVE_wrap.cxx'],['../plplot__octaveOCTAVE__wrap_8cxx.html#af603dd8b1bc7c35c0f7d994edb96961f',1,'DEFUN_DLD(SWIG_name, args, nargout, SWIG_name_usage):&#160;plplot_octaveOCTAVE_wrap.cxx']]],
   ['deg_5fto_5frad',['DEG_TO_RAD',['../plarc_8c.html#a8ed7b6a1f199b6d2af90e642918cf271',1,'plarc.c']]],
@@ -166,12 +166,12 @@ var searchData=
   ['dist1',['dist1',['../plgridd_8c.html#aed35f65d98dcda4b8a545087dd3ee6ec',1,'plgridd.c']]],
   ['dist2',['dist2',['../plgridd_8c.html#a418f460dd7759aef145b685bdada2637',1,'plgridd.c']]],
   ['distance',['distance',['../csa_8c.html#a35d71de6ce16c9812718704541edc013',1,'csa.c']]],
-  ['div',['div',['../structplf2ops__t.html#a5ba25212fe6a2ea7cdac6985620b56c5',1,'plf2ops_t']]],
-  ['do_5fct_5fcallback',['do_ct_callback',['../plplotcmodulePYTHON__wrap_8c.html#aa55de72b3611b0c8da14b06623b31d00',1,'plplotcmodulePYTHON_wrap.c']]],
-  ['do_5ff2eval_5fcallback',['do_f2eval_callback',['../plplotcmodulePYTHON__wrap_8c.html#a186e3ee0d5d1fd3e9dcc77c8946d9607',1,'plplotcmodulePYTHON_wrap.c']]],
-  ['do_5flabel_5fcallback',['do_label_callback',['../plplotcmodulePYTHON__wrap_8c.html#a5b0321ad235146d11e01257ddf5783e2',1,'plplotcmodulePYTHON_wrap.c']]],
-  ['do_5fmapform_5fcallback',['do_mapform_callback',['../plplotcmodulePYTHON__wrap_8c.html#a2ad7669c1293909aafb1a4539ae41f4e',1,'plplotcmodulePYTHON_wrap.c']]],
-  ['do_5fpltr_5fcallback',['do_pltr_callback',['../plplotcmodulePYTHON__wrap_8c.html#ad26774534ac3b87f0895b44638d77ace',1,'plplotcmodulePYTHON_wrap.c']]],
+  ['div',['div',['../structplf2ops__t.html#adee8c7c790b5b49672909c53f505a5d4',1,'plf2ops_t']]],
+  ['do_5fct_5fcallback',['do_ct_callback',['../plplotcPYTHON__wrap_8c.html#aa55de72b3611b0c8da14b06623b31d00',1,'plplotcPYTHON_wrap.c']]],
+  ['do_5ff2eval_5fcallback',['do_f2eval_callback',['../plplotcPYTHON__wrap_8c.html#a186e3ee0d5d1fd3e9dcc77c8946d9607',1,'plplotcPYTHON_wrap.c']]],
+  ['do_5flabel_5fcallback',['do_label_callback',['../plplotcPYTHON__wrap_8c.html#a5b0321ad235146d11e01257ddf5783e2',1,'plplotcPYTHON_wrap.c']]],
+  ['do_5fmapform_5fcallback',['do_mapform_callback',['../plplotcPYTHON__wrap_8c.html#a2ad7669c1293909aafb1a4539ae41f4e',1,'plplotcPYTHON_wrap.c']]],
+  ['do_5fpltr_5fcallback',['do_pltr_callback',['../plplotcPYTHON__wrap_8c.html#ad26774534ac3b87f0895b44638d77ace',1,'plplotcPYTHON_wrap.c']]],
   ['doc',['doc',['../structswig__octave__member.html#a9d331d2028fa0141e9fb9824dfe48b9b',1,'swig_octave_member']]],
   ['domxma',['domxma',['../structPLStream.html#a4c6dedc71895250e9ca0d1c06ff8332d',1,'PLStream']]],
   ['domxmi',['domxmi',['../structPLStream.html#ac067cc75f47a42d588dc74194e0e0bc7',1,'PLStream']]],
@@ -202,8 +202,8 @@ var searchData=
   ['drawrband',['DrawRband',['../plframe_8c.html#a15a2da7baf33ee3bcf95a3fa301a4a78',1,'DrawRband(PlFrame *, int, int):&#160;plframe.c'],['../plplotter_8c.html#a34e94728a8cbb3f868617819d2e21f93',1,'DrawRband(PlPlotter *, int, int):&#160;plplotter.c']]],
   ['drawtext',['drawText',['../classPlDevice.html#a3c68a9d54fcb56e68613653f5593988b',1,'PlDevice::drawText()'],['../classQtPLDriver.html#ac2fa93d479f3c737375f933d9eff4e32',1,'QtPLDriver::drawText()']]],
   ['drawtextinpicture',['drawTextInPicture',['../classQtPLDriver.html#ab60f69a6b11708230670c807f4cc5b4d',1,'QtPLDriver']]],
-  ['drawtextline',['DrawTextLine',['../classPlDevice.html#a252cf7172f293c7761703769b5f2ab6e',1,'PlDevice']]],
-  ['drawtextsection',['DrawTextSection',['../classPlDevice.html#abca74884d734a919c2fa8c8c54ec28ca',1,'PlDevice::DrawTextSection()'],['../classwxPLDevice.html#abc5f3cbb3309bb9edf754a38a6449fe6',1,'wxPLDevice::DrawTextSection()']]],
+  ['drawtextline',['DrawTextLine',['../classPlDevice.html#a4c99f2188467bd5a80948cb67311fee4',1,'PlDevice']]],
+  ['drawtextsection',['DrawTextSection',['../classPlDevice.html#a07dea92732956d650c2edb2765e72b3b',1,'PlDevice::DrawTextSection()'],['../classwxPLDevice.html#a51cbc96777fc3bb31e30de2c69843e6f',1,'wxPLDevice::DrawTextSection()']]],
   ['drawxhairs',['DrawXhairs',['../plframe_8c.html#ad0fc44bf75ba9c49e410b8758ab2e5a7',1,'DrawXhairs(PlFrame *, int, int):&#160;plframe.c'],['../plplotter_8c.html#a88797198c2fdfdb31fedd9f8201dc27a',1,'DrawXhairs(PlPlotter *, int, int):&#160;plplotter.c']]],
   ['driver_5finterface',['DRIVER_INTERFACE',['../metadefs_8h.html#a69063a66eb5cc1673e7898be53e40bd5',1,'metadefs.h']]],
   ['drivers_2eh',['drivers.h',['../drivers_8h.html',1,'']]],
