@@ -181,6 +181,7 @@ var searchData=
   ['pl_5fundefined',['PL_UNDEFINED',['../plplotP_8h.html#aad52408b58851dc6713a87f439d0d926',1,'plplotP.h']]],
   ['pl_5funused',['PL_UNUSED',['../plplot_8h.html#a7d5497a8bc266dc65d84f05403965fbd',1,'plplot.h']]],
   ['pl_5fuse_5fnamespace',['PL_USE_NAMESPACE',['../plConfig_8h.html#a38438bcfe34ee23b6c0d3f4bc66fd118',1,'plConfig.h']]],
+  ['pl_5fwxwidgets_5fipc3',['PL_WXWIDGETS_IPC3',['../plplot__config_8h.html#a978aa51558d71c50dfaf34071b9aaeea',1,'plplot_config.h']]],
   ['pl_5fx_5faxis',['PL_X_AXIS',['../plplot_8h.html#a56a5fd49ef1fdbddaea6796d554a8ea2',1,'plplot.h']]],
   ['pl_5fxfont',['PL_XFONT',['../plplotP_8h.html#afa71ec0de00d1490f068a5a74903e07e',1,'plplotP.h']]],
   ['pl_5fy_5faxis',['PL_Y_AXIS',['../plplot_8h.html#a1112e4818b4e23d202362016b0f248e6',1,'plplot.h']]],
@@ -246,10 +247,8 @@ var searchData=
   ['pldllimpexp_5fdata',['PLDLLIMPEXP_DATA',['../pldll_8h.html#a00b57362a33448d57f58ad8c9c39b80c',1,'pldll.h']]],
   ['pldllimpexp_5fdriver',['PLDLLIMPEXP_DRIVER',['../pldll_8h.html#af9bec706108ea4c17c55222a4a2899f3',1,'pldll.h']]],
   ['pldllimpexp_5fdriver_5fdata',['PLDLLIMPEXP_DRIVER_DATA',['../pldll_8h.html#a593250b83d4303fb58bcb8b4ca17f6ac',1,'pldll.h']]],
-  ['pldllimpexp_5ff95c',['PLDLLIMPEXP_F95C',['../pldll_8h.html#aa0380576febb76f2e23ac30616e38af1',1,'pldll.h']]],
-  ['pldllimpexp_5ff95c_5fdata',['PLDLLIMPEXP_F95C_DATA',['../pldll_8h.html#a2470f3d22c17ab84c907d97eaedb969e',1,'pldll.h']]],
-  ['pldllimpexp_5fplplot_5fmodule',['PLDLLIMPEXP_PLPLOT_MODULE',['../pldll_8h.html#aa1e089e55f9a5e488e64ce4c3f85f622',1,'pldll.h']]],
-  ['pldllimpexp_5fplplot_5fmodule_5fdata',['PLDLLIMPEXP_PLPLOT_MODULE_DATA',['../pldll_8h.html#a56029a7e57892da9b7e1768b404864cd',1,'pldll.h']]],
+  ['pldllimpexp_5ffortranc',['PLDLLIMPEXP_FORTRANC',['../pldll_8h.html#a842f1eb32e448f33ad7b2c77520cb57d',1,'pldll.h']]],
+  ['pldllimpexp_5ffortranc_5fdata',['PLDLLIMPEXP_FORTRANC_DATA',['../pldll_8h.html#a640ed3869f78bbcad3bb92b8a3fd88e3',1,'pldll.h']]],
   ['pldllimpexp_5fpyqt4',['PLDLLIMPEXP_PYQT4',['../pldll_8h.html#a87f5399c8969b2cce703051418a4c2ee',1,'pldll.h']]],
   ['pldllimpexp_5fpyqt4_5fdata',['PLDLLIMPEXP_PYQT4_DATA',['../pldll_8h.html#aae6c49bfd5cf09716169dc21a4756977',1,'pldll.h']]],
   ['pldllimpexp_5fpyqt5',['PLDLLIMPEXP_PYQT5',['../pldll_8h.html#ad965cc839f8e4aa18b9b47a617faf266',1,'pldll.h']]],
@@ -664,19 +663,19 @@ var searchData=
   ['positive_5fslope',['POSITIVE_SLOPE',['../plshade_8c.html#a370d47b188a024bae0cbdc4fb2708ba8',1,'plshade.c']]],
   ['psx',['PSX',['../ps_8h.html#a81bd405f224a24cc3fd0db79f40507c5',1,'ps.h']]],
   ['psy',['PSY',['../ps_8h.html#a1a0aebfec9c29e451f68a9cca220252f',1,'ps.h']]],
-  ['py_5fnotimplemented',['Py_NotImplemented',['../plplotcmodulePYTHON__wrap_8c.html#ae5603e8c5fd8ec50c4936e1012a58cb4',1,'plplotcmodulePYTHON_wrap.c']]],
-  ['py_5fssize_5ft_5fmax',['PY_SSIZE_T_MAX',['../plplotcmodulePYTHON__wrap_8c.html#aa5b5990f814eb53730c24c7f911f9132',1,'plplotcmodulePYTHON_wrap.c']]],
-  ['py_5fssize_5ft_5fmin',['PY_SSIZE_T_MIN',['../plplotcmodulePYTHON__wrap_8c.html#a9fbcf3e88f34de99fb3bd045cffd6ce4',1,'plplotcmodulePYTHON_wrap.c']]],
-  ['py_5ftype',['Py_TYPE',['../plplotcmodulePYTHON__wrap_8c.html#afd489119bf6e3552bdaa6bc365e35e59',1,'plplotcmodulePYTHON_wrap.c']]],
-  ['py_5fvisit',['Py_VISIT',['../plplotcmodulePYTHON__wrap_8c.html#a8a5af783da2cdbcfdc7c354f635df8be',1,'plplotcmodulePYTHON_wrap.c']]],
-  ['pydescr_5fname',['PyDescr_NAME',['../plplotcmodulePYTHON__wrap_8c.html#a7b007021fc924eb74eccb0bb05d99ad1',1,'plplotcmodulePYTHON_wrap.c']]],
-  ['pydescr_5ftype',['PyDescr_TYPE',['../plplotcmodulePYTHON__wrap_8c.html#a0d2bc679367576eb4071b8c3bfe13edc',1,'plplotcmodulePYTHON_wrap.c']]],
-  ['pyexc_5fstopiteration',['PyExc_StopIteration',['../plplotcmodulePYTHON__wrap_8c.html#a0cba46b26eb93c57b8b96696ba92adb4',1,'plplotcmodulePYTHON_wrap.c']]],
-  ['pyint_5ffromsize_5ft',['PyInt_FromSize_t',['../plplotcmodulePYTHON__wrap_8c.html#a2a72c6061f4d23c35a8340448dd0cd2b',1,'plplotcmodulePYTHON_wrap.c']]],
-  ['pyobject_5fdel',['PyObject_Del',['../plplotcmodulePYTHON__wrap_8c.html#a5777895532ba038acdbde39ef6f78a82',1,'PyObject_Del():&#160;plplotcmodulePYTHON_wrap.c'],['../plplotcmodulePYTHON__wrap_8c.html#a3e72f1bb4b2af8f115a750f832d421b4',1,'PyObject_DEL():&#160;plplotcmodulePYTHON_wrap.c']]],
-  ['pyobject_5fgenericgetattr',['PyObject_GenericGetAttr',['../plplotcmodulePYTHON__wrap_8c.html#a2d659e3ecdc8d792ec516753e6fd37a2',1,'plplotcmodulePYTHON_wrap.c']]],
-  ['pyos_5fsnprintf',['PyOS_snprintf',['../plplotcmodulePYTHON__wrap_8c.html#aaf424b640ab3bb23906652e73030992b',1,'plplotcmodulePYTHON_wrap.c']]],
-  ['pysequence_5ffast_5fget_5fitem',['PySequence_Fast_GET_ITEM',['../plplotcmodulePYTHON__wrap_8c.html#ada824e75a50f73e7439516caeaecb478',1,'plplotcmodulePYTHON_wrap.c']]],
-  ['pysequence_5fsize',['PySequence_Size',['../plplotcmodulePYTHON__wrap_8c.html#ae0178153199e3020e8d586e0e50fc796',1,'PySequence_Size():&#160;plplotcmodulePYTHON_wrap.c'],['../plplotcmodulePYTHON__wrap_8c.html#ae0178153199e3020e8d586e0e50fc796',1,'PySequence_Size():&#160;plplotcmodulePYTHON_wrap.c']]],
-  ['pystring_5fasstringandsize',['PyString_AsStringAndSize',['../plplotcmodulePYTHON__wrap_8c.html#afdc43df5cb9472c0f13c86d8e01aea31',1,'plplotcmodulePYTHON_wrap.c']]]
+  ['py_5fnotimplemented',['Py_NotImplemented',['../plplotcPYTHON__wrap_8c.html#ae5603e8c5fd8ec50c4936e1012a58cb4',1,'plplotcPYTHON_wrap.c']]],
+  ['py_5fssize_5ft_5fmax',['PY_SSIZE_T_MAX',['../plplotcPYTHON__wrap_8c.html#aa5b5990f814eb53730c24c7f911f9132',1,'plplotcPYTHON_wrap.c']]],
+  ['py_5fssize_5ft_5fmin',['PY_SSIZE_T_MIN',['../plplotcPYTHON__wrap_8c.html#a9fbcf3e88f34de99fb3bd045cffd6ce4',1,'plplotcPYTHON_wrap.c']]],
+  ['py_5ftype',['Py_TYPE',['../plplotcPYTHON__wrap_8c.html#afd489119bf6e3552bdaa6bc365e35e59',1,'plplotcPYTHON_wrap.c']]],
+  ['py_5fvisit',['Py_VISIT',['../plplotcPYTHON__wrap_8c.html#a8a5af783da2cdbcfdc7c354f635df8be',1,'plplotcPYTHON_wrap.c']]],
+  ['pydescr_5fname',['PyDescr_NAME',['../plplotcPYTHON__wrap_8c.html#a7b007021fc924eb74eccb0bb05d99ad1',1,'plplotcPYTHON_wrap.c']]],
+  ['pydescr_5ftype',['PyDescr_TYPE',['../plplotcPYTHON__wrap_8c.html#a0d2bc679367576eb4071b8c3bfe13edc',1,'plplotcPYTHON_wrap.c']]],
+  ['pyexc_5fstopiteration',['PyExc_StopIteration',['../plplotcPYTHON__wrap_8c.html#a0cba46b26eb93c57b8b96696ba92adb4',1,'plplotcPYTHON_wrap.c']]],
+  ['pyint_5ffromsize_5ft',['PyInt_FromSize_t',['../plplotcPYTHON__wrap_8c.html#a2a72c6061f4d23c35a8340448dd0cd2b',1,'plplotcPYTHON_wrap.c']]],
+  ['pyobject_5fdel',['PyObject_Del',['../plplotcPYTHON__wrap_8c.html#a5777895532ba038acdbde39ef6f78a82',1,'PyObject_Del():&#160;plplotcPYTHON_wrap.c'],['../plplotcPYTHON__wrap_8c.html#a3e72f1bb4b2af8f115a750f832d421b4',1,'PyObject_DEL():&#160;plplotcPYTHON_wrap.c']]],
+  ['pyobject_5fgenericgetattr',['PyObject_GenericGetAttr',['../plplotcPYTHON__wrap_8c.html#a2d659e3ecdc8d792ec516753e6fd37a2',1,'plplotcPYTHON_wrap.c']]],
+  ['pyos_5fsnprintf',['PyOS_snprintf',['../plplotcPYTHON__wrap_8c.html#aaf424b640ab3bb23906652e73030992b',1,'plplotcPYTHON_wrap.c']]],
+  ['pysequence_5ffast_5fget_5fitem',['PySequence_Fast_GET_ITEM',['../plplotcPYTHON__wrap_8c.html#ada824e75a50f73e7439516caeaecb478',1,'plplotcPYTHON_wrap.c']]],
+  ['pysequence_5fsize',['PySequence_Size',['../plplotcPYTHON__wrap_8c.html#ae0178153199e3020e8d586e0e50fc796',1,'PySequence_Size():&#160;plplotcPYTHON_wrap.c'],['../plplotcPYTHON__wrap_8c.html#ae0178153199e3020e8d586e0e50fc796',1,'PySequence_Size():&#160;plplotcPYTHON_wrap.c']]],
+  ['pystring_5fasstringandsize',['PyString_AsStringAndSize',['../plplotcPYTHON__wrap_8c.html#afdc43df5cb9472c0f13c86d8e01aea31',1,'plplotcPYTHON_wrap.c']]]
 ];
