@@ -16,7 +16,7 @@ var searchData=
   ['c_5fplcol1',['c_plcol1',['../plctrl_8c.html#a603b23649a648f93bc71a72c74e7b322',1,'c_plcol1():&#160;plctrl.c'],['../namespaceplplot.html#a3623f4f7d266155f40cacc03ee9c7942',1,'plplot::c_plcol1()'],['../plplot_8h.html#a5ada6ff695ce184c11be47def6dae0a6',1,'c_plcol1():&#160;plctrl.c']]],
   ['c_5fplcolorbar',['c_plcolorbar',['../pllegend_8c.html#acab91e12a21610cf82acb45af785eef8',1,'c_plcolorbar():&#160;pllegend.c'],['../namespaceplplot.html#a4964a6240e828bb7b8eaa1f1ec7805c3',1,'plplot::c_plcolorbar()'],['../plplot_8h.html#a46c03ffbe85b2a03a5f8597188e0e488',1,'c_plcolorbar():&#160;plplot.h']]],
   ['c_5fplconfigtime',['c_plconfigtime',['../pltime_8c.html#a00537880dbb29517076b2fc924df4005',1,'c_plconfigtime():&#160;pltime.c'],['../namespaceplplot.html#affd4a9742097665110b2cdc8732207f0',1,'plplot::c_plconfigtime()'],['../plplot_8h.html#a5f35b5400d68ae1ebe6418c5bec5052c',1,'c_plconfigtime():&#160;pltime.c']]],
-  ['c_5fplcont',['c_plcont',['../plcont_8c.html#a523561cdd668576f34cc4286422495f3',1,'c_plcont():&#160;plcont.c'],['../namespaceplplot.html#ae4f6b3c11f651d6103168853fdf8eec1',1,'plplot::c_plcont()'],['../plplot_8h.html#acff127342bc923c604b70008009859b8',1,'c_plcont():&#160;plcont.c']]],
+  ['c_5fplcont',['c_plcont',['../plcont_8c.html#a523561cdd668576f34cc4286422495f3',1,'c_plcont():&#160;plcont.c'],['../namespaceplplot.html#ae4f6b3c11f651d6103168853fdf8eec1',1,'plplot::c_plcont()'],['../plplot_8h.html#a9ee068257e863261b9da62455e3e6467',1,'c_plcont():&#160;plcont.c']]],
   ['c_5fplcpstrm',['c_plcpstrm',['../plcore_8c.html#a808e7856a0bef6d71c2309abea207c78',1,'c_plcpstrm():&#160;plcore.c'],['../namespaceplplot.html#a695e1e6c1def7151027bb5478dc74649',1,'plplot::c_plcpstrm()'],['../plplot_8h.html#ad16c39cffa39e594adba42654a95b698',1,'c_plcpstrm():&#160;plcore.c']]],
   ['c_5fplctime',['c_plctime',['../pltime_8c.html#abfd974ab4f78f7b591e73cfc3b3f4f4c',1,'c_plctime():&#160;pltime.c'],['../namespaceplplot.html#a8ea62d1294f79d32b7b7d8a31a4a602b',1,'plplot::c_plctime()'],['../plplot_8h.html#afc0c95bf532e98f61c0da1e8933bf6f6',1,'c_plctime():&#160;plplot.h']]],
   ['c_5fplend',['c_plend',['../plcore_8c.html#a057806120a84ea1da3ffef67bff47491',1,'c_plend():&#160;plcore.c'],['../namespaceplplot.html#abc2df3677e61a8fad26cedd5b51a2048',1,'plplot::c_plend()'],['../plplot_8h.html#a4ab1fe008a7495add8bb292f79806ead',1,'c_plend():&#160;plcore.c']]],
@@ -66,7 +66,7 @@ var searchData=
   ['c_5fplhls',['c_plhls',['../namespaceplplot.html#ae64e0e1a256915d94bf330a6427cedce',1,'plplot']]],
   ['c_5fplhlsrgb',['c_plhlsrgb',['../plctrl_8c.html#afe5c216f6c83e64df5a16b48b2f7af15',1,'c_plhlsrgb():&#160;plctrl.c'],['../namespaceplplot.html#a9da5d6fa041c7256061955d7ace6e62a',1,'plplot::c_plhlsrgb()'],['../plplot_8h.html#a9e9560a0fddc381de37802b7d14ec1e1',1,'c_plhlsrgb():&#160;plplot.h']]],
   ['c_5fplimage',['c_plimage',['../plimage_8c.html#ae0d2aee9a1e865cda3428d51990ed46f',1,'c_plimage():&#160;plimage.c'],['../namespaceplplot.html#a6ca701d920c0c0708ad8685969baab6e',1,'plplot::c_plimage()'],['../plplot_8h.html#a8e4c28058e6347f092502d71de4537de',1,'c_plimage():&#160;plimage.c']]],
-  ['c_5fplimagefr',['c_plimagefr',['../plimage_8c.html#a870571ff0cc72aa355cc64c68b94a316',1,'c_plimagefr():&#160;plimage.c'],['../namespaceplplot.html#a4b288976d5756013c9c41dcee6b48bc7',1,'plplot::c_plimagefr()'],['../plplot_8h.html#a06279ee83cd77e1bc299300b79e7dd4c',1,'c_plimagefr():&#160;plimage.c']]],
+  ['c_5fplimagefr',['c_plimagefr',['../plimage_8c.html#a870571ff0cc72aa355cc64c68b94a316',1,'c_plimagefr():&#160;plimage.c'],['../namespaceplplot.html#a4b288976d5756013c9c41dcee6b48bc7',1,'plplot::c_plimagefr()'],['../plplot_8h.html#a7f5ce2feda00354aebbd4073db12c492',1,'c_plimagefr():&#160;plimage.c']]],
   ['c_5fplinit',['c_plinit',['../plcore_8c.html#ab4936c1ab86820efcc43ba6d2d3e98bd',1,'c_plinit():&#160;plcore.c'],['../namespaceplplot.html#af6879e026a87986cf246b6ad230f5d74',1,'plplot::c_plinit()'],['../plplot_8h.html#a16ca877b784c3f1afa2157e7b01c9f09',1,'c_plinit():&#160;plcore.c']]],
   ['c_5fpljoin',['c_pljoin',['../plline_8c.html#ac9265d404c0ac361ae7c052a72b05815',1,'c_pljoin():&#160;plline.c'],['../namespaceplplot.html#ac22b591e6252c2aaaa38d4f3bf847375',1,'plplot::c_pljoin()'],['../plplot_8h.html#ae41b66e619fb441dae94b8fe9c7de1e7',1,'c_pljoin():&#160;plline.c']]],
   ['c_5fpllab',['c_pllab',['../plsym_8c.html#a3f0cbf25fcf03518b5a816339b84f651',1,'c_pllab():&#160;plsym.c'],['../namespaceplplot.html#a49e321eebc6a6d803fc9b2e39bb783ec',1,'plplot::c_pllab()'],['../plplot_8h.html#a2d786426e8f623cbd69b2b2c214cb2c9',1,'c_pllab():&#160;plsym.c']]],
@@ -134,13 +134,13 @@ var searchData=
   ['c_5fplsfci',['c_plsfci',['../plcore_8c.html#ac161115689719887c26b967f5ae8cc17',1,'c_plsfci():&#160;plcore.c'],['../namespaceplplot.html#a8c335543dfd6a3f04afd9e22e412bb57',1,'plplot::c_plsfci()'],['../plplot_8h.html#a074ce37141f38208e2d25ce5bb3a785b',1,'c_plsfci():&#160;plcore.c']]],
   ['c_5fplsfnam',['c_plsfnam',['../plcore_8c.html#ae483472b1b57f3281c85c6e968b607d4',1,'c_plsfnam():&#160;plcore.c'],['../namespaceplplot.html#abf9a388c1ceb8a0d0c3c5c4e1038dcdf',1,'plplot::c_plsfnam()'],['../plplot_8h.html#a5337f550e9667396f3ebf85dd8508e65',1,'c_plsfnam():&#160;plcore.c']]],
   ['c_5fplsfont',['c_plsfont',['../plsym_8c.html#a6bcba7ea478412dd64c6f8e2eb834f06',1,'c_plsfont():&#160;plsym.c'],['../namespaceplplot.html#a5b068eafc7f0e005e57efdf2345bdd75',1,'plplot::c_plsfont()'],['../plplot_8h.html#a6393d02708ce42194302ccf3b94edf47',1,'c_plsfont():&#160;plsym.c']]],
-  ['c_5fplshade',['c_plshade',['../plshade_8c.html#abc5a40007856cb961f2c192c799e8ace',1,'c_plshade():&#160;plshade.c'],['../namespaceplplot.html#aff655c6b4bfe486a4826d684f7eb8162',1,'plplot::c_plshade()'],['../plplot_8h.html#abb98f54306b240493ac9031342e2df04',1,'c_plshade():&#160;plshade.c']]],
-  ['c_5fplshade1',['c_plshade1',['../plshade_8c.html#add9e26b8c903ec27b358b65b02957c09',1,'c_plshade1(PLFLT_VECTOR a, PLINT nx, PLINT ny, PLDEFINED_callback defined, PLFLT xmin, PLFLT xmax, PLFLT ymin, PLFLT ymax, PLFLT shade_min, PLFLT shade_max, PLINT sh_cmap, PLFLT sh_color, PLFLT sh_width, PLINT min_color, PLFLT min_width, PLINT max_color, PLFLT max_width, PLFILL_callback fill, PLINT rectangular, PLTRANSFORM_callback pltr, PLPointer pltr_data):&#160;plshade.c'],['../plplot_8h.html#a41c572aa37f14e6ee3861e135784458f',1,'c_plshade1(PLFLT_FE_POINTER a, PLINT nx, PLINT ny, PLDEFINED_callback defined, PLFLT xmin, PLFLT xmax, PLFLT ymin, PLFLT ymax, PLFLT shade_min, PLFLT shade_max, PLINT sh_cmap, PLFLT sh_color, PLFLT sh_width, PLINT min_color, PLFLT min_width, PLINT max_color, PLFLT max_width, PLFILL_callback fill, PLBOOL rectangular, PLTRANSFORM_callback pltr, PL_GENERIC_POINTER pltr_data):&#160;plshade.c']]],
-  ['c_5fplshades',['c_plshades',['../plshade_8c.html#aa2ce196b86af4014f0f684381db7ad87',1,'c_plshades():&#160;plshade.c'],['../namespaceplplot.html#a965abbc050863a7fb8be7f8b9c95ba8c',1,'plplot::c_plshades()'],['../plplot_8h.html#ab4b7bb654479745c52febe90d0bd802c',1,'c_plshades():&#160;plshade.c']]],
-  ['c_5fplslabelfunc',['c_plslabelfunc',['../plbox_8c.html#a556211357054b5b8e994502b2d8d25f2',1,'c_plslabelfunc():&#160;plbox.c'],['../namespaceplplot.html#a3afe1f3514bd9954f8298df421bff580',1,'plplot::c_plslabelfunc()'],['../plplot_8h.html#ab29b59ea8d08227dd770d7165db236fb',1,'c_plslabelfunc():&#160;plbox.c']]],
+  ['c_5fplshade',['c_plshade',['../plshade_8c.html#abc5a40007856cb961f2c192c799e8ace',1,'c_plshade():&#160;plshade.c'],['../namespaceplplot.html#aff655c6b4bfe486a4826d684f7eb8162',1,'plplot::c_plshade()'],['../plplot_8h.html#a7b704b2af4c8e38945eaa60cf37b529b',1,'c_plshade():&#160;plshade.c']]],
+  ['c_5fplshade1',['c_plshade1',['../plshade_8c.html#add9e26b8c903ec27b358b65b02957c09',1,'c_plshade1(PLFLT_VECTOR a, PLINT nx, PLINT ny, PLDEFINED_callback defined, PLFLT xmin, PLFLT xmax, PLFLT ymin, PLFLT ymax, PLFLT shade_min, PLFLT shade_max, PLINT sh_cmap, PLFLT sh_color, PLFLT sh_width, PLINT min_color, PLFLT min_width, PLINT max_color, PLFLT max_width, PLFILL_callback fill, PLINT rectangular, PLTRANSFORM_callback pltr, PLPointer pltr_data):&#160;plshade.c'],['../plplot_8h.html#aecc19194ce082d26d401069d401fae1c',1,'c_plshade1(PLFLT_FE_POINTER a, PLINT nx, PLINT ny, PLDEFINED_callback defined, PLFLT xmin, PLFLT xmax, PLFLT ymin, PLFLT ymax, PLFLT shade_min, PLFLT shade_max, PLINT sh_cmap, PLFLT sh_color, PLFLT sh_width, PLINT min_color, PLFLT min_width, PLINT max_color, PLFLT max_width, PLFILL_callback fill, PLBOOL rectangular, PLTRANSFORM_callback pltr, PLPointer pltr_data):&#160;plshade.c']]],
+  ['c_5fplshades',['c_plshades',['../plshade_8c.html#aa2ce196b86af4014f0f684381db7ad87',1,'c_plshades():&#160;plshade.c'],['../namespaceplplot.html#a965abbc050863a7fb8be7f8b9c95ba8c',1,'plplot::c_plshades()'],['../plplot_8h.html#ae6230a52f672b926669e78f76bc6154f',1,'c_plshades():&#160;plshade.c']]],
+  ['c_5fplslabelfunc',['c_plslabelfunc',['../plbox_8c.html#a556211357054b5b8e994502b2d8d25f2',1,'c_plslabelfunc():&#160;plbox.c'],['../namespaceplplot.html#a3afe1f3514bd9954f8298df421bff580',1,'plplot::c_plslabelfunc()'],['../plplot_8h.html#ae52bcc90ec1061aecf3654dee05e56e0',1,'c_plslabelfunc():&#160;plbox.c']]],
   ['c_5fplsmaj',['c_plsmaj',['../plsdef_8c.html#aff3d7a3414c7ccf801748e9c594a8425',1,'c_plsmaj():&#160;plsdef.c'],['../namespaceplplot.html#aece3d659a68624da7636e7fa347c340e',1,'plplot::c_plsmaj()'],['../plplot_8h.html#a1c011f9eeab7ca11a5de4f2afdc2b501',1,'c_plsmaj():&#160;plsdef.c']]],
-  ['c_5fplsmem',['c_plsmem',['../plcore_8c.html#a5332cad59cd8e8424274d43a50c869db',1,'c_plsmem():&#160;plcore.c'],['../namespaceplplot.html#a8dbab3b79283c14dcd32b500b512fc1e',1,'plplot::c_plsmem()'],['../plplot_8h.html#a0614f09ef44ed5cffc694a972a057968',1,'c_plsmem():&#160;plcore.c']]],
-  ['c_5fplsmema',['c_plsmema',['../plcore_8c.html#a7c4475f45e1b579af4b147f4cd5df58a',1,'c_plsmema(PLINT maxx, PLINT maxy, void *plotmem):&#160;plcore.c'],['../plplot_8h.html#a06ad1c316055aaaa74f9ba2eb9daf605',1,'c_plsmema(PLINT maxx, PLINT maxy, PL_NC_GENERIC_POINTER plotmem):&#160;plcore.c']]],
+  ['c_5fplsmem',['c_plsmem',['../plcore_8c.html#a5332cad59cd8e8424274d43a50c869db',1,'c_plsmem():&#160;plcore.c'],['../namespaceplplot.html#a8dbab3b79283c14dcd32b500b512fc1e',1,'plplot::c_plsmem()'],['../plplot_8h.html#a7d89468a6bad6367bb1d64c18bd6293c',1,'c_plsmem():&#160;plcore.c']]],
+  ['c_5fplsmema',['c_plsmema',['../plcore_8c.html#a7c4475f45e1b579af4b147f4cd5df58a',1,'c_plsmema(PLINT maxx, PLINT maxy, void *plotmem):&#160;plcore.c'],['../plplot_8h.html#a95631c576074df1dd45ee3cc0a1ddb70',1,'c_plsmema(PLINT maxx, PLINT maxy, PLPointer plotmem):&#160;plcore.c']]],
   ['c_5fplsmin',['c_plsmin',['../plsdef_8c.html#a15fc4e3d0e506b357aa626220152cba2',1,'c_plsmin():&#160;plsdef.c'],['../namespaceplplot.html#afb634e82ed33c8f87328c9b78521c549',1,'plplot::c_plsmin()'],['../plplot_8h.html#afaa43df242c2a6166072b2cc3cf1d1a2',1,'c_plsmin():&#160;plsdef.c']]],
   ['c_5fplsori',['c_plsori',['../plcore_8c.html#aece5565b63831fdba73b39c9a1f2ea1e',1,'c_plsori():&#160;plcore.c'],['../namespaceplplot.html#ac6700874a4b5d3e55a04206ccafa22bc',1,'plplot::c_plsori()'],['../plplot_8h.html#ae92f904189306eb1dc8f1b6641bd3c6b',1,'c_plsori():&#160;plcore.c']]],
   ['c_5fplspage',['c_plspage',['../plcore_8c.html#ad12f661799506496b1172332fd00e54f',1,'c_plspage():&#160;plcore.c'],['../namespaceplplot.html#a5faaf381f93b54562b9770d83362b5c8',1,'plplot::c_plspage()'],['../plplot_8h.html#a993d2bc54f3dd8d7432fe9e2d8ce1b09',1,'c_plspage():&#160;plcore.c']]],
@@ -152,7 +152,7 @@ var searchData=
   ['c_5fplssym',['c_plssym',['../plsdef_8c.html#a54e0770c4bf0e7ce9f405dde72f261c2',1,'c_plssym():&#160;plsdef.c'],['../namespaceplplot.html#ae6219d749ee7630013cc5e6f91a64af9',1,'plplot::c_plssym()'],['../plplot_8h.html#a940a97b378a847bd9699d0e18162d57e',1,'c_plssym():&#160;plsdef.c']]],
   ['c_5fplstar',['c_plstar',['../plcore_8c.html#a3d15fa158e627ba1582fbad9271c797b',1,'c_plstar():&#160;plcore.c'],['../namespaceplplot.html#a80ca439ae6fe5db885c066ec461efa62',1,'plplot::c_plstar()'],['../plplot_8h.html#a1690af1bfe3d5c00784fdb9e68d830f9',1,'c_plstar():&#160;plcore.c']]],
   ['c_5fplstart',['c_plstart',['../plcore_8c.html#a30abc7821b66912c4103c994c2e009ee',1,'c_plstart():&#160;plcore.c'],['../namespaceplplot.html#a23d9f44ae538a81b5989f284583e0cf6',1,'plplot::c_plstart()'],['../plplot_8h.html#acf171cdde28a0ee9c413c912d359420c',1,'c_plstart():&#160;plcore.c']]],
-  ['c_5fplstransform',['c_plstransform',['../plcore_8c.html#a437721a29e32435183c99fa8e9e5f5a2',1,'c_plstransform():&#160;plcore.c'],['../namespaceplplot.html#a247e7fabb00a5f2ac6d81385d366709b',1,'plplot::c_plstransform()'],['../plplot_8h.html#ad6ebe304a1955f9a50f4fdee36a0a749',1,'c_plstransform():&#160;plcore.c']]],
+  ['c_5fplstransform',['c_plstransform',['../plcore_8c.html#a437721a29e32435183c99fa8e9e5f5a2',1,'c_plstransform():&#160;plcore.c'],['../namespaceplplot.html#a247e7fabb00a5f2ac6d81385d366709b',1,'plplot::c_plstransform()'],['../plplot_8h.html#ab4f5d2715b351a7215907a11ecca92e9',1,'c_plstransform():&#160;plcore.c']]],
   ['c_5fplstring',['c_plstring',['../plsym_8c.html#a342c77b0761f0c7c6be8e8df2f60f4ea',1,'c_plstring():&#160;plsym.c'],['../namespaceplplot.html#a31a1d0908fcb030d73f2454fd5315114',1,'plplot::c_plstring()'],['../plplot_8h.html#a8422af8d77d66646808e57f0585934a5',1,'c_plstring():&#160;plsym.c']]],
   ['c_5fplstring3',['c_plstring3',['../plsym_8c.html#a3723083bc0d76615f416937ec59bae5b',1,'c_plstring3():&#160;plsym.c'],['../namespaceplplot.html#a69b4ec3b9328c306109dad867b0c6dab',1,'plplot::c_plstring3()'],['../plplot_8h.html#ac8a61d7c6fae85234acbe7ca5983e94c',1,'c_plstring3():&#160;plsym.c']]],
   ['c_5fplstripa',['c_plstripa',['../plstripc_8c.html#ade08cf4f557157f5fdb772791a90ae1c',1,'c_plstripa():&#160;plstripc.c'],['../namespaceplplot.html#a108b680da31e4c7a095f3473b60786ee',1,'plplot::c_plstripa()'],['../plplot_8h.html#a7635fe351043aa7138a17a7d4b7ba2a4',1,'c_plstripa():&#160;plstripc.c']]],
@@ -170,7 +170,7 @@ var searchData=
   ['c_5fpltext',['c_pltext',['../plctrl_8c.html#a4c415dc78101b686ddd487d8f0dcc24f',1,'c_pltext():&#160;plctrl.c'],['../namespaceplplot.html#a426135b864521001f1048223f4d97bf1',1,'plplot::c_pltext()'],['../plplot_8h.html#a94c1af262a2855684ddeeea0d13e3fa5',1,'c_pltext():&#160;plctrl.c']]],
   ['c_5fpltimefmt',['c_pltimefmt',['../pltime_8c.html#a58c5f37950e02f670b372534da7ef04c',1,'c_pltimefmt():&#160;pltime.c'],['../namespaceplplot.html#aae6cd0577e41bed837f0df5766dd203e',1,'plplot::c_pltimefmt()'],['../plplot_8h.html#aff9a3a7ee09c2c1c4076058aa07cc4eb',1,'c_pltimefmt():&#160;pltime.c']]],
   ['c_5fplvasp',['c_plvasp',['../plvpor_8c.html#a61eccae47199b96f3cf1e68955998a47',1,'c_plvasp():&#160;plvpor.c'],['../namespaceplplot.html#af28bc6aa01b3bda2fb22dd2988beb6e9',1,'plplot::c_plvasp()'],['../plplot_8h.html#a6d0c2a4be40790e91824ad0b7bac0bec',1,'c_plvasp():&#160;plvpor.c']]],
-  ['c_5fplvect',['c_plvect',['../plvect_8c.html#ab36164048c3c08f3e139c619e7d9568e',1,'c_plvect():&#160;plvect.c'],['../namespaceplplot.html#abfe95f7e5cee37e1b7c449c1bde17854',1,'plplot::c_plvect()'],['../plplot_8h.html#a2835835831901d228e1cfbf152afc9c6',1,'c_plvect():&#160;plvect.c']]],
+  ['c_5fplvect',['c_plvect',['../plvect_8c.html#ab36164048c3c08f3e139c619e7d9568e',1,'c_plvect():&#160;plvect.c'],['../namespaceplplot.html#abfe95f7e5cee37e1b7c449c1bde17854',1,'plplot::c_plvect()'],['../plplot_8h.html#a12842a5955e8151ee92f4904d60c0066',1,'c_plvect():&#160;plvect.c']]],
   ['c_5fplvpas',['c_plvpas',['../plvpor_8c.html#a78a625661389b35e5678e7d5b88722c2',1,'c_plvpas():&#160;plvpor.c'],['../namespaceplplot.html#a9db90eb66c2c80dd6f4d40c60d361a53',1,'plplot::c_plvpas()'],['../plplot_8h.html#abd8a7e0ae9bb0da76807e7e0bf93e3a4',1,'c_plvpas():&#160;plvpor.c']]],
   ['c_5fplvpor',['c_plvpor',['../plvpor_8c.html#a3deca6d002c87668a1ea23c2e58a354c',1,'c_plvpor():&#160;plvpor.c'],['../namespaceplplot.html#aafb44a4d4a54f5a5dd45c089b69a76e2',1,'plplot::c_plvpor()'],['../plplot_8h.html#a5fd547420fef9e958c4026bc2e9c4898',1,'c_plvpor():&#160;plvpor.c']]],
   ['c_5fplvsta',['c_plvsta',['../plvpor_8c.html#a631c030c812252a8a613572bbe1270ef',1,'c_plvsta():&#160;plvpor.c'],['../namespaceplplot.html#adf0f30dfd998a1253eab87d34fae0586',1,'plplot::c_plvsta()'],['../plplot_8h.html#ad6443e9ab2395017d048b8efb06e2ee2',1,'c_plvsta():&#160;plvpor.c']]],
@@ -264,12 +264,12 @@ var searchData=
   ['circle_5fcontains',['circle_contains',['../delaunay_8c.html#a6e51a289b1d8edfa40827e1b41d667f4',1,'circle_contains(circle *c, point *p):&#160;nncommon.c'],['../nncommon_8c.html#a6e51a289b1d8edfa40827e1b41d667f4',1,'circle_contains(circle *c, point *p):&#160;nncommon.c'],['../nnpi_8c.html#a6e51a289b1d8edfa40827e1b41d667f4',1,'circle_contains(circle *c, point *p):&#160;nncommon.c']]],
   ['circulation',['circulation',['../plfill_8c.html#a6ad6543e94d58212155ed3a930842dd3',1,'plfill.c']]],
   ['ckcalloc',['ckcalloc',['../tkwin_8c.html#a45c855cdc0bd19c27be8b5cf937d43b0',1,'tkwin.c']]],
-  ['cleanup_5fct',['cleanup_ct',['../plplotcmodulePYTHON__wrap_8c.html#a567b8a6e77233b620e6e356ce926b0c5',1,'plplotcmodulePYTHON_wrap.c']]],
-  ['cleanup_5fmapform',['cleanup_mapform',['../plplotcmodulePYTHON__wrap_8c.html#a20a1f2c307cb467884edd487c715010f',1,'plplotcmodulePYTHON_wrap.c']]],
-  ['cleanup_5fplcgrid1',['cleanup_PLcGrid1',['../plplotcmodulePYTHON__wrap_8c.html#a50b51d3c720a3d5516de3052c316fd5b',1,'plplotcmodulePYTHON_wrap.c']]],
-  ['cleanup_5fplcgrid2',['cleanup_PLcGrid2',['../plplotcmodulePYTHON__wrap_8c.html#a8e2cf3c60970cb7e7fc7e991a30dff14',1,'plplotcmodulePYTHON_wrap.c']]],
-  ['cleanup_5fplpointer',['cleanup_PLPointer',['../plplotcmodulePYTHON__wrap_8c.html#a210e38636bba3af6c5db9c8db451475f',1,'plplotcmodulePYTHON_wrap.c']]],
-  ['cleanup_5fpltr',['cleanup_pltr',['../plplotcmodulePYTHON__wrap_8c.html#a8d677910d74d3609111bb05a59ee49ec',1,'plplotcmodulePYTHON_wrap.c']]],
+  ['cleanup_5fct',['cleanup_ct',['../plplotcPYTHON__wrap_8c.html#a567b8a6e77233b620e6e356ce926b0c5',1,'plplotcPYTHON_wrap.c']]],
+  ['cleanup_5fmapform',['cleanup_mapform',['../plplotcPYTHON__wrap_8c.html#a20a1f2c307cb467884edd487c715010f',1,'plplotcPYTHON_wrap.c']]],
+  ['cleanup_5fplcgrid1',['cleanup_PLcGrid1',['../plplotcPYTHON__wrap_8c.html#a50b51d3c720a3d5516de3052c316fd5b',1,'plplotcPYTHON_wrap.c']]],
+  ['cleanup_5fplcgrid2',['cleanup_PLcGrid2',['../plplotcPYTHON__wrap_8c.html#a8e2cf3c60970cb7e7fc7e991a30dff14',1,'plplotcPYTHON_wrap.c']]],
+  ['cleanup_5fplpointer',['cleanup_PLPointer',['../plplotcPYTHON__wrap_8c.html#a210e38636bba3af6c5db9c8db451475f',1,'plplotcPYTHON_wrap.c']]],
+  ['cleanup_5fpltr',['cleanup_pltr',['../plplotcPYTHON__wrap_8c.html#a8d677910d74d3609111bb05a59ee49ec',1,'plplotcPYTHON_wrap.c']]],
   ['clear',['clear',['../classPLNamedMutex.html#ac871dfb9aa304c7b2973b6aa85500f65',1,'PLNamedMutex::clear()'],['../classplstream.html#af542aefb8cfea11f5e747e13311b5ce4',1,'plstream::clear()']]],
   ['clearbackground',['ClearBackground',['../classPlDevice.html#a691496af2bdad6325865ebf55a65ec8a',1,'PlDevice::ClearBackground()'],['../classwxPLDevice.html#adf773b89cce422a8993cff532d1468b5',1,'wxPLDevice::ClearBackground()']]],
   ['clearopts',['ClearOpts',['../classplstream.html#a3921c12c03ad654e354bbba07a6c57eb',1,'plstream']]],
