@@ -4,10 +4,10 @@ var searchData=
   ['cdimageptr',['cdImagePtr',['../cd_8h.html#a96862f8dfa2edfeb3a49e76ab0b9009f',1,'cd.h']]],
   ['cdpoint',['cdPoint',['../cd_8h.html#a809092add405aafd7d1c1983557ac29b',1,'cd.h']]],
   ['cdpointptr',['cdPointPtr',['../cd_8h.html#a91e78e65629ff570d6815732cdff9a89',1,'cd.h']]],
-  ['charbufferproc',['charbufferproc',['../plplotcmodulePYTHON__wrap_8c.html#a250efddeec782b8e392f0bbd1e3616ce',1,'plplotcmodulePYTHON_wrap.c']]],
+  ['charbufferproc',['charbufferproc',['../plplotcPYTHON__wrap_8c.html#a250efddeec782b8e392f0bbd1e3616ce',1,'plplotcPYTHON_wrap.c']]],
   ['command',['Command',['../tclAPI_8c.html#a1e070cd9ac686a0bb549183eaf77290e',1,'tclAPI.c']]],
   ['cont_5flevel',['CONT_LEVEL',['../plplotP_8h.html#a554bcd61c1010c02fc4711a3541be30a',1,'plplotP.h']]],
   ['cont_5fline',['CONT_LINE',['../plplotP_8h.html#af46feab5c736df8fe9a4406061ac7c69',1,'plplotP.h']]],
   ['csa',['csa',['../csa_8h.html#a08d0734d8d85dfb8c7eb0f539cfdf11a',1,'csa.h']]],
-  ['ct_5ffunc',['ct_func',['../plplotluacLUA__wrap_8c.html#a595f4b3960322d1991cb097ff49edb3f',1,'ct_func():&#160;plplotluacLUA_wrap.c'],['../plplot__octaveOCTAVE__wrap_8cxx.html#a595f4b3960322d1991cb097ff49edb3f',1,'ct_func():&#160;plplot_octaveOCTAVE_wrap.cxx'],['../plplotcmodulePYTHON__wrap_8c.html#a595f4b3960322d1991cb097ff49edb3f',1,'ct_func():&#160;plplotcmodulePYTHON_wrap.c']]]
+  ['ct_5ffunc',['ct_func',['../plplotluacLUA__wrap_8c.html#a595f4b3960322d1991cb097ff49edb3f',1,'ct_func():&#160;plplotluacLUA_wrap.c'],['../plplot__octaveOCTAVE__wrap_8cxx.html#a595f4b3960322d1991cb097ff49edb3f',1,'ct_func():&#160;plplot_octaveOCTAVE_wrap.cxx'],['../plplotcPYTHON__wrap_8c.html#a595f4b3960322d1991cb097ff49edb3f',1,'ct_func():&#160;plplotcPYTHON_wrap.c']]]
 ];
