@@ -11,34 +11,34 @@ var searchData=
   ['_5fnx',['_nx',['../classContourable__Data.html#a81d1eb26e390b2a3b0c3ab0ada6960c0',1,'Contourable_Data']]],
   ['_5fny',['_ny',['../classContourable__Data.html#aa548943e7e73bc001c0d7f162106ac9e',1,'Contourable_Data']]],
   ['_5fplplotc',['_plplotc',['../namespaceplplotc.html#ac3c13b77c76baac12d69958f88eca623',1,'plplotc._plplotc()'],['../namespaceplplotc__fixed.html#a4183603368371b1d7d897cd4aa6cd389',1,'plplotc_fixed._plplotc()']]],
-  ['_5fswigc_5f_5fp_5fchar',['_swigc__p_char',['../plplotluacLUA__wrap_8c.html#a8848127146fe0444e2fe3183a15b67f5',1,'_swigc__p_char():&#160;plplotluacLUA_wrap.c'],['../plplot__octaveOCTAVE__wrap_8cxx.html#a8848127146fe0444e2fe3183a15b67f5',1,'_swigc__p_char():&#160;plplot_octaveOCTAVE_wrap.cxx'],['../plplotcmodulePYTHON__wrap_8c.html#a8848127146fe0444e2fe3183a15b67f5',1,'_swigc__p_char():&#160;plplotcmodulePYTHON_wrap.c']]],
-  ['_5fswigc_5f_5fp_5fdouble',['_swigc__p_double',['../plplotluacLUA__wrap_8c.html#a28b7f0e03111f37524cf093e3a8a2304',1,'_swigc__p_double():&#160;plplotluacLUA_wrap.c'],['../plplot__octaveOCTAVE__wrap_8cxx.html#a28b7f0e03111f37524cf093e3a8a2304',1,'_swigc__p_double():&#160;plplot_octaveOCTAVE_wrap.cxx'],['../plplotcmodulePYTHON__wrap_8c.html#a28b7f0e03111f37524cf093e3a8a2304',1,'_swigc__p_double():&#160;plplotcmodulePYTHON_wrap.c']]],
-  ['_5fswigc_5f_5fp_5ff_5fdouble_5fdouble_5f_5fint',['_swigc__p_f_double_double__int',['../plplotluacLUA__wrap_8c.html#a207f66749bdba90b94fc94339a002520',1,'_swigc__p_f_double_double__int():&#160;plplotluacLUA_wrap.c'],['../plplotcmodulePYTHON__wrap_8c.html#a207f66749bdba90b94fc94339a002520',1,'_swigc__p_f_double_double__int():&#160;plplotcmodulePYTHON_wrap.c']]],
-  ['_5fswigc_5f_5fp_5ff_5fdouble_5fdouble_5fp_5fdouble_5fp_5fdouble_5fp_5fvoid_5f_5fvoid',['_swigc__p_f_double_double_p_double_p_double_p_void__void',['../plplotluacLUA__wrap_8c.html#a3f4c37068cdd295d0dafa913f043216e',1,'_swigc__p_f_double_double_p_double_p_double_p_void__void():&#160;plplotluacLUA_wrap.c'],['../plplot__octaveOCTAVE__wrap_8cxx.html#a3f4c37068cdd295d0dafa913f043216e',1,'_swigc__p_f_double_double_p_double_p_double_p_void__void():&#160;plplot_octaveOCTAVE_wrap.cxx'],['../plplotcmodulePYTHON__wrap_8c.html#a3f4c37068cdd295d0dafa913f043216e',1,'_swigc__p_f_double_double_p_double_p_double_p_void__void():&#160;plplotcmodulePYTHON_wrap.c']]],
-  ['_5fswigc_5f_5fp_5ff_5fint_5fdouble_5fp_5fchar_5fint_5fp_5fvoid_5f_5fvoid',['_swigc__p_f_int_double_p_char_int_p_void__void',['../plplotluacLUA__wrap_8c.html#abd7eee4930f48e2326a9df35e20f0bba',1,'_swigc__p_f_int_double_p_char_int_p_void__void():&#160;plplotluacLUA_wrap.c'],['../plplot__octaveOCTAVE__wrap_8cxx.html#abd7eee4930f48e2326a9df35e20f0bba',1,'_swigc__p_f_int_double_p_char_int_p_void__void():&#160;plplot_octaveOCTAVE_wrap.cxx'],['../plplotcmodulePYTHON__wrap_8c.html#abd7eee4930f48e2326a9df35e20f0bba',1,'_swigc__p_f_int_double_p_char_int_p_void__void():&#160;plplotcmodulePYTHON_wrap.c']]],
-  ['_5fswigc_5f_5fp_5ff_5fint_5fp_5fdouble_5fp_5fdouble_5f_5fvoid',['_swigc__p_f_int_p_double_p_double__void',['../plplotluacLUA__wrap_8c.html#a5c2379fb009e6c97a5de4731c20e4283',1,'_swigc__p_f_int_p_double_p_double__void():&#160;plplotluacLUA_wrap.c'],['../plplot__octaveOCTAVE__wrap_8cxx.html#a5c2379fb009e6c97a5de4731c20e4283',1,'_swigc__p_f_int_p_double_p_double__void():&#160;plplot_octaveOCTAVE_wrap.cxx'],['../plplotcmodulePYTHON__wrap_8c.html#a5c2379fb009e6c97a5de4731c20e4283',1,'_swigc__p_f_int_p_double_p_double__void():&#160;plplotcmodulePYTHON_wrap.c']]],
-  ['_5fswigc_5f_5fp_5ff_5fint_5fp_5fq_5fconst_5f_5fdouble_5fp_5fq_5fconst_5f_5fdouble_5f_5fvoid',['_swigc__p_f_int_p_q_const__double_p_q_const__double__void',['../plplotluacLUA__wrap_8c.html#af6625b2b7918b35eddbed9053fad7905',1,'_swigc__p_f_int_p_q_const__double_p_q_const__double__void():&#160;plplotluacLUA_wrap.c'],['../plplotcmodulePYTHON__wrap_8c.html#af6625b2b7918b35eddbed9053fad7905',1,'_swigc__p_f_int_p_q_const__double_p_q_const__double__void():&#160;plplotcmodulePYTHON_wrap.c']]],
-  ['_5fswigc_5f_5fp_5fint',['_swigc__p_int',['../plplotluacLUA__wrap_8c.html#a216d8b24b856092e2e65830ef290159b',1,'_swigc__p_int():&#160;plplotluacLUA_wrap.c'],['../plplot__octaveOCTAVE__wrap_8cxx.html#a216d8b24b856092e2e65830ef290159b',1,'_swigc__p_int():&#160;plplot_octaveOCTAVE_wrap.cxx'],['../plplotcmodulePYTHON__wrap_8c.html#a216d8b24b856092e2e65830ef290159b',1,'_swigc__p_int():&#160;plplotcmodulePYTHON_wrap.c']]],
-  ['_5fswigc_5f_5fp_5fp_5fchar',['_swigc__p_p_char',['../plplotluacLUA__wrap_8c.html#adf82b09513b48dd2275acc2fa74711b7',1,'_swigc__p_p_char():&#160;plplotluacLUA_wrap.c'],['../plplot__octaveOCTAVE__wrap_8cxx.html#adf82b09513b48dd2275acc2fa74711b7',1,'_swigc__p_p_char():&#160;plplot_octaveOCTAVE_wrap.cxx'],['../plplotcmodulePYTHON__wrap_8c.html#adf82b09513b48dd2275acc2fa74711b7',1,'_swigc__p_p_char():&#160;plplotcmodulePYTHON_wrap.c']]],
-  ['_5fswigc_5f_5fp_5fp_5fdouble',['_swigc__p_p_double',['../plplotluacLUA__wrap_8c.html#a8ef572e7214cb0eedcc6419377664472',1,'_swigc__p_p_double():&#160;plplotluacLUA_wrap.c'],['../plplotcmodulePYTHON__wrap_8c.html#a8ef572e7214cb0eedcc6419377664472',1,'_swigc__p_p_double():&#160;plplotcmodulePYTHON_wrap.c']]],
-  ['_5fswigc_5f_5fp_5fplcgrid',['_swigc__p_PLcGrid',['../plplotcmodulePYTHON__wrap_8c.html#ab71600ff158f81ba0f2ad17add084b68',1,'plplotcmodulePYTHON_wrap.c']]],
-  ['_5fswigc_5f_5fp_5fplcgrid2',['_swigc__p_PLcGrid2',['../plplotcmodulePYTHON__wrap_8c.html#a15ad6cd2c38c0be50be771105a0e60a6',1,'plplotcmodulePYTHON_wrap.c']]],
-  ['_5fswigc_5f_5fp_5fplgraphicsin',['_swigc__p_PLGraphicsIn',['../plplotluacLUA__wrap_8c.html#adbc9470f42e7e3c0a2adab2df09b950d',1,'_swigc__p_PLGraphicsIn():&#160;plplotluacLUA_wrap.c'],['../plplot__octaveOCTAVE__wrap_8cxx.html#adbc9470f42e7e3c0a2adab2df09b950d',1,'_swigc__p_PLGraphicsIn():&#160;plplot_octaveOCTAVE_wrap.cxx'],['../plplotcmodulePYTHON__wrap_8c.html#adbc9470f42e7e3c0a2adab2df09b950d',1,'_swigc__p_PLGraphicsIn():&#160;plplotcmodulePYTHON_wrap.c']]],
-  ['_5fswigc_5f_5fp_5funsigned_5fint',['_swigc__p_unsigned_int',['../plplotluacLUA__wrap_8c.html#aba9e61dc970ecfa60bf8a90276b1daa9',1,'_swigc__p_unsigned_int():&#160;plplotluacLUA_wrap.c'],['../plplot__octaveOCTAVE__wrap_8cxx.html#aba9e61dc970ecfa60bf8a90276b1daa9',1,'_swigc__p_unsigned_int():&#160;plplot_octaveOCTAVE_wrap.cxx'],['../plplotcmodulePYTHON__wrap_8c.html#aba9e61dc970ecfa60bf8a90276b1daa9',1,'_swigc__p_unsigned_int():&#160;plplotcmodulePYTHON_wrap.c']]],
-  ['_5fswigt_5f_5fp_5fchar',['_swigt__p_char',['../plplotluacLUA__wrap_8c.html#ae66f44191f70db7b9634a8321766c840',1,'_swigt__p_char():&#160;plplotluacLUA_wrap.c'],['../plplot__octaveOCTAVE__wrap_8cxx.html#ae66f44191f70db7b9634a8321766c840',1,'_swigt__p_char():&#160;plplot_octaveOCTAVE_wrap.cxx'],['../plplotcmodulePYTHON__wrap_8c.html#ae66f44191f70db7b9634a8321766c840',1,'_swigt__p_char():&#160;plplotcmodulePYTHON_wrap.c']]],
-  ['_5fswigt_5f_5fp_5fdouble',['_swigt__p_double',['../plplotluacLUA__wrap_8c.html#a650096f8d16b87549437da125768b407',1,'_swigt__p_double():&#160;plplotluacLUA_wrap.c'],['../plplot__octaveOCTAVE__wrap_8cxx.html#a650096f8d16b87549437da125768b407',1,'_swigt__p_double():&#160;plplot_octaveOCTAVE_wrap.cxx'],['../plplotcmodulePYTHON__wrap_8c.html#a650096f8d16b87549437da125768b407',1,'_swigt__p_double():&#160;plplotcmodulePYTHON_wrap.c']]],
-  ['_5fswigt_5f_5fp_5ff_5fdouble_5fdouble_5f_5fint',['_swigt__p_f_double_double__int',['../plplotluacLUA__wrap_8c.html#aa99dba7c5dc196a6edb638363e104be7',1,'_swigt__p_f_double_double__int():&#160;plplotluacLUA_wrap.c'],['../plplotcmodulePYTHON__wrap_8c.html#aa99dba7c5dc196a6edb638363e104be7',1,'_swigt__p_f_double_double__int():&#160;plplotcmodulePYTHON_wrap.c']]],
-  ['_5fswigt_5f_5fp_5ff_5fdouble_5fdouble_5fp_5fdouble_5fp_5fdouble_5fp_5fvoid_5f_5fvoid',['_swigt__p_f_double_double_p_double_p_double_p_void__void',['../plplotluacLUA__wrap_8c.html#a169d330528354eea0e80046288f7a240',1,'_swigt__p_f_double_double_p_double_p_double_p_void__void():&#160;plplotluacLUA_wrap.c'],['../plplot__octaveOCTAVE__wrap_8cxx.html#a169d330528354eea0e80046288f7a240',1,'_swigt__p_f_double_double_p_double_p_double_p_void__void():&#160;plplot_octaveOCTAVE_wrap.cxx'],['../plplotcmodulePYTHON__wrap_8c.html#a169d330528354eea0e80046288f7a240',1,'_swigt__p_f_double_double_p_double_p_double_p_void__void():&#160;plplotcmodulePYTHON_wrap.c']]],
-  ['_5fswigt_5f_5fp_5ff_5fint_5fdouble_5fp_5fchar_5fint_5fp_5fvoid_5f_5fvoid',['_swigt__p_f_int_double_p_char_int_p_void__void',['../plplotluacLUA__wrap_8c.html#ad192a829bb4110f62a13c396ab965321',1,'_swigt__p_f_int_double_p_char_int_p_void__void():&#160;plplotluacLUA_wrap.c'],['../plplot__octaveOCTAVE__wrap_8cxx.html#ad192a829bb4110f62a13c396ab965321',1,'_swigt__p_f_int_double_p_char_int_p_void__void():&#160;plplot_octaveOCTAVE_wrap.cxx'],['../plplotcmodulePYTHON__wrap_8c.html#ad192a829bb4110f62a13c396ab965321',1,'_swigt__p_f_int_double_p_char_int_p_void__void():&#160;plplotcmodulePYTHON_wrap.c']]],
-  ['_5fswigt_5f_5fp_5ff_5fint_5fp_5fdouble_5fp_5fdouble_5f_5fvoid',['_swigt__p_f_int_p_double_p_double__void',['../plplotluacLUA__wrap_8c.html#ac93b2bfcffa54c72401ce0fe924336ef',1,'_swigt__p_f_int_p_double_p_double__void():&#160;plplotluacLUA_wrap.c'],['../plplot__octaveOCTAVE__wrap_8cxx.html#ac93b2bfcffa54c72401ce0fe924336ef',1,'_swigt__p_f_int_p_double_p_double__void():&#160;plplot_octaveOCTAVE_wrap.cxx'],['../plplotcmodulePYTHON__wrap_8c.html#ac93b2bfcffa54c72401ce0fe924336ef',1,'_swigt__p_f_int_p_double_p_double__void():&#160;plplotcmodulePYTHON_wrap.c']]],
-  ['_5fswigt_5f_5fp_5ff_5fint_5fp_5fq_5fconst_5f_5fdouble_5fp_5fq_5fconst_5f_5fdouble_5f_5fvoid',['_swigt__p_f_int_p_q_const__double_p_q_const__double__void',['../plplotluacLUA__wrap_8c.html#a8a3b05af198a366e7d91148da9aa0695',1,'_swigt__p_f_int_p_q_const__double_p_q_const__double__void():&#160;plplotluacLUA_wrap.c'],['../plplotcmodulePYTHON__wrap_8c.html#a8a3b05af198a366e7d91148da9aa0695',1,'_swigt__p_f_int_p_q_const__double_p_q_const__double__void():&#160;plplotcmodulePYTHON_wrap.c']]],
-  ['_5fswigt_5f_5fp_5fint',['_swigt__p_int',['../plplotluacLUA__wrap_8c.html#abb18e7711ddb7deeaf40f89dd6643b2c',1,'_swigt__p_int():&#160;plplotluacLUA_wrap.c'],['../plplot__octaveOCTAVE__wrap_8cxx.html#abb18e7711ddb7deeaf40f89dd6643b2c',1,'_swigt__p_int():&#160;plplot_octaveOCTAVE_wrap.cxx'],['../plplotcmodulePYTHON__wrap_8c.html#abb18e7711ddb7deeaf40f89dd6643b2c',1,'_swigt__p_int():&#160;plplotcmodulePYTHON_wrap.c']]],
-  ['_5fswigt_5f_5fp_5fp_5fchar',['_swigt__p_p_char',['../plplotluacLUA__wrap_8c.html#a701773c68706ee07319dc186a10ec151',1,'_swigt__p_p_char():&#160;plplotluacLUA_wrap.c'],['../plplot__octaveOCTAVE__wrap_8cxx.html#a701773c68706ee07319dc186a10ec151',1,'_swigt__p_p_char():&#160;plplot_octaveOCTAVE_wrap.cxx'],['../plplotcmodulePYTHON__wrap_8c.html#a701773c68706ee07319dc186a10ec151',1,'_swigt__p_p_char():&#160;plplotcmodulePYTHON_wrap.c']]],
-  ['_5fswigt_5f_5fp_5fp_5fdouble',['_swigt__p_p_double',['../plplotluacLUA__wrap_8c.html#a7142a8246b533266bb0a1ec0e07d0516',1,'_swigt__p_p_double():&#160;plplotluacLUA_wrap.c'],['../plplotcmodulePYTHON__wrap_8c.html#a7142a8246b533266bb0a1ec0e07d0516',1,'_swigt__p_p_double():&#160;plplotcmodulePYTHON_wrap.c']]],
-  ['_5fswigt_5f_5fp_5fplcgrid',['_swigt__p_PLcGrid',['../plplotcmodulePYTHON__wrap_8c.html#ac62d4edffb73674c8eb44ee0965094fc',1,'plplotcmodulePYTHON_wrap.c']]],
-  ['_5fswigt_5f_5fp_5fplcgrid2',['_swigt__p_PLcGrid2',['../plplotcmodulePYTHON__wrap_8c.html#aefc05597d3afa2cf5e60f169e7326c10',1,'plplotcmodulePYTHON_wrap.c']]],
-  ['_5fswigt_5f_5fp_5fplgraphicsin',['_swigt__p_PLGraphicsIn',['../plplotluacLUA__wrap_8c.html#aa7423ef65fc1e3d9cc8e9acb90b31531',1,'_swigt__p_PLGraphicsIn():&#160;plplotluacLUA_wrap.c'],['../plplot__octaveOCTAVE__wrap_8cxx.html#aa7423ef65fc1e3d9cc8e9acb90b31531',1,'_swigt__p_PLGraphicsIn():&#160;plplot_octaveOCTAVE_wrap.cxx'],['../plplotcmodulePYTHON__wrap_8c.html#aa7423ef65fc1e3d9cc8e9acb90b31531',1,'_swigt__p_PLGraphicsIn():&#160;plplotcmodulePYTHON_wrap.c']]],
-  ['_5fswigt_5f_5fp_5funsigned_5fint',['_swigt__p_unsigned_int',['../plplotluacLUA__wrap_8c.html#ac758895aa5c2bb2a384d76af7fc77b2c',1,'_swigt__p_unsigned_int():&#160;plplotluacLUA_wrap.c'],['../plplot__octaveOCTAVE__wrap_8cxx.html#ac758895aa5c2bb2a384d76af7fc77b2c',1,'_swigt__p_unsigned_int():&#160;plplot_octaveOCTAVE_wrap.cxx'],['../plplotcmodulePYTHON__wrap_8c.html#ac758895aa5c2bb2a384d76af7fc77b2c',1,'_swigt__p_unsigned_int():&#160;plplotcmodulePYTHON_wrap.c']]],
+  ['_5fswigc_5f_5fp_5fchar',['_swigc__p_char',['../plplotluacLUA__wrap_8c.html#a8848127146fe0444e2fe3183a15b67f5',1,'_swigc__p_char():&#160;plplotluacLUA_wrap.c'],['../plplot__octaveOCTAVE__wrap_8cxx.html#a8848127146fe0444e2fe3183a15b67f5',1,'_swigc__p_char():&#160;plplot_octaveOCTAVE_wrap.cxx'],['../plplotcPYTHON__wrap_8c.html#a8848127146fe0444e2fe3183a15b67f5',1,'_swigc__p_char():&#160;plplotcPYTHON_wrap.c']]],
+  ['_5fswigc_5f_5fp_5fdouble',['_swigc__p_double',['../plplotluacLUA__wrap_8c.html#a28b7f0e03111f37524cf093e3a8a2304',1,'_swigc__p_double():&#160;plplotluacLUA_wrap.c'],['../plplot__octaveOCTAVE__wrap_8cxx.html#a28b7f0e03111f37524cf093e3a8a2304',1,'_swigc__p_double():&#160;plplot_octaveOCTAVE_wrap.cxx'],['../plplotcPYTHON__wrap_8c.html#a28b7f0e03111f37524cf093e3a8a2304',1,'_swigc__p_double():&#160;plplotcPYTHON_wrap.c']]],
+  ['_5fswigc_5f_5fp_5ff_5fdouble_5fdouble_5f_5fint',['_swigc__p_f_double_double__int',['../plplotluacLUA__wrap_8c.html#a207f66749bdba90b94fc94339a002520',1,'_swigc__p_f_double_double__int():&#160;plplotluacLUA_wrap.c'],['../plplotcPYTHON__wrap_8c.html#a207f66749bdba90b94fc94339a002520',1,'_swigc__p_f_double_double__int():&#160;plplotcPYTHON_wrap.c']]],
+  ['_5fswigc_5f_5fp_5ff_5fdouble_5fdouble_5fp_5fdouble_5fp_5fdouble_5fp_5fvoid_5f_5fvoid',['_swigc__p_f_double_double_p_double_p_double_p_void__void',['../plplotluacLUA__wrap_8c.html#a3f4c37068cdd295d0dafa913f043216e',1,'_swigc__p_f_double_double_p_double_p_double_p_void__void():&#160;plplotluacLUA_wrap.c'],['../plplot__octaveOCTAVE__wrap_8cxx.html#a3f4c37068cdd295d0dafa913f043216e',1,'_swigc__p_f_double_double_p_double_p_double_p_void__void():&#160;plplot_octaveOCTAVE_wrap.cxx'],['../plplotcPYTHON__wrap_8c.html#a3f4c37068cdd295d0dafa913f043216e',1,'_swigc__p_f_double_double_p_double_p_double_p_void__void():&#160;plplotcPYTHON_wrap.c']]],
+  ['_5fswigc_5f_5fp_5ff_5fint_5fdouble_5fp_5fchar_5fint_5fp_5fvoid_5f_5fvoid',['_swigc__p_f_int_double_p_char_int_p_void__void',['../plplotluacLUA__wrap_8c.html#abd7eee4930f48e2326a9df35e20f0bba',1,'_swigc__p_f_int_double_p_char_int_p_void__void():&#160;plplotluacLUA_wrap.c'],['../plplot__octaveOCTAVE__wrap_8cxx.html#abd7eee4930f48e2326a9df35e20f0bba',1,'_swigc__p_f_int_double_p_char_int_p_void__void():&#160;plplot_octaveOCTAVE_wrap.cxx'],['../plplotcPYTHON__wrap_8c.html#abd7eee4930f48e2326a9df35e20f0bba',1,'_swigc__p_f_int_double_p_char_int_p_void__void():&#160;plplotcPYTHON_wrap.c']]],
+  ['_5fswigc_5f_5fp_5ff_5fint_5fp_5fdouble_5fp_5fdouble_5f_5fvoid',['_swigc__p_f_int_p_double_p_double__void',['../plplotluacLUA__wrap_8c.html#a5c2379fb009e6c97a5de4731c20e4283',1,'_swigc__p_f_int_p_double_p_double__void():&#160;plplotluacLUA_wrap.c'],['../plplot__octaveOCTAVE__wrap_8cxx.html#a5c2379fb009e6c97a5de4731c20e4283',1,'_swigc__p_f_int_p_double_p_double__void():&#160;plplot_octaveOCTAVE_wrap.cxx'],['../plplotcPYTHON__wrap_8c.html#a5c2379fb009e6c97a5de4731c20e4283',1,'_swigc__p_f_int_p_double_p_double__void():&#160;plplotcPYTHON_wrap.c']]],
+  ['_5fswigc_5f_5fp_5ff_5fint_5fp_5fq_5fconst_5f_5fdouble_5fp_5fq_5fconst_5f_5fdouble_5f_5fvoid',['_swigc__p_f_int_p_q_const__double_p_q_const__double__void',['../plplotluacLUA__wrap_8c.html#af6625b2b7918b35eddbed9053fad7905',1,'_swigc__p_f_int_p_q_const__double_p_q_const__double__void():&#160;plplotluacLUA_wrap.c'],['../plplotcPYTHON__wrap_8c.html#af6625b2b7918b35eddbed9053fad7905',1,'_swigc__p_f_int_p_q_const__double_p_q_const__double__void():&#160;plplotcPYTHON_wrap.c']]],
+  ['_5fswigc_5f_5fp_5fint',['_swigc__p_int',['../plplotluacLUA__wrap_8c.html#a216d8b24b856092e2e65830ef290159b',1,'_swigc__p_int():&#160;plplotluacLUA_wrap.c'],['../plplot__octaveOCTAVE__wrap_8cxx.html#a216d8b24b856092e2e65830ef290159b',1,'_swigc__p_int():&#160;plplot_octaveOCTAVE_wrap.cxx'],['../plplotcPYTHON__wrap_8c.html#a216d8b24b856092e2e65830ef290159b',1,'_swigc__p_int():&#160;plplotcPYTHON_wrap.c']]],
+  ['_5fswigc_5f_5fp_5fp_5fchar',['_swigc__p_p_char',['../plplotluacLUA__wrap_8c.html#adf82b09513b48dd2275acc2fa74711b7',1,'_swigc__p_p_char():&#160;plplotluacLUA_wrap.c'],['../plplot__octaveOCTAVE__wrap_8cxx.html#adf82b09513b48dd2275acc2fa74711b7',1,'_swigc__p_p_char():&#160;plplot_octaveOCTAVE_wrap.cxx'],['../plplotcPYTHON__wrap_8c.html#adf82b09513b48dd2275acc2fa74711b7',1,'_swigc__p_p_char():&#160;plplotcPYTHON_wrap.c']]],
+  ['_5fswigc_5f_5fp_5fp_5fdouble',['_swigc__p_p_double',['../plplotluacLUA__wrap_8c.html#a8ef572e7214cb0eedcc6419377664472',1,'_swigc__p_p_double():&#160;plplotluacLUA_wrap.c'],['../plplotcPYTHON__wrap_8c.html#a8ef572e7214cb0eedcc6419377664472',1,'_swigc__p_p_double():&#160;plplotcPYTHON_wrap.c']]],
+  ['_5fswigc_5f_5fp_5fplcgrid',['_swigc__p_PLcGrid',['../plplotcPYTHON__wrap_8c.html#ab71600ff158f81ba0f2ad17add084b68',1,'plplotcPYTHON_wrap.c']]],
+  ['_5fswigc_5f_5fp_5fplcgrid2',['_swigc__p_PLcGrid2',['../plplotcPYTHON__wrap_8c.html#a15ad6cd2c38c0be50be771105a0e60a6',1,'plplotcPYTHON_wrap.c']]],
+  ['_5fswigc_5f_5fp_5fplgraphicsin',['_swigc__p_PLGraphicsIn',['../plplotluacLUA__wrap_8c.html#adbc9470f42e7e3c0a2adab2df09b950d',1,'_swigc__p_PLGraphicsIn():&#160;plplotluacLUA_wrap.c'],['../plplot__octaveOCTAVE__wrap_8cxx.html#adbc9470f42e7e3c0a2adab2df09b950d',1,'_swigc__p_PLGraphicsIn():&#160;plplot_octaveOCTAVE_wrap.cxx'],['../plplotcPYTHON__wrap_8c.html#adbc9470f42e7e3c0a2adab2df09b950d',1,'_swigc__p_PLGraphicsIn():&#160;plplotcPYTHON_wrap.c']]],
+  ['_5fswigc_5f_5fp_5funsigned_5fint',['_swigc__p_unsigned_int',['../plplotluacLUA__wrap_8c.html#aba9e61dc970ecfa60bf8a90276b1daa9',1,'_swigc__p_unsigned_int():&#160;plplotluacLUA_wrap.c'],['../plplot__octaveOCTAVE__wrap_8cxx.html#aba9e61dc970ecfa60bf8a90276b1daa9',1,'_swigc__p_unsigned_int():&#160;plplot_octaveOCTAVE_wrap.cxx'],['../plplotcPYTHON__wrap_8c.html#aba9e61dc970ecfa60bf8a90276b1daa9',1,'_swigc__p_unsigned_int():&#160;plplotcPYTHON_wrap.c']]],
+  ['_5fswigt_5f_5fp_5fchar',['_swigt__p_char',['../plplotluacLUA__wrap_8c.html#ae66f44191f70db7b9634a8321766c840',1,'_swigt__p_char():&#160;plplotluacLUA_wrap.c'],['../plplot__octaveOCTAVE__wrap_8cxx.html#ae66f44191f70db7b9634a8321766c840',1,'_swigt__p_char():&#160;plplot_octaveOCTAVE_wrap.cxx'],['../plplotcPYTHON__wrap_8c.html#ae66f44191f70db7b9634a8321766c840',1,'_swigt__p_char():&#160;plplotcPYTHON_wrap.c']]],
+  ['_5fswigt_5f_5fp_5fdouble',['_swigt__p_double',['../plplotluacLUA__wrap_8c.html#a650096f8d16b87549437da125768b407',1,'_swigt__p_double():&#160;plplotluacLUA_wrap.c'],['../plplot__octaveOCTAVE__wrap_8cxx.html#a650096f8d16b87549437da125768b407',1,'_swigt__p_double():&#160;plplot_octaveOCTAVE_wrap.cxx'],['../plplotcPYTHON__wrap_8c.html#a650096f8d16b87549437da125768b407',1,'_swigt__p_double():&#160;plplotcPYTHON_wrap.c']]],
+  ['_5fswigt_5f_5fp_5ff_5fdouble_5fdouble_5f_5fint',['_swigt__p_f_double_double__int',['../plplotluacLUA__wrap_8c.html#aa99dba7c5dc196a6edb638363e104be7',1,'_swigt__p_f_double_double__int():&#160;plplotluacLUA_wrap.c'],['../plplotcPYTHON__wrap_8c.html#aa99dba7c5dc196a6edb638363e104be7',1,'_swigt__p_f_double_double__int():&#160;plplotcPYTHON_wrap.c']]],
+  ['_5fswigt_5f_5fp_5ff_5fdouble_5fdouble_5fp_5fdouble_5fp_5fdouble_5fp_5fvoid_5f_5fvoid',['_swigt__p_f_double_double_p_double_p_double_p_void__void',['../plplotluacLUA__wrap_8c.html#a169d330528354eea0e80046288f7a240',1,'_swigt__p_f_double_double_p_double_p_double_p_void__void():&#160;plplotluacLUA_wrap.c'],['../plplot__octaveOCTAVE__wrap_8cxx.html#a169d330528354eea0e80046288f7a240',1,'_swigt__p_f_double_double_p_double_p_double_p_void__void():&#160;plplot_octaveOCTAVE_wrap.cxx'],['../plplotcPYTHON__wrap_8c.html#a169d330528354eea0e80046288f7a240',1,'_swigt__p_f_double_double_p_double_p_double_p_void__void():&#160;plplotcPYTHON_wrap.c']]],
+  ['_5fswigt_5f_5fp_5ff_5fint_5fdouble_5fp_5fchar_5fint_5fp_5fvoid_5f_5fvoid',['_swigt__p_f_int_double_p_char_int_p_void__void',['../plplotluacLUA__wrap_8c.html#ad192a829bb4110f62a13c396ab965321',1,'_swigt__p_f_int_double_p_char_int_p_void__void():&#160;plplotluacLUA_wrap.c'],['../plplot__octaveOCTAVE__wrap_8cxx.html#ad192a829bb4110f62a13c396ab965321',1,'_swigt__p_f_int_double_p_char_int_p_void__void():&#160;plplot_octaveOCTAVE_wrap.cxx'],['../plplotcPYTHON__wrap_8c.html#ad192a829bb4110f62a13c396ab965321',1,'_swigt__p_f_int_double_p_char_int_p_void__void():&#160;plplotcPYTHON_wrap.c']]],
+  ['_5fswigt_5f_5fp_5ff_5fint_5fp_5fdouble_5fp_5fdouble_5f_5fvoid',['_swigt__p_f_int_p_double_p_double__void',['../plplotluacLUA__wrap_8c.html#ac93b2bfcffa54c72401ce0fe924336ef',1,'_swigt__p_f_int_p_double_p_double__void():&#160;plplotluacLUA_wrap.c'],['../plplot__octaveOCTAVE__wrap_8cxx.html#ac93b2bfcffa54c72401ce0fe924336ef',1,'_swigt__p_f_int_p_double_p_double__void():&#160;plplot_octaveOCTAVE_wrap.cxx'],['../plplotcPYTHON__wrap_8c.html#ac93b2bfcffa54c72401ce0fe924336ef',1,'_swigt__p_f_int_p_double_p_double__void():&#160;plplotcPYTHON_wrap.c']]],
+  ['_5fswigt_5f_5fp_5ff_5fint_5fp_5fq_5fconst_5f_5fdouble_5fp_5fq_5fconst_5f_5fdouble_5f_5fvoid',['_swigt__p_f_int_p_q_const__double_p_q_const__double__void',['../plplotluacLUA__wrap_8c.html#a8a3b05af198a366e7d91148da9aa0695',1,'_swigt__p_f_int_p_q_const__double_p_q_const__double__void():&#160;plplotluacLUA_wrap.c'],['../plplotcPYTHON__wrap_8c.html#a8a3b05af198a366e7d91148da9aa0695',1,'_swigt__p_f_int_p_q_const__double_p_q_const__double__void():&#160;plplotcPYTHON_wrap.c']]],
+  ['_5fswigt_5f_5fp_5fint',['_swigt__p_int',['../plplotluacLUA__wrap_8c.html#abb18e7711ddb7deeaf40f89dd6643b2c',1,'_swigt__p_int():&#160;plplotluacLUA_wrap.c'],['../plplot__octaveOCTAVE__wrap_8cxx.html#abb18e7711ddb7deeaf40f89dd6643b2c',1,'_swigt__p_int():&#160;plplot_octaveOCTAVE_wrap.cxx'],['../plplotcPYTHON__wrap_8c.html#abb18e7711ddb7deeaf40f89dd6643b2c',1,'_swigt__p_int():&#160;plplotcPYTHON_wrap.c']]],
+  ['_5fswigt_5f_5fp_5fp_5fchar',['_swigt__p_p_char',['../plplotluacLUA__wrap_8c.html#a701773c68706ee07319dc186a10ec151',1,'_swigt__p_p_char():&#160;plplotluacLUA_wrap.c'],['../plplot__octaveOCTAVE__wrap_8cxx.html#a701773c68706ee07319dc186a10ec151',1,'_swigt__p_p_char():&#160;plplot_octaveOCTAVE_wrap.cxx'],['../plplotcPYTHON__wrap_8c.html#a701773c68706ee07319dc186a10ec151',1,'_swigt__p_p_char():&#160;plplotcPYTHON_wrap.c']]],
+  ['_5fswigt_5f_5fp_5fp_5fdouble',['_swigt__p_p_double',['../plplotluacLUA__wrap_8c.html#a7142a8246b533266bb0a1ec0e07d0516',1,'_swigt__p_p_double():&#160;plplotluacLUA_wrap.c'],['../plplotcPYTHON__wrap_8c.html#a7142a8246b533266bb0a1ec0e07d0516',1,'_swigt__p_p_double():&#160;plplotcPYTHON_wrap.c']]],
+  ['_5fswigt_5f_5fp_5fplcgrid',['_swigt__p_PLcGrid',['../plplotcPYTHON__wrap_8c.html#ac62d4edffb73674c8eb44ee0965094fc',1,'plplotcPYTHON_wrap.c']]],
+  ['_5fswigt_5f_5fp_5fplcgrid2',['_swigt__p_PLcGrid2',['../plplotcPYTHON__wrap_8c.html#aefc05597d3afa2cf5e60f169e7326c10',1,'plplotcPYTHON_wrap.c']]],
+  ['_5fswigt_5f_5fp_5fplgraphicsin',['_swigt__p_PLGraphicsIn',['../plplotluacLUA__wrap_8c.html#aa7423ef65fc1e3d9cc8e9acb90b31531',1,'_swigt__p_PLGraphicsIn():&#160;plplotluacLUA_wrap.c'],['../plplot__octaveOCTAVE__wrap_8cxx.html#aa7423ef65fc1e3d9cc8e9acb90b31531',1,'_swigt__p_PLGraphicsIn():&#160;plplot_octaveOCTAVE_wrap.cxx'],['../plplotcPYTHON__wrap_8c.html#aa7423ef65fc1e3d9cc8e9acb90b31531',1,'_swigt__p_PLGraphicsIn():&#160;plplotcPYTHON_wrap.c']]],
+  ['_5fswigt_5f_5fp_5funsigned_5fint',['_swigt__p_unsigned_int',['../plplotluacLUA__wrap_8c.html#ac758895aa5c2bb2a384d76af7fc77b2c',1,'_swigt__p_unsigned_int():&#160;plplotluacLUA_wrap.c'],['../plplot__octaveOCTAVE__wrap_8cxx.html#ac758895aa5c2bb2a384d76af7fc77b2c',1,'_swigt__p_unsigned_int():&#160;plplot_octaveOCTAVE_wrap.cxx'],['../plplotcPYTHON__wrap_8c.html#ac758895aa5c2bb2a384d76af7fc77b2c',1,'_swigt__p_unsigned_int():&#160;plplotcPYTHON_wrap.c']]],
   ['_5fwrap_5fclass_5fplgraphicsin',['_wrap_class_PLGraphicsIn',['../plplotluacLUA__wrap_8c.html#af535aeb8e20ec55a72edebec41daf497',1,'_wrap_class_PLGraphicsIn():&#160;plplotluacLUA_wrap.c'],['../plplot__octaveOCTAVE__wrap_8cxx.html#ab1150b7ebddb76d9e0884b3300ef4edd',1,'_wrap_class_PLGraphicsIn():&#160;plplot_octaveOCTAVE_wrap.cxx']]],
   ['_5fwrap_5fpl_5fsetcontlabelformat_5ftexinfo',['_wrap_pl_setcontlabelformat_texinfo',['../plplot__octaveOCTAVE__wrap_8cxx.html#a76edcc2158f8896af1584385985b7baa',1,'plplot_octaveOCTAVE_wrap.cxx']]],
   ['_5fwrap_5fpl_5fsetcontlabelparam_5ftexinfo',['_wrap_pl_setcontlabelparam_texinfo',['../plplot__octaveOCTAVE__wrap_8cxx.html#a7d69e72e6fa91ee737d5b6f20af8bc4a',1,'plplot_octaveOCTAVE_wrap.cxx']]],
