@@ -292,7 +292,6 @@ var searchData=
   ['plplot_5fccmap',['plplot_ccmap',['../plxwd_8h.html#a75b2632f0a1230d5173060415f8df303',1,'plxwd.h']]],
   ['plplot_5fnotes',['plplot_notes',['../plargs_8c.html#a2e4785f19ff0f8d5cce0494e8e607376',1,'plargs.c']]],
   ['plplot_5ftkwin_5fccmap',['plplot_tkwin_ccmap',['../pltkwd_8h.html#a75aa0f644a3eff27e35ecc0e82f2247e',1,'pltkwd.h']]],
-  ['plplot_5fwidget_5fmethods',['plplot_widget_methods',['../plplot__widgetmodule_8c.html#a91666925fff3e80ea47304f2bdd9b2b8',1,'plplot_widgetmodule.c']]],
   ['plplotlibdir',['plplotLibDir',['../plctrl_8c.html#a4ce541bc2941502478f734a5a4d0a060',1,'plplotLibDir():&#160;plctrl.c'],['../tclAPI_8c.html#aecc09632d4e39fd61019c56b064b2475',1,'plplotLibDir():&#160;plctrl.c']]],
   ['plplotqt_5fsmoke',['plplotqt_Smoke',['../plplotqt__smoke_8h.html#ac9e79be6efe920104bd37238781f3313',1,'plplotqt_smoke.h']]],
   ['plplotterptr',['plPlotterPtr',['../structPLStream.html#a9d81841ac0ad6a24645f9f04e115bf31',1,'PLStream']]],
@@ -363,9 +362,9 @@ var searchData=
   ['pltr0',['pltr0',['../namespaceplplotc.html#a1a3d30415da615635d94e4b2c3d96204',1,'plplotc.pltr0()'],['../namespaceplplotc__fixed.html#a21a5a4b79976f85993d3d2ed7059c546',1,'plplotc_fixed.pltr0()']]],
   ['pltr1',['pltr1',['../namespaceplplotc.html#a5ab0ac0ec378324110aa4e00e0f5aab4',1,'plplotc.pltr1()'],['../namespaceplplotc__fixed.html#a48541260090563bddbb9c4f8842620d0',1,'plplotc_fixed.pltr1()']]],
   ['pltr2',['pltr2',['../namespaceplplotc.html#ade02f9b8fdd455998a19d329c375efb5',1,'plplotc.pltr2()'],['../namespaceplplotc__fixed.html#aa729218d82b539d47475146724751a88',1,'plplotc_fixed.pltr2()']]],
-  ['pltr_5ftype',['pltr_type',['../plplotcmodulePYTHON__wrap_8c.html#ac1ba1957081dd47cfc51c81b349fb65a',1,'plplotcmodulePYTHON_wrap.c']]],
-  ['pltr_5fxg',['pltr_xg',['../plplotcmodulePYTHON__wrap_8c.html#abc329ab5d5455e741b49a7cfca82b74c',1,'plplotcmodulePYTHON_wrap.c']]],
-  ['pltr_5fyg',['pltr_yg',['../plplotcmodulePYTHON__wrap_8c.html#acab766c33a03fec035a91e4d28e150a2',1,'plplotcmodulePYTHON_wrap.c']]],
+  ['pltr_5ftype',['pltr_type',['../plplotcPYTHON__wrap_8c.html#ac1ba1957081dd47cfc51c81b349fb65a',1,'plplotcPYTHON_wrap.c']]],
+  ['pltr_5fxg',['pltr_xg',['../plplotcPYTHON__wrap_8c.html#abc329ab5d5455e741b49a7cfca82b74c',1,'plplotcPYTHON_wrap.c']]],
+  ['pltr_5fyg',['pltr_yg',['../plplotcPYTHON__wrap_8c.html#acab766c33a03fec035a91e4d28e150a2',1,'plplotcPYTHON_wrap.c']]],
   ['plunicode',['PLUNICODE',['../classplplot.html#ae6821277959dc78b2623efa4c6293b12',1,'plplot']]],
   ['plvasp',['plvasp',['../classplplot.html#a6d01a94c0ac3f7e1fa7e72eabad1179b',1,'plplot']]],
   ['plvpas',['plvpas',['../classplplot.html#acda6f8cf1dd36564c294fcc170b557d3',1,'plplot']]],
@@ -401,14 +400,14 @@ var searchData=
   ['ptype',['ptype',['../structswig__lua__const__info.html#a0557056988d98840029075f204d2bf59',1,'swig_lua_const_info::ptype()'],['../structswig__const__info.html#aedd46d173c5b5ed4ee60ad5660233557',1,'swig_const_info::ptype()']]],
   ['put',['put',['../structtclMatrix.html#a12ddbdf9fa8106de061fc66ca0be9d27',1,'tclMatrix']]],
   ['pvalue',['pvalue',['../structswig__lua__const__info.html#a54637f2603b1179d4996c06e82e3f23a',1,'swig_lua_const_info::pvalue()'],['../structswig__const__info.html#abbc43512c364bff11fac5961c1155090',1,'swig_const_info::pvalue()']]],
-  ['px',['pX',['../structplplot_1_1__N2.html#a4d588287a6595c7ba20977b449c2aa4e',1,'plplot::_N2::pX()'],['../structPLGraphicsIn.html#a65a7c2ad35465fdda2da1cdad78c6fed',1,'PLGraphicsIn::pX()'],['../structplplot__graphics_1_1plgraphicsin.html#ae4a00e0a17bb6592041308831dac1b3d',1,'plplot_graphics::plgraphicsin::px()']]],
+  ['px',['px',['../structplplot__graphics_1_1plgraphicsin.html#ae4a00e0a17bb6592041308831dac1b3d',1,'plplot_graphics::plgraphicsin::px()'],['../structplplot_1_1__N2.html#a4d588287a6595c7ba20977b449c2aa4e',1,'plplot::_N2::pX()'],['../structPLGraphicsIn.html#a65a7c2ad35465fdda2da1cdad78c6fed',1,'PLGraphicsIn::pX()']]],
   ['pxlx',['pxlx',['../structPLmDev.html#ae41ae47a21545c83ab0c3ace2fb46cfe',1,'PLmDev::pxlx()'],['../structPLDev.html#a357154f1b97fcc69c434ad9220dda746',1,'PLDev::pxlx()'],['../structPSDev.html#af0b2d28b35838694ff24f90af6d95213',1,'PSDev::pxlx()']]],
   ['pxly',['pxly',['../structPLmDev.html#afcaf79a40e6fce0c4234017d6411b098',1,'PLmDev::pxly()'],['../structPLDev.html#a3c3bffd26090366eb11df6537508e0fa',1,'PLDev::pxly()'],['../structPSDev.html#ac12a32c014bc6200acd8ddd50fa4f1f1',1,'PSDev::pxly()']]],
-  ['py',['py',['../structplplot__graphics_1_1plgraphicsin.html#ac68342e0093fe3100f4aea9e89578580',1,'plplot_graphics::plgraphicsin::py()'],['../structplplot_1_1__N2.html#a0815facf07c4811909f0bf3b0c87316a',1,'plplot::_N2::pY()'],['../structPLGraphicsIn.html#a21b1933fd85acc870381e8a8a176b259',1,'PLGraphicsIn::pY()']]],
-  ['python_5fct',['python_ct',['../plplotcmodulePYTHON__wrap_8c.html#accd45e261658e868dbba9789704cb8d5',1,'plplotcmodulePYTHON_wrap.c']]],
-  ['python_5ff2eval',['python_f2eval',['../plplotcmodulePYTHON__wrap_8c.html#a487895e00ae9be090c71512415fc35d6',1,'plplotcmodulePYTHON_wrap.c']]],
-  ['python_5flabel',['python_label',['../plplotcmodulePYTHON__wrap_8c.html#a728cbc7612574a50db094ae556e4b368',1,'plplotcmodulePYTHON_wrap.c']]],
-  ['python_5fmapform',['python_mapform',['../plplotcmodulePYTHON__wrap_8c.html#aa64bb28869b331ad013625fbad5cdf57',1,'plplotcmodulePYTHON_wrap.c']]],
-  ['python_5fpltr',['python_pltr',['../plplotcmodulePYTHON__wrap_8c.html#a9606f0b730c8f4c62e20c00e2dfde1c6',1,'plplotcmodulePYTHON_wrap.c']]],
+  ['py',['pY',['../structplplot_1_1__N2.html#a0815facf07c4811909f0bf3b0c87316a',1,'plplot::_N2::pY()'],['../structPLGraphicsIn.html#a21b1933fd85acc870381e8a8a176b259',1,'PLGraphicsIn::pY()'],['../structplplot__graphics_1_1plgraphicsin.html#ac68342e0093fe3100f4aea9e89578580',1,'plplot_graphics::plgraphicsin::py()']]],
+  ['python_5fct',['python_ct',['../plplotcPYTHON__wrap_8c.html#accd45e261658e868dbba9789704cb8d5',1,'plplotcPYTHON_wrap.c']]],
+  ['python_5ff2eval',['python_f2eval',['../plplotcPYTHON__wrap_8c.html#a487895e00ae9be090c71512415fc35d6',1,'plplotcPYTHON_wrap.c']]],
+  ['python_5flabel',['python_label',['../plplotcPYTHON__wrap_8c.html#a728cbc7612574a50db094ae556e4b368',1,'plplotcPYTHON_wrap.c']]],
+  ['python_5fmapform',['python_mapform',['../plplotcPYTHON__wrap_8c.html#aa64bb28869b331ad013625fbad5cdf57',1,'plplotcPYTHON_wrap.c']]],
+  ['python_5fpltr',['python_pltr',['../plplotcPYTHON__wrap_8c.html#a9606f0b730c8f4c62e20c00e2dfde1c6',1,'plplotcPYTHON_wrap.c']]],
   ['pytype',['pytype',['../structSwigPyClientData.html#a1f172e51bb27f670dacdf8247843b4c2',1,'SwigPyClientData']]]
 ];
