@@ -4,10 +4,12 @@ var structtclMatrix =
     [ "fdata", "structtclMatrix.html#a4f4d6a7288dc4f8972e0f708b5eac2ee", null ],
     [ "get", "structtclMatrix.html#a33d2abf4f0d6e86fcfdf32a333265b12", null ],
     [ "idata", "structtclMatrix.html#a0c600083f8e36b51593a7cc12b06b313", null ],
+    [ "indices", "structtclMatrix.html#aa63afe78c8cb1a9bd3a0e00a19064983", null ],
     [ "interp", "structtclMatrix.html#a936710d703ada601feb9c729bac48b79", null ],
     [ "len", "structtclMatrix.html#afdcff3698b42f36cd218fff46d8cd060", null ],
     [ "n", "structtclMatrix.html#a216f6d867e625e1ec9164d979df574e4", null ],
     [ "name", "structtclMatrix.html#a23d513f4af30315f54d281b5a39042d9", null ],
+    [ "nindices", "structtclMatrix.html#a4b4d457630f50125c9ab3b8ca536d7a7", null ],
     [ "put", "structtclMatrix.html#a12ddbdf9fa8106de061fc66ca0be9d27", null ],
     [ "tracing", "structtclMatrix.html#adf4b8505958549c7a93ed953eac5232d", null ],
     [ "type", "structtclMatrix.html#a38cf2a4a8e722bf59db7e0e6f40a29b7", null ]
