@@ -217,6 +217,7 @@ void plD_bop_pdfqt( PLStream * );
 void plD_dispatch_init_qtwidget( PLDispatchTable *pdt );
 void plD_init_qtwidget( PLStream * );
 void plD_eop_qtwidget( PLStream * );
+void plD_wait_qtwidget( PLStream * );
 void plD_line_qtwidget( PLStream *, short, short, short, short );
 void plD_polyline_qtwidget( PLStream *, short*, short*, PLINT );
 void plD_tidy_qtwidget( PLStream * );
@@ -450,7 +451,7 @@ void plD_state_rasterqt( PLStream * pls, PLINT op )
     switch ( op )
     {
     case PLSTATE_WIDTH:
-        widget->setWidth( pls->width );
+        widget->setWidthF( pls->width );
         break;
 
     case PLSTATE_COLOR0:
@@ -755,6 +756,10 @@ void plD_eop_svgqt( PLStream *pls )
     double downscale;
     QSize  s;
 
+    if ( qt_family_check( pls ) )
+    {
+        return;
+    }
     ( (QtSVGDevice *) pls->dev )->savePlot();
     // Once saved, we have to create a new device with the same properties
     // to be able to plot another page.
@@ -889,7 +894,7 @@ void plD_state_svgqt( PLStream * pls, PLINT op )
     switch ( op )
     {
     case PLSTATE_WIDTH:
-        widget->setWidth( pls->width );
+        widget->setWidthF( pls->width );
         break;
 
     case PLSTATE_COLOR0:
@@ -1041,8 +1046,6 @@ void plD_eop_epspdfqt( PLStream *pls )
 {
     double downscale;
 
-    int    argc   = 0;
-    char   argv[] = { '\0' };
     if ( qt_family_check( pls ) )
     {
         return;
@@ -1184,7 +1187,7 @@ void plD_state_epspdfqt( PLStream * pls, PLINT op )
     switch ( op )
     {
     case PLSTATE_WIDTH:
-        widget->setWidth( pls->width );
+        widget->setWidthF( pls->width );
         break;
 
     case PLSTATE_COLOR0:
@@ -1247,6 +1250,7 @@ void plD_dispatch_init_qtwidget( PLDispatchTable *pdt )
     pdt->pl_tidy     = (plD_tidy_fp) plD_tidy_qtwidget;
     pdt->pl_state    = (plD_state_fp) plD_state_qtwidget;
     pdt->pl_esc      = (plD_esc_fp) plD_esc_qtwidget;
+    pdt->pl_wait     = (plD_wait_fp) plD_wait_qtwidget;
 }
 
 void plD_init_qtwidget( PLStream * pls )
@@ -1318,11 +1322,19 @@ void plD_init_qtwidget( PLStream * pls )
 
 void plD_eop_qtwidget( PLStream *pls )
 {
-    QtPLWidget* widget    = ( (QtPLWidget *) pls->dev );
-    int       currentPage = widget->pageNumber;
+    QtPLWidget* widget = ( (QtPLWidget *) pls->dev );
+
     widget->flush();
     widget->raise();
-    while ( currentPage == widget->pageNumber && handler.isMasterDevice( widget ) && !pls->nopause )
+}
+
+void plD_wait_qtwidget( PLStream *pls )
+{
+    QtPLWidget* widget    = ( (QtPLWidget *) pls->dev );
+    int       currentPage = widget->pageNumber;
+
+    widget->raise();
+    while ( currentPage == widget->pageNumber && handler.isMasterDevice( widget ) )
     {
         qApp->processEvents( QEventLoop::WaitForMoreEvents );
     }
@@ -1444,7 +1456,7 @@ void plD_state_qtwidget( PLStream * pls, PLINT op )
     switch ( op )
     {
     case PLSTATE_WIDTH:
-        widget->setWidth( pls->width );
+        widget->setWidthF( pls->width );
         break;
 
     case PLSTATE_COLOR0:
@@ -1646,7 +1658,7 @@ void plD_state_extqt( PLStream * pls, PLINT op )
     switch ( op )
     {
     case PLSTATE_WIDTH:
-        widget->setWidth( pls->width );
+        widget->setWidthF( pls->width );
         break;
 
     case PLSTATE_COLOR0:
@@ -1677,7 +1689,7 @@ void plD_tidy_extqt( PLStream * pls )
     closeQtApp();
 }
 
-void plD_eop_extqt( PLStream *pls )
+void plD_eop_extqt( PLStream * /* pls */ )
 {
 }
 
@@ -1802,7 +1814,7 @@ void plD_init_memqt( PLStream * pls )
     pls->family = true;
 }
 
-void plD_bop_memqt( PLStream *pls )
+void plD_bop_memqt( PLStream * /* pls */ )
 {
     // Do nothing to preserve user data
 }
