@@ -64,7 +64,7 @@ void Log_Verbose( const char *fmt, ... )
     va_end( args );
     fflush( stderr );
 #else
-    (void) fmt;        // Cast to void to silence compiler warnings about unused paraemeter
+    (void) fmt;        // Cast to void to silence compiler warnings about unused parameter
 #endif
 }
 
@@ -85,7 +85,7 @@ void Log_Debug( const char *fmt, ... )
     va_end( args );
     fflush( stderr );
 #else
-    (void) fmt;        // Cast to void to silence compiler warnings about unused paraemeter
+    (void) fmt;        // Cast to void to silence compiler warnings about unused parameter
 #endif
 }
 
@@ -132,6 +132,7 @@ void plD_dispatch_init_wxwidgets( PLDispatchTable *pdt )
     pdt->pl_line     = (plD_line_fp) plD_line_wxwidgets;
     pdt->pl_polyline = (plD_polyline_fp) plD_polyline_wxwidgets;
     pdt->pl_eop      = (plD_eop_fp) plD_eop_wxwidgets;
+    pdt->pl_wait     = (plD_wait_fp) plD_wait_wxwidgets;
     pdt->pl_bop      = (plD_bop_fp) plD_bop_wxwidgets;
     pdt->pl_tidy     = (plD_tidy_fp) plD_tidy_wxwidgets;
     pdt->pl_state    = (plD_state_fp) plD_state_wxwidgets;
@@ -154,7 +155,7 @@ void plD_init_wxwidgets( PLStream* pls )
             throw( "plD_init_wxwidgets called when a initialization has already occurred." );
 
         //initialise wxWidgets - this is required in order to allow some wxWidgets functions to
-        //be called frm within the driver when the user isn't passing a wxDC in. See e.g
+        //be called from within the driver when the user isn't passing a wxDC in. See e.g
         //http://stackoverflow.com/questions/208373
         if ( !wxTheApp )
         {
@@ -198,9 +199,10 @@ void plD_init_wxwidgets( PLStream* pls )
         }
         pls->has_string_length = 1;
     }
-    catch ( char *message )
+    catch ( const char *message )
     {
         plabort( message );
+        plabort( "error in plD_init_wxwidgets." );
         pls->dev = NULL;
     }
     catch ( ... )
@@ -285,9 +287,10 @@ void plD_line_wxwidgets( PLStream *pls, short x1a, short y1a, short x2a, short y
             throw( "plD_line_wxwidgets called before initialization." );
         device->DrawLine( x1a, y1a, x2a, y2a );
     }
-    catch ( char* message )
+    catch ( const char* message )
     {
         plabort( message );
+        plabort( "error in plD_line_wxwidgets." );
     }
     catch ( ... )
     {
@@ -312,9 +315,10 @@ void plD_polyline_wxwidgets( PLStream *pls, short *xa, short *ya, PLINT npts )
             throw( "plD_polyline_wxwidgets called before initialization." );
         device->DrawPolyline( xa, ya, npts );
     }
-    catch ( char* message )
+    catch ( const char* message )
     {
         plabort( message );
+        plabort( "error in plD_polyline_wxwidgets." );
     }
     catch ( ... )
     {
@@ -339,11 +343,13 @@ void plD_eop_wxwidgets( PLStream *pls )
         wxPLDevice *device = (wxPLDevice *) pls->dev;
         if ( !device )
             throw( "plD_eop_wxwidgets called before initialization." );
-        device->EndPage( pls );
+        if ( pls->nopause )
+            device->EndPage( pls );
     }
-    catch ( char* message )
+    catch ( const char* message )
     {
         plabort( message );
+        plabort( "error in plD_eop_wxwidgets." );
     }
     catch ( ... )
     {
@@ -352,6 +358,34 @@ void plD_eop_wxwidgets( PLStream *pls )
 }
 
 
+//--------------------------------------------------------------------------
+//  void plD_wait_wxwidgets( PLStream *pls )
+//
+//  Wait for user input. This command is ignored if we have the plot embedded in a
+//  wxWidgets application, otherwise the application created by the device
+//  takes over.
+//--------------------------------------------------------------------------
+void plD_wait_wxwidgets( PLStream *pls )
+{
+    // PLPLOT_wxLogDebug( "plD_wait_wxwidgets()" );
+    try
+    {
+        wxPLDevice *device = (wxPLDevice *) pls->dev;
+        if ( !device )
+            throw( "plD_wait_wxwidgets called before initialization." );
+        device->EndPage( pls );
+    }
+    catch ( const char* message )
+    {
+        plabort( message );
+        plabort( "error in plD_wait_wxwidgets." );
+    }
+    catch ( ... )
+    {
+        plabort( "unknown error in plD_wait_wxwidgets." );
+    }
+}
+
 //--------------------------------------------------------------------------
 //  void plD_bop_wxwidgets( PLStream *pls )
 //
@@ -371,9 +405,10 @@ void plD_bop_wxwidgets( PLStream *pls )
             throw( "plD_bop_wxwidgets called before initialization." );
         device->BeginPage( pls );
     }
-    catch ( char* message )
+    catch ( const char* message )
     {
         plabort( message );
+        plabort( "error in plD_bop_wxwidgets." );
     }
     catch ( ... )
     {
@@ -381,7 +416,6 @@ void plD_bop_wxwidgets( PLStream *pls )
     }
 }
 
-
 //--------------------------------------------------------------------------
 //  void plD_tidy_wxwidgets( PLStream *pls )
 //
@@ -400,13 +434,14 @@ void plD_tidy_wxwidgets( PLStream *pls )
             device->PreDestructorTidy( pls );
             delete device;
         }
-        pls->dev = NULL;         //so it doesn't get freed elswhere
+        pls->dev = NULL;         //so it doesn't get freed elsewhere
         if ( g_weInitializedWx )
             wxEntryCleanup();
     }
-    catch ( char* message )
+    catch ( const char* message )
     {
         plabort( message );
+        plabort( "error in plD_tidy_wxwidgets." );
     }
     catch ( ... )
     {
@@ -414,7 +449,6 @@ void plD_tidy_wxwidgets( PLStream *pls )
     }
 }
 
-
 //--------------------------------------------------------------------------
 //  void plD_state_wxwidgets( PLStream *pls, PLINT op )
 //
@@ -428,7 +462,7 @@ void plD_state_wxwidgets( PLStream *pls, PLINT op )
     {
         wxPLDevice *device = (wxPLDevice *) pls->dev;
         if ( !device )
-            return;             //we can call state functions befor initialization so just return
+            return;             //we can call state functions before initialization so just return
         switch ( op )
         {
         case PLSTATE_WIDTH:         // 1
@@ -444,9 +478,10 @@ void plD_state_wxwidgets( PLStream *pls, PLINT op )
             break;
         }
     }
-    catch ( char* message )
+    catch ( const char* message )
     {
         plabort( message );
+        plabort( "error in plD_state_wxwidgets." );
     }
     catch ( ... )
     {
@@ -454,13 +489,12 @@ void plD_state_wxwidgets( PLStream *pls, PLINT op )
     }
 }
 
-
 //--------------------------------------------------------------------------
 //  void plD_esc_wxwidgets( PLStream *pls, PLINT op, void *ptr )
 //
 //  Handler for several escape codes. Here we take care of filled polygons,
 //  XOR or copy mode, initialize device (install dc from outside), and if
-//  there is freetype support, rerendering of text.
+//  there is freetype support, re-rendering of text.
 //--------------------------------------------------------------------------
 void plD_esc_wxwidgets( PLStream *pls, PLINT op, void *ptr )
 {
@@ -526,9 +560,10 @@ void plD_esc_wxwidgets( PLStream *pls, PLINT op, void *ptr )
             break;
         }
     }
-    catch ( char* message )
+    catch ( const char* message )
     {
         plabort( message );
+        plabort( "error in plD_tidy_wxwidgets." );
     }
     catch ( ... )
     {
