@@ -1,8 +1,4 @@
 //--------------------------------------------------------------------------
-// $Id: x15.cc 12372 2013-06-06 21:44:33Z andrewross $
-//--------------------------------------------------------------------------
-//
-//--------------------------------------------------------------------------
 // Copyright (C) 2004  Andrew Ross
 // Copyright (C) 2004  Alan W. Irwin
 //
@@ -34,7 +30,7 @@ using namespace std;
 
 class x15 {
 public:
-    x15( int, const char ** );
+    x15( int, char ** );
     void plot1( PLFLT * *, PLFLT, PLFLT );
     void plot2( PLFLT * *, PLFLT, PLFLT );
     void plot3();
@@ -51,7 +47,7 @@ const int x15::  XPTS = 35;
 const int x15::  YPTS = 46;
 
 
-x15::x15( int argc, const char ** argv )
+x15::x15( int argc, char ** argv )
 {
     int   i, j;
 
@@ -131,7 +127,7 @@ void x15::plot1( PLFLT **z, PLFLT zmin, PLFLT zmax )
         shade_min, shade_max,
         sh_cmap, sh_color, sh_width,
         min_color, min_width, max_color, max_width,
-        plstream::fill, true, NULL, NULL );
+        plcallback::fill, true, NULL, NULL );
 
     pls->col0( 1 );
     pls->box( "bcnst", 0.0, 0, "bcnstv", 0.0, 0 );
@@ -177,7 +173,7 @@ void x15::plot2( PLFLT **z, PLFLT zmin, PLFLT zmax )
             shade_min, shade_max,
             sh_cmap, sh_color, sh_width,
             min_color, min_width, max_color, max_width,
-            plstream::fill, true, NULL, NULL );
+            plcallback::fill, true, NULL, NULL );
     }
 
     pls->col0( 1 );
@@ -220,7 +216,7 @@ void x15::plot3()
 }
 
 
-int main( int argc, const char ** argv )
+int main( int argc, char ** argv )
 {
     x15 *x = new x15( argc, argv );
 
