@@ -1,7 +1,4 @@
-(* -*- coding: utf-8; -*-
-
-   $Id: x26.ml 12313 2013-05-01 01:12:18Z hezekiahcarty $
-
+(*
    Multi-lingual version of the first page of example 4.
 
    Copyright (C) 2006 Alan Irwin
@@ -39,23 +36,23 @@
   required glyphs.
 
   Translation instructions: The strings to be translated are given by
-  x_label, y_label, alty_label, title_label, and line_label below.  The 
+  x_label, y_label, alty_label, title_label, and line_label below.  The
   encoding used must be UTF-8.
 
-  The following strings to be translated involve some scientific/mathematical 
+  The following strings to be translated involve some scientific/mathematical
   jargon which is now discussed further to help translators.
 
   (1) dB is a decibel unit, see http://en.wikipedia.org/wiki/Decibel .
-  (2) degrees is an angular measure, see 
+  (2) degrees is an angular measure, see
       http://en.wikipedia.org/wiki/Degree_(angle) .
   (3) low-pass filter is one that transmits (passes) low frequencies.
   (4) pole is in the mathematical sense, see
       http://en.wikipedia.org/wiki/Pole_(complex_analysis) .  "Single Pole"
       means a particular mathematical transformation of the filter function has
       a single pole, see
-      http://ccrma.stanford.edu/~jos/filters/Pole_Zero_Analysis_I.html .  
-      Furthermore, a single-pole filter must have an inverse square decline 
-      (or -20 db/decade). Since the filter plotted here does have that 
+      http://ccrma.stanford.edu/~jos/filters/Pole_Zero_Analysis_I.html .
+      Furthermore, a single-pole filter must have an inverse square decline
+      (or -20 db/decade). Since the filter plotted here does have that
       characteristic, it must by definition be a single-pole filter, see also
       http://www-k.ext.ti.com/SRVS/Data/ti/KnowledgeBases/analog/document/faqs/1p.htm
   (5) decade represents a factor of 10, see
@@ -158,7 +155,7 @@ let plot1 label_type x_label y_label alty_label legend_text title_label line_lab
     plbox "" 0.0 0 "cmstv" 30.0 3;
     plcol0 3;
     plline freql phase;
-    plstring freql phase "*";
+    plstring freql phase "#(728)";
     plcol0 3;
     plmtex "r" 5.0 0.5 0.5 alty_label;
   );
@@ -177,7 +174,7 @@ let plot1 label_type x_label y_label alty_label legend_text title_label line_lab
   let symbol_colors = [| 0; 3 |] in
   let symbol_scales = [| 0.0; 1.0 |] in
   let symbol_numbers = [| 0; 4 |] in
-  let symbols = [| ""; "*" |] in
+  let symbols = [| ""; "#(728)" |] in
   (* from the above opt_arrays we can completely ignore everything
      to do with boxes *)
 
