@@ -1,11 +1,11 @@
 ## Copyright (C) 1998, 1999, 2000  Joao Cardoso
 ## Copyright (C) 2004  Rafael Laboissiere
-## 
+##
 ## This program is free software; you can redistribute it and/or modify it
 ## under the terms of the GNU General Public License as published by the
 ## Free Software Foundation; either version 2 of the License, or (at your
 ## option) any later version.
-## 
+##
 ## This program is distributed in the hope that it will be useful, but
 ## WITHOUT ANY WARRANTY; without even the implied warranty of
 ## MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
@@ -20,7 +20,7 @@
 ## Plots several simple functions from other example programs.
 #
 ## This version sends the output of the first 4 plots (one page) to two
-## independent streams.  
+## independent streams.
 
 1;
 
@@ -30,10 +30,6 @@ function ix14c(fname2,strm)
     strm = stdout;
   endif
 
-  if (!exist("plinit"))
-    plplot_stub
-  endif
-
   xleng0 = 400; yleng0 = 300; xoff0 = 200; yoff0 = 200;
   xleng1 = 400; yleng1 = 300; xoff1 = 500; yoff1 = 500;
 
@@ -61,8 +57,8 @@ function ix14c(fname2,strm)
   ##fprintf(strm,"or the enter key in the first (left) window\n");
   fprintf(strm,"\n");
 
-  ## This is an entirely bogus message since the output file name is 
-  ## set by the function arguments - but it does ensure that stdout 
+  ## This is an entirely bogus message since the output file name is
+  ## set by the function arguments - but it does ensure that stdout
   ## is identical to the C version of the example for ctest.
   if (strm != stdout)
     fprintf(strm,"Enter graphics output file name: ");
@@ -154,7 +150,7 @@ function ix14c(fname2,strm)
   ## close master
   plsstrm(0);
   plend1();
-  
+
 endfunction
 
 function plot1(xoff,xscale,yoff,yscale)
@@ -179,22 +175,22 @@ function plot1(xoff,xscale,yoff,yscale)
   ## scaled separately (just = 0), and we just draw a labelled */
   ## box (axis = 0). */
 
-  plcol(1);
+  plcol0(1);
   plenv(xmin, xmax, ymin, ymax, 0, 0);
-  plcol(6);
+  plcol0(6);
   pllab("(x)", "(y)", "#frPLplot Example 1 - y=x#u2");
 
   ## Plot the data points */
 
-  plcol(9);
+  plcol0(9);
   plpoin(xs', ys', 9);
 
   ## Draw the line through the data */
 
-  plcol(4);
+  plcol0(4);
   plline(x', y');
   plflush;#pleop();
-  
+
 endfunction
 
 function plot2()
@@ -203,9 +199,9 @@ function plot2()
   ##       10.0, and the range in Y is -0.4 to 2.0. The axes are scaled separately
   ##       (just = 0), and we draw a box with axes (axis = 1).
 
-  plcol(1);
+  plcol0(1);
   plenv(-2.0, 10.0, -0.4, 1.2, 0, 1);
-  plcol(2);
+  plcol0(2);
   pllab("(x)", "sin(x)/x", "#frPLplot Example 1 - Sinc Function");
 
   ## Fill up the arrays */
@@ -220,7 +216,7 @@ function plot2()
 
   ## Draw the line */
 
-  plcol(3);
+  plcol0(3);
   plline(x', y');
   plflush;#pleop();
 endfunction
@@ -241,26 +237,26 @@ function plot3()
 
   ## Draw a box with ticks spaced 60 degrees apart in X, and 0.2 in Y. */
 
-  plcol(1);
+  plcol0(1);
   plbox("bcnst", 60.0, 2, "bcnstv", 0.2, 2);
 
   ## Superimpose a dashed line grid, with 1.5 mm marks and spaces. plstyl
   ##       expects a pointer!! */
 
   plstyl(mark1, space1);
-  plcol(2);
+  plcol0(2);
   plbox("g", 30.0, 0, "g", 0.2, 0);
   plstyl(mark0, space0);
 
-  plcol(3);
+  plcol0(3);
   pllab("Angle (degrees)", "sine", "#frPLplot Example 1 - Sine function");
 
   for i = 0:100
     x(i+1) = 3.6 * i;
-    y(i+1) = sin(x(i+1) * 3.141592654 / 180.0);
+    y(i+1) = sin(x(i+1) * pi / 180.0);
   endfor
 
-  plcol(4);
+  plcol0(4);
   plline(x', y');
   plflush;#pleop();
 
@@ -278,7 +274,7 @@ function plot4()
   ## Set up viewport and window, but do not draw box */
 
   plenv(-1.3, 1.3, -1.3, 1.3, 1, -2);
-  
+
   for i = 1:10
     x = 0.1 * i * x0;
     y = 0.1 * i * y0;
@@ -287,8 +283,8 @@ function plot4()
 
     plline(x, y);
   endfor
-  
-  plcol(2);
+
+  plcol0(2);
   for i = 0:11
     theta = 30.0 * i;
     dx = cos(dtr * theta);
@@ -313,11 +309,11 @@ function plot4()
   r = sin(dtr * (5 * zz'));
   x = x0 .* r;
   y = y0 .* r;
-  
-  plcol(3);
+
+  plcol0(3);
   plline(x, y);
 
-  plcol(4);
+  plcol0(4);
   plmtex("t", 2.0, 0.5, 0.5,
 	 "#frPLplot Example 3 - r(#gh)=sin 5#gh");
   plflush;#pleop();
@@ -335,7 +331,7 @@ function plot5()
   tr=[XSPA, 0.0, -1.0, 0.0, YSPA, -1.0]';
 
   ## this is builtin in plplot_octave
-  ## It is based on the corresponding demo function of PLplot.## 
+  ## It is based on the corresponding demo function of PLplot.##
   ## mypltr(PLFLT x, PLFLT y, PLFLT *tx, PLFLT *ty, void *pltr_data)
   ## {
   ##    *tx = tr(0) * x + tr(1) * y + tr(2);
@@ -358,12 +354,12 @@ function plot5()
   endfor
 
   plenv(-1.0, 1.0, -1.0, 1.0, 0, 0);
-  plcol(2);
-  plcont(z, 1, XPTS, 1, YPTS, clevel, tr, 0);
+  plcol0(2);
+  plcont(z, 1, XPTS, 1, YPTS, clevel, tr);
   plstyl(mark, space);
-  plcol(3);
-  plcont(w, 1, XPTS, 1, YPTS, clevel, tr, 0);
-  plcol(1);
+  plcol0(3);
+  plcont(w, 1, XPTS, 1, YPTS, clevel, tr);
+  plcol0(1);
   pllab("X Coordinate", "Y Coordinate", "Streamlines of flow");
   plflush;#pleop();
 endfunction
