@@ -9,7 +9,7 @@
 # This file is part of PLplot.
 #
 # PLplot is free software; you can redistribute it and/or modify
-# it under the terms of the GNU General Library Public License as published
+# it under the terms of the GNU Library General Public License as published
 # by the Free Software Foundation; either version 2 of the License, or
 # (at your option) any later version.
 #
@@ -111,15 +111,15 @@ EOT
       if $f_name;
   }
 
-  # read Lena image
+  # read Chloe image
 
-  my $lena = "lena.pgm";
-  my ($img_f, $width, $height, $num_col) = read_img ($lena);
+  my $Chloe = "Chloe.pgm";
+  my ($img_f, $width, $height, $num_col) = read_img ($Chloe);
   if ($width == 0 && $height == 0) {
-    my $lena = "../lena.pgm";
-    ($img_f, $width, $height, $num_col) = read_img ($lena);
+    my $Chloe = "../Chloe.pgm";
+    ($img_f, $width, $height, $num_col) = read_img ($Chloe);
     if ($width == 0 && $height == 0) {
-      die "Cannot find image file $lena";
+      die "Cannot find image file $Chloe";
     }
   }
 
@@ -127,23 +127,23 @@ EOT
 
   gray_cmap ($num_col);
 
-  # display Lena
+  # display Chloe
 
   plenv (1, $width, 1, $height, 1, -1);
 
   pllab (((not $nointeractive)
           ? "Set and drag Button 1 to (re)set selection, Button 2 to finish."
-          : ""), " ", "Lena...");
+          : ""), " ", "Chloe...");
 
   plimage ($img_f, 1, $width, 1, $height, 0, 0, 1, $width, 1, $height);
 
   # selection/expansion demo
 
   if (not $nointeractive) {
-    $xi = 200;
-    $xe = 330;
-    $yi = 280;
-    $ye = 220;
+    $xi = 25;
+    $xe = 130;
+    $yi = 235;
+    $ye = 125;
 
     if (get_clip (\$xi, \$xe, \$yi, \$ye)) { # get selection rectangle
       plend ();
@@ -171,7 +171,7 @@ EOT
   plcol0(2);
   plenv(0, $width, 0, $height, 1, -1);
   pllab("", "", "Reduced dynamic range image example");
-  plimagefr($img_f, 0, $width, 0, $height, 0, 0, 
+  plimagefr($img_f, 0, $width, 0, $height, 0, 0,
 	    $img_min + $img_max * 0.25, $img_max - $img_max * 0.25, 0, 0);
 
   # Draw a distorted version of the original image, showing its full dynamic range.
@@ -226,7 +226,7 @@ sub read_img {
   my $fname = shift;
   if (-r $fname) {
     my $img = rpnm ($fname);
-    # We want the number of colours from the header, not the maximum 
+    # We want the number of colours from the header, not the maximum
     # colour. We can't get this via PDL, so hard code it to 255.
     #return ($img, $img->dims (), $img->max);
     return ($img, $img->dims (), 255);
@@ -307,18 +307,18 @@ sub get_clip {
 	$xxi = $xxe;
 	$xxe = $t;
     }
-    
+
     if ($yyi < $yye) {
 	my $t = $yyi;
 	$yyi = $yye;
 	$yye = $t;
     }
-    
+
     $$xe = $xxe;
     $$xi = $xxi;
     $$ye = $yye;
     $$yi = $yyi;
-    
+
     return ($gin{keysym} eq 'Q');
   }
 
