@@ -1,8 +1,6 @@
-# $Id: x33.tcl 12683 2013-11-12 10:16:40Z airwin $
-#
 # Demonstrate most pllegend capability including unicode symbols.
 #
-# Copyright (C) 2010 Alan Irwin
+# Copyright (C) 2010-2014 Alan Irwin
 #
 # This file is part of PLplot.
 #
@@ -166,7 +164,7 @@ proc x33 {{w loopback}} {
     set line_widths    [list 1.]
     set symbol_scales  [list 1.]
     set symbol_numbers [list 4]
-    set symbols        [list "*"]
+    set symbols        [list "#(728)"]
 
     # Use monotype fonts so that all legends are the same size.
     $w cmd plsfont [expr {$::PLPLOT::PL_FCI_MONO}] -1 -1
@@ -220,7 +218,7 @@ proc x33 {{w loopback}} {
         lappend line_widths    1.
         lappend symbol_scales  1.
         lappend symbol_numbers 2
-        lappend symbols        "*"
+        lappend symbols        "#(728)"
         lappend text           [format "%2.2d" $k]
         lappend text_colors    [expr {1 +  $k % 8}]
         lappend line_colors    [expr {1 +  $k % 8}]
@@ -369,7 +367,7 @@ proc x33 {{w loopback}} {
             lappend line_widths    1.
             lappend symbol_scales  1.
             lappend symbol_numbers 2
-            lappend symbols        "*"
+            lappend symbols        "#(728)"
             lappend text           [format "%2.2d" $k]
             lappend text_colors    [expr {1 + $k % 8}]
             lappend line_colors    [expr {1 + $k % 8}]
@@ -833,11 +831,11 @@ proc x33 {{w loopback}} {
         matrix values_small  f 2
         matrix values_uneven f 9
         matrix values_even   f 9
-        foreach i {0 1} v {-1.0e-200 1.0e-200 } {
+        foreach i {0 1} v {-1.0e-20 1.0e-20 } {
             values_small $i = $v
         }
-        foreach i {0 1 2 3 4 5 6 7 8} vu {-1.0e-200 2.0e-200 2.6e-200 3.4e-200 6.0e-200 7.0e-200 8.0e-200 9.0e-200 10.0e-200 } \
-                                      ve {-2.0e-200 -1.0e-200 0.0e-200 1.0e-200 2.0e-200 3.0e-200 4.0e-200 5.0e-200 6.0e-200 } {
+        foreach i {0 1 2 3 4 5 6 7 8} vu {-1.0e-20 2.0e-20 2.6e-20 3.4e-20 6.0e-20 7.0e-20 8.0e-20 9.0e-20 10.0e-20 } \
+                                      ve {-2.0e-20 -1.0e-20 0.0e-20 1.0e-20 2.0e-20 3.0e-20 4.0e-20 5.0e-20 6.0e-20 } {
             values_uneven $i = $vu
             values_even $i = $ve
         }
