@@ -242,6 +242,9 @@ static PLDispatchInit  static_device_initializers[] = {
 #endif
 #if defined ( PLD_xwin ) && !defined ( ENABLE_DYNDRIVERS )
     plD_dispatch_init_xw,
+#endif
+#if defined ( PLD_wingdi ) && !defined ( ENABLE_DYNDRIVERS )
+    plD_dispatch_init_wingdi,
 #endif
     NULL
 };
