@@ -11,6 +11,7 @@
 //  Copyright (C) 2004  Andrew Roach
 //  Copyright (C) 2006  Andrew Ross
 //  Copyright (C) 2006  Hazen Babcock
+//  Copyright (C) 2001-2015  Alan W. Irwin
 //
 //
 //  This file is part of PLplot.
@@ -229,8 +230,8 @@ extern PLDLLIMPEXP_DATA( PLStream * ) plsc;
 #else // !PL_HAVE_SNPRINTF
 // declare dummy functions which just call the unsafe
 // functions ignoring the size of the string
-int plsnprintf( char *buffer, int n, const char *format, ... );
-int plsnscanf( const char *buffer, int n, const char *format, ... );
+int plsnprintf( char *buffer, int n, PLCHAR_VECTOR format, ... );
+int plsnscanf( PLCHAR_VECTOR buffer, int n, PLCHAR_VECTOR format, ... );
   #define snprintf    plsnprintf
   #define snscanf     plsnscanf
 #endif // PL_HAVE_SNPRINTF
@@ -307,6 +308,44 @@ int plsnscanf( const char *buffer, int n, const char *format, ... );
 #define LPAGE_X     ( PIXELS_X / VDPMM ) // virtual page length in x in mm (256)
 #define LPAGE_Y     ( PIXELS_Y / VDPMM ) // virtual page length in y in mm (192)
 
+// Constants that help to define ideal plspage arguments for devices
+
+#define PLPLOT_MM_PER_INCH        25.4
+#define PLPLOT_POINTS_PER_INCH    72.
+#define PLPLOT_WIDTH_A4_MM        297.
+#define PLPLOT_HEIGHT_A4_MM       210.
+#define PLPLOT_WIDTH_A5_MM        210.
+#define PLPLOT_HEIGHT_A5_MM       148.
+
+// Devices with pixel units for sizes.
+
+// Adopt this default value as reasonable approximation for typical
+// LCD monitors, but note that the user can replace this default by
+// setting plsc->[xy]dpi values (e.g., by using the -dpi command-line
+// option or by calling plspage with non-zero first two arguments).
+#define PLPLOT_DEFAULT_PIXELS_PER_INCH    90.
+// These default pixel dimensions correspond to A5 size if actual
+// pixels per inch is PLPLOT_DEFAULT_PIXELS_PER_INCH
+#define PLPLOT_DEFAULT_WIDTH_PIXELS       ( (int) ( PLPLOT_WIDTH_A5_MM * PLPLOT_DEFAULT_PIXELS_PER_INCH / PLPLOT_MM_PER_INCH ) )
+#define PLPLOT_DEFAULT_HEIGHT_PIXELS      ( (int) ( PLPLOT_HEIGHT_A5_MM * PLPLOT_DEFAULT_PIXELS_PER_INCH / PLPLOT_MM_PER_INCH ) )
+
+// Devices with real world units for sizes.
+
+// N.B. these devices normally use fixed values of units per inch,
+// i.e., they ignore any attempt by users to set plsc->[xy]dpi values
+// (e.g., by using the -dpi command-line option or by calling plspage
+// with non-zero first two arguments).
+
+// 1. Devices with mm units for sizes.
+// These default mm dimensions correspond to A4 size.
+#define PLPLOT_DEFAULT_WIDTH_MM     ( (int) ( PLPLOT_WIDTH_A4_MM )
+#define PLPLOT_DEFAULT_HEIGHT_MM    ( (int) ( PLPLOT_HEIGHT_A4_MM )
+
+// 2. Devices with points (= 1/72 inch) units for sizes.
+// These default points dimensions correspond to A4 size.
+#define PLPLOT_DEFAULT_WIDTH_POINTS     ( (int) ( PLPLOT_WIDTH_A4_MM * PLPLOT_POINTS_PER_INCH / PLPLOT_MM_PER_INCH ) )
+#define PLPLOT_DEFAULT_HEIGHT_POINTS    ( (int) ( PLPLOT_HEIGHT_A4_MM * PLPLOT_POINTS_PER_INCH / PLPLOT_MM_PER_INCH ) )
+
 // This defines the first argument of the plRotPhy invocation that is made
 // in a number of device drivers (e.g., found in ps.c
 // and pstex.c) to rotate them "permanently" from portrait mode to non-
@@ -482,8 +521,8 @@ plP_affine_yskew( PLFLT *affine_vector, PLFLT angle );
 PLDLLIMPEXP void
 plP_affine_multiply(
     PLFLT *affine_vectorA,
-    const PLFLT *affine_vectorB,
-    const PLFLT *affine_vectorC );
+    PLFLT_VECTOR affine_vectorB,
+    PLFLT_VECTOR affine_vectorC );
 
 // Determines interval between numeric labels
 
@@ -493,7 +532,7 @@ pldtik( PLFLT vmin, PLFLT vmax, PLFLT *tick, PLINT *nsubt, PLBOOL ld );
 // Writes numeric labels on side(s) of box in custom locations
 
 void
-label_box_custom( const char *xopt, PLINT n_xticks, const PLFLT *xticks, const char *yopt, PLINT n_yticks, const PLFLT *yticks );
+label_box_custom( PLCHAR_VECTOR xopt, PLINT n_xticks, PLFLT_VECTOR xticks, PLCHAR_VECTOR yopt, PLINT n_yticks, PLFLT_VECTOR yticks );
 
 // Determine factor to convert date / time in seconds to more natural
 // units
@@ -548,7 +587,7 @@ plfill_soft( short *x, short *y, PLINT npts );
 // error message and tries to clean up as much as possible.
 
 PLDLLIMPEXP void
-plexit( const char *errormsg );
+plexit( PLCHAR_VECTOR errormsg );
 
 // Just a front-end to exit().
 
@@ -558,12 +597,12 @@ pl_exit( void );
 // A handy way to issue warnings, if need be.
 
 PLDLLIMPEXP void
-plwarn( const char *errormsg );
+plwarn( PLCHAR_VECTOR errormsg );
 
 // Same as plwarn(), but appends ", aborting plot" to the error message
 
 PLDLLIMPEXP void
-plabort( const char *errormsg );
+plabort( PLCHAR_VECTOR errormsg );
 
 // Loads either the standard or extended font.
 
@@ -578,7 +617,7 @@ plfontrel( void );
 // A replacement for strdup(), which isn't portable.
 
 PLDLLIMPEXP char *
-plstrdup( const char *src );
+plstrdup( PLCHAR_VECTOR src );
 
 // Bin up cmap 1 space and assign colors to make inverse mapping easy.
 
@@ -595,7 +634,7 @@ plstik( PLFLT mx, PLFLT my, PLFLT dx, PLFLT dy );
 // (refx,refy).
 
 void
-plstr( PLINT base, PLFLT *xform, PLINT refx, PLINT refy, const char *string );
+plstr( PLINT base, PLFLT *xform, PLINT refx, PLINT refy, PLCHAR_VECTOR string );
 
 // Draws a tick parallel to x.
 
@@ -632,7 +671,7 @@ plP_script_scale( PLBOOL ifupper, PLINT *level,
 
 void
 plP_text( PLINT base, PLFLT just, PLFLT *xform, PLINT x, PLINT y,
-          PLINT refx, PLINT refy, const char *string );
+          PLINT refx, PLINT refy, PLCHAR_VECTOR string );
 
 // Save LC_NUMERIC locale string, then set "C" locale to protect
 // parts of PLplot which absolutely demand the LC_NUMERIC "C" locale.
@@ -704,10 +743,10 @@ typedef struct
 
 typedef struct
 {
-    const char *opt;     // a string with the name of the option
-    PLINT      type;     // the type of the variable to be set, see bellow the available types
-    void       *var_ptr; // a pointer to the variable to be set
-    const char *hlp_msg; // help message of the option
+    PLCHAR_VECTOR opt;      // a string with the name of the option
+    PLINT         type;     // the type of the variable to be set, see bellow the available types
+    void          *var_ptr; // a pointer to the variable to be set
+    PLCHAR_VECTOR hlp_msg;  // help message of the option
 } DrvOpt;
 
 // the available variable types, DrvOpt.type, for driver specific options
@@ -748,9 +787,9 @@ typedef struct cont_level
 } CONT_LEVEL;
 
 void
-cont_store( const PLFLT * const *f, PLINT nx, PLINT ny,
+cont_store( PLFLT_MATRIX f, PLINT nx, PLINT ny,
             PLINT kx, PLINT lx, PLINT ky, PLINT ly,
-            const PLFLT *clevel, PLINT nlevel,
+            PLFLT_VECTOR clevel, PLINT nlevel,
             void ( *pltr )( PLFLT, PLFLT, PLFLT *, PLFLT *, PLPointer ),
             PLPointer pltr_data,
             CONT_LEVEL **contour );
@@ -852,7 +891,7 @@ plP_draphy_poly( PLINT *x, PLINT *y, PLINT n );
 // Draw polyline in world coordinates.
 
 void
-plP_drawor_poly( const PLFLT *x, const PLFLT *y, PLINT n );
+plP_drawor_poly( PLFLT_VECTOR x, PLFLT_VECTOR y, PLINT n );
 
 // Sets up physical limits of plotting device.
 
@@ -877,22 +916,22 @@ plP_gtimefmt( void );
 // Computes the length of a string in mm, including escape sequences.
 
 PLFLT
-plstrl( const char *string );
+plstrl( PLCHAR_VECTOR string );
 
 // Similar to strpos, but searches for occurence of string str2.
 
 PLINT
-plP_stindex( const char *str1, const char *str2 );
+plP_stindex( PLCHAR_VECTOR str1, PLCHAR_VECTOR str2 );
 
 // Searches string str for first occurence of character chr.
 
 PLDLLIMPEXP PLINT
-plP_strpos( const char *str, int chr );
+plP_strpos( PLCHAR_VECTOR str, int chr );
 
 // Searches string str for character chr (case insensitive).
 
 PLBOOL
-plP_stsearch( const char *str, int chr );
+plP_stsearch( PLCHAR_VECTOR str, int chr );
 
 // Conversion functions
 
@@ -1018,7 +1057,7 @@ plRotationShear( PLFLT *xFormMatrix, PLFLT *rotation, PLFLT *shear, PLFLT *strid
 
 // Test whether a point is in a polygon.
 int
-plP_pointinpolygon( PLINT n, const PLFLT *x, const PLFLT *y,
+plP_pointinpolygon( PLINT n, PLFLT_VECTOR x, PLFLT_VECTOR y,
                     PLFLT xp, PLFLT yp );
 
 // Driver calls
@@ -1105,7 +1144,7 @@ plP_wait( void );
 // Return file pointer to lib file.
 
 FILE *
-plLibOpen( const char *fn );
+plLibOpen( PLCHAR_VECTOR fn );
 
 // Does required startup initialization of library.
 
