@@ -13,8 +13,9 @@ usage () {
     local prog=`basename $0`
     echo "Usage: $prog [OPTIONS]
 OPTIONS:
-  The next option specifies the directory prefix which controls where
-  all files produced by this script are located.
+  The next option specifies the directory prefix (absolute or relative to
+  the original directory from which this script was invoked) which controls
+  where all files produced by this script are located.
   [--prefix (defaults to the 'comprehensive_test_disposeable'
                   subdirectory of the directory just above the
                   top-level source-tree directory)]
@@ -79,46 +80,46 @@ collect_exit() {
     # have been defined.
 
     return_code=$1
-    cd $prefix
+    cd "$prefix"
 
     # Clean up stale results before appending new information to the tarball.
-    TARBALL=$prefix/comprehensive_test.tar
+    TARBALL="$prefix/comprehensive_test.tar"
 
-    rm -f $TARBALL $TARBALL.gz
+    rm -f "$TARBALL" "$TARBALL.gz"
 
     # Collect relevant subset of $prefix information in the tarball
     if [ -f $RELATIVE_COMPREHENSIVE_TEST_LOG ] ; then
-	tar rf $TARBALL $RELATIVE_COMPREHENSIVE_TEST_LOG
+	tar rf "$TARBALL" $RELATIVE_COMPREHENSIVE_TEST_LOG
     fi
 
     if [ -f $RELATIVE_ENVIRONMENT_LOG ] ; then
-	tar rf $TARBALL $RELATIVE_ENVIRONMENT_LOG
+	tar rf "$TARBALL" $RELATIVE_ENVIRONMENT_LOG
     fi
 
     for directory in shared/interactive shared/noninteractive nondynamic/interactive nondynamic/noninteractive static/interactive static/noninteractive ; do
 	if [ -d $directory/output_tree ] ; then
-	    tar rf $TARBALL $directory/output_tree
+	    tar rf "$TARBALL" $directory/output_tree
 	fi
 	if [ -f $directory/build_tree/CMakeCache.txt ] ; then
-	    tar rf $TARBALL $directory/build_tree/CMakeCache.txt
+	    tar rf "$TARBALL" $directory/build_tree/CMakeCache.txt
 	fi
 	if [ -f $directory/install_build_tree/CMakeCache.txt ] ; then
-	    tar rf $TARBALL $directory/install_build_tree/CMakeCache.txt
+	    tar rf "$TARBALL" $directory/install_build_tree/CMakeCache.txt
 	fi
     done
 
     # Collect listing of every file generated by the script
     find . -type f |xargs ls -l >| comprehensive_test_listing.out
-    tar rf $TARBALL comprehensive_test_listing.out
+    tar rf "$TARBALL" comprehensive_test_listing.out
 
-    gzip $TARBALL
+    gzip "$TARBALL"
 
     exit $return_code
 }
 
 echo_tee() {
     # N.B. only useful after this script defines $COMPREHENSIVE_TEST_LOG
-    echo "$@" |tee -a $COMPREHENSIVE_TEST_LOG
+    echo "$@" |tee -a "$COMPREHENSIVE_TEST_LOG"
 }
 
 comprehensive_test () {
@@ -133,17 +134,17 @@ CMAKE_BUILD_TYPE_OPTION = $CMAKE_BUILD_TYPE_OPTION
 TEST_TYPE = ${TEST_TYPE}
 
 The location below is where all the important *.out files will be found.
-OUTPUT_TREE = $OUTPUT_TREE
+OUTPUT_TREE = \"$OUTPUT_TREE\"
 
 The location below is the top-level build-tree directory.
-BUILD_TREE = $BUILD_TREE
+BUILD_TREE = \"$BUILD_TREE\"
 
 The location below is the top-level install-tree directory.
-INSTALL_TREE = $INSTALL_TREE
+INSTALL_TREE = \"$INSTALL_TREE\"
 
 The location below is the top-level directory of the build tree used
 for the CMake-based build and test of the installed examples.
-INSTALL_BUILD_TREE = $INSTALL_BUILD_TREE"
+INSTALL_BUILD_TREE = \"$INSTALL_BUILD_TREE\""
 
     echo_tee "
 This variable specifies whether any windows platform has been detected
@@ -152,7 +153,7 @@ ANY_WINDOWS_PLATFORM=$ANY_WINDOWS_PLATFORM"
     echo_tee "
 Each of the steps in this comprehensive test may take a while...."
 
-    PATH_SAVE=$PATH
+    PATH_SAVE="$PATH"
     mkdir -p "$OUTPUT_TREE"
     # Clean start with nonexistent install tree and empty build tree(s).
     rm -rf "$INSTALL_TREE"
@@ -172,8 +173,8 @@ Each of the steps in this comprehensive test may take a while...."
     rm -f "$output"
 
     if [ "$CMAKE_BUILD_TYPE_OPTION" != "-DBUILD_SHARED_LIBS=OFF" -a "$ANY_WINDOWS_PLATFORM" = "true" ] ; then
-	echo_tee "Prepend $BUILD_TREE/dll to the original PATH"
-	PATH=$BUILD_TREE/dll:$PATH_SAVE
+	echo_tee "Prepend \"$BUILD_TREE/dll\" to the original PATH"
+	PATH="$BUILD_TREE/dll:$PATH_SAVE"
     fi
 
     # Process $cmake_added_options into $* to be used on the ${cmake_command} command
@@ -256,29 +257,31 @@ Each of the steps in this comprehensive test may take a while...."
 	if [[ "$OSTYPE" =~ ^linux && "$CMAKE_BUILD_TYPE_OPTION" != "-DBUILD_SHARED_LIBS=OFF" ]]; then
 	    # The above install and the above "if" assure there are
 	    # *.so files in both the build and install trees for the
-	    # linux case that can be analyzed with ldd -r.
-	    # N.B. we deliberately drop dllplplot_stubs.so from the
-	    # reports because there is no known way to set the rpath
-	    # for that ocamlmklib-generated shared object at the
-	    # moment.  See plplot-devel mailing discusion on
-	    # 2016-12-09 with the subject line
-	    # "Setting rpath for dllplplot_stubs.so appears not to be possible".
+	    # linux case that can be analyzed with ldd -r.  N.B. we
+	    # deliberately drop dllplplot_stubs.so and
+	    # dllinstalled_plplotstubs.so from the reports because
+	    # there is no known way to set the rpath for that
+	    # ocamlmklib-generated shared object at the moment.  See
+	    # plplot-devel mailing discusion on 2016-12-09 with the
+	    # subject line "Setting rpath for dllplplot_stubs.so
+	    # appears not to be possible".
 	    output="$OUTPUT_TREE"/build_tree_ldd.out
 	    rm -f "$output"
-	    echo_tee "find \"$BUILD_TREE\" -name \"*.so\" | grep -v 'dllplplot_stubs\.so' |xargs ldd -r in the build tree just after the install for TEST_TYPE = ${TEST_TYPE})"
-	    find "$BUILD_TREE" -name "*.so" | grep -v 'dllplplot_stubs\.so' | xargs ldd -r >& "$output"
+	    echo_tee "find \"$BUILD_TREE\" -name \"*.so\" -a ! -name \"dll*plplot_stubs.so\" -a -print0 |xargs -0 ldd -r >& \"$output\" in the build tree just after the install for TEST_TYPE = ${TEST_TYPE})"
+	    find "$BUILD_TREE" -name "*.so" -a ! -name "dll*plplot_stubs.so" -a -print0 | xargs -0 ldd -r >& "$output"
 	    ldd_rc=$?
 	    if [ "$ldd_rc" -ne 0 ] ; then
-		echo_tee "ERROR: find \"$BUILD_TREE\" -name \"*.so\" | grep -v 'dllplplot_stubs\.so' | xargs ldd -r failed in the build tree"
+		echo_tee "ERROR: find \"$BUILD_TREE\" -name \"*.so\" -a ! -name \"dll*plplot_stubs.so\" -a -print0 |xargs -0 ldd -r >& \"$output\" failed in the build tree"
 		collect_exit 1
 	    fi
+
 	    output="$OUTPUT_TREE"/install_tree_ldd.out
 	    rm -f "$output"
-	    echo_tee "find \"$INSTALL_TREE\" -name \"*.so\" | grep -v 'dllplplot_stubs\.so' | xargs ldd -r in the install tree just after the install for TEST_TYPE = ${TEST_TYPE})"
-	    find "$INSTALL_TREE" -name "*.so" | grep -v 'dllplplot_stubs\.so' | xargs ldd -r >& "$output"
+	    echo_tee "find \"$INSTALL_TREE\" -name \"*.so\" -a ! -name \"dll*plplot_stubs.so\" -a -print0 |xargs -0 ldd -r >& \"$output\" in the install tree just after the install for TEST_TYPE = ${TEST_TYPE})"
+	    find "$INSTALL_TREE" -name "*.so" -a ! -name "dll*plplot_stubs.so" -a -print0 | xargs -0 ldd -r >& "$output"
 	    ldd_rc=$?
 	    if [ "$ldd_rc" -ne 0 ] ; then
-		echo_tee "ERROR: find \"$INSTALL_TREE\" -name \"*.so\" | grep -v 'dllplplot_stubs\.so' | xargs ldd -r failed in the install tree"
+		echo_tee "ERROR: find \"$INSTALL_TREE\" -name \"*.so\" -a ! -name \"dll*plplot_stubs.so\" -a -print0 |xargs -0 ldd -r >& \"$output\" failed in the install tree"
 		collect_exit 1
 	    fi
 	fi
@@ -297,15 +300,15 @@ Each of the steps in this comprehensive test may take a while...."
     fi
 
     if [ "$do_test_install_tree" = "yes" -o "$do_test_traditional_install_tree" = "yes" ] ; then
-	echo_tee "Prepend $INSTALL_TREE/bin to the original PATH"
-	PATH="$INSTALL_TREE/bin":$PATH_SAVE
+	echo_tee "Prepend \"$INSTALL_TREE/bin\" to the original PATH"
+	PATH="$INSTALL_TREE/bin:$PATH_SAVE"
 
 	if [ "$CMAKE_BUILD_TYPE_OPTION" = "-DBUILD_SHARED_LIBS=ON" -a "$ANY_WINDOWS_PLATFORM" = "true" ] ; then
 	    # Use this logic to be as version-independent as possible.
-	    current_dir=$(pwd)
+	    current_dir="$(pwd)"
 	    # Wild cards must not be inside quotes.
 	    cd "$INSTALL_TREE"/lib/plplot[0-9].[0-9]*.[0-9]*/drivers*
-	    echo_tee "Prepend $(pwd) to the current PATH"
+	    echo_tee "Prepend \"$(pwd)\" to the current PATH"
 	    PATH="$(pwd):$PATH"
 	    cd $current_dir
 	fi
@@ -370,7 +373,7 @@ Each of the steps in this comprehensive test may take a while...."
 	fi
     fi
     echo_tee "Restore PATH to its original form"
-    PATH=$PATH_SAVE
+    PATH="$PATH_SAVE"
 }
 
 # Start of actual script after functions are defined.
@@ -386,7 +389,7 @@ cd "${ORIGINAL_PATH}"
 
 # Assumption: top-level source tree is parent directory of where script
 # is located.
-SOURCE_TREE="$(dirname ${SCRIPT_PATH})"
+SOURCE_TREE=$(dirname "${SCRIPT_PATH}")
 # This is the parent tree for the BUILD_TREE, INSTALL_TREE,
 # INSTALL_BUILD_TREE, and OUTPUT_TREE.  It is disposable.
 
@@ -421,7 +424,7 @@ while test $# -gt 0; do
 
     case $1 in
         --prefix)
-	    prefix=$2
+	    prefix="$2"
 	    shift
 	    ;;
 	--do_clean_first)
@@ -430,7 +433,7 @@ while test $# -gt 0; do
 		    do_clean_first=$2
 		    shift
 		    ;;
-		
+
 		*)
 		    usage 1 1>&2
 		    ;;
@@ -442,7 +445,7 @@ while test $# -gt 0; do
 		    do_clean_as_you_go=$2
 		    shift
 		    ;;
-		
+
 		*)
 		    usage 1 1>&2
 		    ;;
@@ -474,7 +477,7 @@ while test $# -gt 0; do
 		    do_submit_dashboard=$2
 		    shift
 		    ;;
-		
+
 		*)
 		    usage 1 1>&2
 		    ;;
@@ -486,7 +489,7 @@ while test $# -gt 0; do
 		    do_shared=$2
 		    shift
 		    ;;
-		
+
 		*)
 		    usage 1 1>&2
 		    ;;
@@ -601,7 +604,11 @@ if [ $usage_reported -eq 1 ]; then
 fi
 
 # Create $prefix directory if it does not exist already
-mkdir -p $prefix
+mkdir -p "$prefix"
+# Convert $prefix to absolute path (if it is not already that).
+cd "$prefix"
+prefix="$(pwd)"
+cd "${ORIGINAL_PATH}"
 
 # Establish names of output files.  We do this here (as soon as
 # possible after $prefix is determined) because
@@ -609,12 +616,12 @@ mkdir -p $prefix
 # The relative versions of these are needed for the tar command.
 RELATIVE_COMPREHENSIVE_TEST_LOG=comprehensive_test.sh.out
 RELATIVE_ENVIRONMENT_LOG=comprehensive_test_env.out
-COMPREHENSIVE_TEST_LOG=$prefix/$RELATIVE_COMPREHENSIVE_TEST_LOG
-ENVIRONMENT_LOG=$prefix/$RELATIVE_ENVIRONMENT_LOG
+COMPREHENSIVE_TEST_LOG="$prefix/$RELATIVE_COMPREHENSIVE_TEST_LOG"
+ENVIRONMENT_LOG="$prefix/$RELATIVE_ENVIRONMENT_LOG"
 
 # Clean up stale results before appending new information to this file
 # with the echo_tee command.
-rm -f $COMPREHENSIVE_TEST_LOG
+rm -f "$COMPREHENSIVE_TEST_LOG"
 
 # Set up trap of user interrupts as soon as possible after the above variables
 # have been determined and the stale $COMPREHENSIVE_TEST_LOG has been removed.
@@ -627,7 +634,7 @@ if [ "$hash_rc" -ne 0 ] ; then
     echo_tee "WARNING: git not on PATH so cannot determine if SOURCE_TREE =
 $SOURCE_TREE is a git repository or not"
 else
-    cd $SOURCE_TREE
+    cd "$SOURCE_TREE"
     git_commit_id=$(git rev-parse --short HEAD)
     git_rc=$?
     if [ "$git_rc" -ne 0 ] ; then
@@ -695,20 +702,19 @@ the high-water mark of disk usage can still be as high as 4GB so be
 sure you have enough free disk space to run this test!
 "
 
-# N.B. dashboard_option must always have a trailing blank
 if [ "$do_submit_dashboard" = "yes" ] ; then
-    echo_tee "WARNING: Because you have specified \"do_submit_dashboard $do_submit_dashboard\" above, all details concerning each
+    echo_tee "WARNING: Because you have specified \"do_submit_dashboard $do_submit_dashboard\" above, all (anonymized) details concerning each
 of your ctest results will be published at <http://my.cdash.org/index.php?project=PLplot_git>
 "
     dashboard_option="-D Experimental "
 else
-    dashboard_option=" "
+    dashboard_option=""
 fi
 
 
 if [ "$do_clean_first" = "yes" ] ; then
     echo_tee "WARNING: The shared, nondynamic, and static subdirectory trees of
-$prefix
+\"$prefix\"
 are about to be removed!
 "
 fi
@@ -729,7 +735,7 @@ if [ "$ANSWER" = "no" ] ; then
 fi
 
 if [ "$do_clean_first" = "yes" ] ; then
-    rm -rf $prefix/shared $prefix/nondynamic $prefix/static
+    rm -rf "$prefix/shared" "$prefix/nondynamic" "$prefix/static"
 fi
 
 # Discover if it is a Windows platform or not.
@@ -759,15 +765,20 @@ else
 fi
 
 # Collect selected important environment variable results prior to testing.
-rm -f $ENVIRONMENT_LOG
-echo "PATH=$PATH" > $ENVIRONMENT_LOG
-echo "CC=$CC" >> $ENVIRONMENT_LOG
-echo "CXX=$CXX" >> $ENVIRONMENT_LOG
-echo "FC=$FC" >> $ENVIRONMENT_LOG
+rm -f "$ENVIRONMENT_LOG"
 if [ "$HAS_PRINTENV" = "false" ] ; then
     echo_tee "WARNING: printenv not on PATH so cannot collect certain important environment variables in $ENVIRONMENT_LOG"
 else
-    printenv |grep -E '^CMAKE_.*PATH=|^.*FLAGS=|^PKG_CONFIG_PATH=|^LD_LIBRARY_PATH=|PLPLOT' >> $ENVIRONMENT_LOG
+    echo "# Look for the following subset of environment variables:
+    # Java-related,
+    # non-Java compilers,
+    # compiler flags,
+    # PATH-related variables,
+    # current directory, and
+    # PLplot-related." > "$ENVIRONMENT_LOG"
+    for ENVVAR in "$(printenv |grep -E '^JAVA.*=|^ADA=|^CC=|^CXX=|^DC=|^FC=|^.*FLAGS=|^PATH=|^CMAKE_.*PATH=|^PKG_CONFIG_PATH=|^LD_LIBRARY_PATH=|^PWD=|PLPLOT' | sort -u)"; do
+	echo "${ENVVAR}" | sed -e 's?=?="?' -e 's?\(.*\)$?\1"?' >> "$ENVIRONMENT_LOG"
+    done
 fi
 
 test_types=
