@@ -21,7 +21,7 @@ read GROUPNAME
 echo -n "ssh-accessible hostname? "
 read HOSTNAME
 echo "The following directory prefix on '$HOSTNAME' will be removed and then replaced by the complete PLplot website so be careful with what you specify"
-echo -n "Expendable directory prefix on '$HOSTNAME'? " 
+echo -n "Expendable directory prefix on '$HOSTNAME'? "
 read WEBSITE_PREFIX
 echo ""
 echo "Summary:"
@@ -58,18 +58,23 @@ rm -rf /tmp/plplotdoc
 mkdir -p /tmp/plplotdoc/build
 cd /tmp/plplotdoc
 echo ""
-echo "svn export working copy (with local changes) from"
-echo "$SOURCE_TREE to /tmp/plplotdoc/plplot_source"
-svn --quiet export $SOURCE_TREE plplot_source
+echo "Use git checkout-index to copy working directory from staged or committed"
+echo "changes of current branch of $SOURCE_TREE to /tmp/plplotdoc/plplot_source"
+# For checkout-index, trailing slash for prefix directory is important for some
+# reason according to the man page.  Furthermore, it turns out
+# that --prefix must be an absolute directory.
+git --work-tree=$SOURCE_TREE --git-dir=$SOURCE_TREE/.git checkout-index --all --prefix=/tmp/plplotdoc/plplot_source/
 echo ""
 echo "Configure and build PLplot documentation.  This may take a while depending on your cpu speed...."
 cd /tmp/plplotdoc/build
+
+# Do NOT exclude all bindings and devices since some of the bindings are dependencies of the
+# doxygen build and some of the bindings depend on certain devices being enabled.
 cmake \
     -DWWW_USER=$USERNAME \
     -DWWW_GROUP=$GROUPNAME \
     -DWWW_HOST=$HOSTNAME \
     -DWWW_DIR=$WEBSITE_PREFIX \
-    -DDEFAULT_NO_BINDINGS=ON -DDEFAULT_NO_DEVICES=ON \
     -DPREBUILD_DIST=ON \
     -DBUILD_DOC=ON \
     -DBUILD_DOX_DOC=ON \
@@ -93,7 +98,7 @@ make VERBOSE=1 www-install-doxygen >& make_www-install-doxygen.out
 echo ""
 echo "Build PLplot, PLplot examples, and screenshots of those examples.  This may take a while depending on your cpu speed...."
 
-# N.B. this command completely removes WWW_DIR/htdocs/examples-data 
+# N.B. this command completely removes WWW_DIR/htdocs/examples-data
 # on $HOSTNAME so be careful how you specify WWW_DIR!
 
 cd /tmp/plplotdoc/plplot_source
