@@ -171,7 +171,7 @@ filled).
 		<input type="submit" name="lbind" value="C" />
 		<input type="submit" name="lbind" value="C++" />
 		<input type="submit" name="lbind" value="D" />
-		<input type="submit" name="lbind" value="F95" />
+		<input type="submit" name="lbind" value="Fortran" />
 		<input type="submit" name="lbind" value="Java" />
 		<input type="submit" name="lbind" value="Lua" />
 		<input type="submit" name="lbind" value="Ocaml" />
@@ -187,7 +187,7 @@ END;
 	  case ("C"):      $fname = "x" . $demo_str . "c.c.txt"; break;
 	  case ("C++"):$fname = "x" . $demo_str . ".cc.txt"; break;
 	  case ("D"):$fname = "x" . $demo_str . "d.d.txt"; break;
-	  case ("F95"):    $fname = "x" . $demo_str . "f.f90.txt"; break;
+	  case ("Fortran"):    $fname = "x" . $demo_str . "f.f90.txt"; break;
 	  case ("Java"):   $fname = "x" . $demo_str . ".java.txt"; break;
 	  case ("Lua"):    $fname = "x" . $demo_str . ".lua.txt"; break;
 	  case ("Ocaml"):  $fname = "x" . $demo_str . ".ml.txt"; break;
@@ -200,7 +200,7 @@ END;
     // view code
 	  echo "<object id=\"codebox\" type=\"text/plain\" data=\"$demo_dir/$fname\">\n";
 		echo "Your browser is not able to display text!\n</object>\n";
-			
+
     // show plots for chosen example
 	  echo "<p>Select to view full-size image</p>\n";
 		echo "<p>\n";
@@ -234,7 +234,7 @@ END;
 		echo <<<END
 			<h3>Examples</h3>
 			<p>These examples were generated with the pngcairo device and
-				 reflect the status of PLplot-5.12.0.</p>
+				 reflect the status of PLplot-5.13.0.</p>
 			<p>Select a thumbnail to view full-size image and source code.</p>
 			<p>
 END;
